@@ -531,8 +531,13 @@ mrp_calendar_remove (MrpCalendar *calendar)
 		new_cal = parent;
 	} else {
 		list = mrp_calendar_get_children (root);
-		if (list) {
-			new_cal = list->data;
+
+		// find the first calendar that is different from the removed calendar
+		for ( ; list ; list = list->next) {
+			if(list->data != calendar) {
+				new_cal = list->data;
+				break;
+			}
 		}
 	}
 
@@ -591,8 +596,10 @@ mrp_calendar_remove (MrpCalendar *calendar)
 
 	g_list_free (list);
 
+	// unlink the removed calendar from its parent
 	if (parent) {
-		priv->children = g_list_remove (priv->children,
+		MrpCalendarPrivate *parent_priv = mrp_calendar_get_instance_private(parent);
+		parent_priv->children = g_list_remove (parent_priv->children,
 						calendar);
 		priv->parent = NULL;
 	}
