@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __MRP_DAY_H__
-#define __MRP_DAY_H__
+#pragma once
 
 #define MRP_TYPE_DAY               (mrp_day_get_type ())
 
@@ -66,5 +65,3 @@ void           mrp_day_unref              (MrpDay      *day);
 MrpDay *       mrp_day_get_work           (void);
 MrpDay *       mrp_day_get_nonwork        (void);
 MrpDay *       mrp_day_get_use_base       (void);
-
-#endif /* __MRP_DAY_H__ */
