@@ -21,8 +21,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __MRP_FILE_MODULE_H__
-#define __MRP_FILE_MODULE_H__
+#pragma once
 
 #include <gmodule.h>
 #include "mrp-application.h"
@@ -95,5 +94,3 @@ gboolean        mrp_file_writer_write              (MrpFileWriter   *writer,
 						    const gchar     *uri,
 						    gboolean         force,
 						    GError         **error);
-
-#endif /* __MRP_FILE_MODULE_H__ */
