@@ -182,12 +182,17 @@ mrp_object_get_g_property (GObject      *g_object,
 static void
 mrp_object_class_init (MrpObjectClass *klass)
 {
-        GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->finalize     = mrp_object_finalize;
-        object_class->set_property = mrp_object_set_g_property;
-        object_class->get_property = mrp_object_get_g_property;
+	object_class->finalize     = mrp_object_finalize;
+	object_class->set_property = mrp_object_set_g_property;
+	object_class->get_property = mrp_object_get_g_property;
 
+	/* TODO: Base implementation shouldn't be missing as it is expected that subclasses
+	call the parent classes method. Either implement a base function or move the vmethod
+	to lower level. Also investigate why is mrp_object_removed() called manually, and
+	should it instead be what the base class implementation of removed() should do?
+	 */
 	klass->removed             = NULL;
 
 	/* Signals */
