@@ -76,6 +76,23 @@ typedef struct {
 	gint       id;
 } NodeEntry;
 
+
+/* These are wrapper functions around the xmlChar type,
+ * to prevent signedness conversion warnings.
+ */
+static xmlChar *
+xmlGetProp_ (xmlNodePtr node, const gchar * x)
+{
+	return xmlGetProp (node, (const xmlChar *) x);
+};
+
+static int
+strcmp_ (const xmlChar * x, const gchar * y)
+{
+	return strcmp ((const char *) x, (const char *) y);
+};
+
+
 static gchar           *old_xml_get_string            (xmlNodePtr   node,
 						       const char  *name);
 static gint             old_xml_get_int               (xmlNodePtr   node,
@@ -110,7 +127,7 @@ old_xml_read_predecessor (MrpParser  *parser,
 	gchar           *str;
 	MrpRelationType  type;
 
-	if (strcmp (tree->name, "predecessor")){
+	if (strcmp_ (tree->name, "predecessor")){
 		/*g_warning ("Got %s, expected 'predecessor'.", tree->name);*/
 		return;
 	}
@@ -192,7 +209,7 @@ old_xml_read_custom_properties (MrpParser  *parser,
 	xmlNodePtr child;
 
 	for (child = node->children; child; child = child->next) {
-		if (strcmp (child->name, "property")) {
+		if (strcmp_ (child->name, "property")) {
 			continue;
 		}
 
@@ -220,7 +237,7 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 	MrpTaskType    type;
 	MrpTaskSched   sched;
 
-	if (strcmp (tree->name, "task")){
+	if (strcmp_ (tree->name, "task")){
 		/*g_warning ("Got %s, expected 'task'.", tree->name);*/
 		return;
 	}
@@ -319,13 +336,13 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 	g_hash_table_insert (parser->task_hash, GINT_TO_POINTER (id), task);
 
 	for (child = tree->children; child; child = child->next) {
-			if (!strcmp (child->name, "properties")) {
+			if (!strcmp_ (child->name, "properties")) {
 				old_xml_read_custom_properties (parser, child, MRP_OBJECT (task));
 			}
 		}
 
 	for (tasks = tree->children; tasks; tasks = tasks->next) {
-		if (!strcmp (tasks->name, "task")) {
+		if (!strcmp_ (tasks->name, "task")) {
 			/* Silently correct old milestones with children to
 			 * normal tasks.
 			 */
@@ -336,12 +353,12 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 
 			old_xml_read_task (parser, tasks, task);
 		}
-		else if (!strcmp (tasks->name, "predecessors")) {
+		else if (!strcmp_ (tasks->name, "predecessors")) {
 			for (predecessor = tasks->children; predecessor; predecessor = predecessor->next) {
 				old_xml_read_predecessor (parser, id, predecessor);
 			}
 		}
-		else if (!strcmp (tasks->name, "constraint")) {
+		else if (!strcmp_ (tasks->name, "constraint")) {
 			got_constraint = old_xml_read_constraint (tasks, &constraint);
 		}
 	}
@@ -369,7 +386,7 @@ old_xml_read_resource (MrpParser *parser, xmlNodePtr tree)
 	MrpGroup    *group;
 	MrpCalendar *calendar;
 
-	if (strcmp (tree->name, "resource")){
+	if (strcmp_ (tree->name, "resource")){
 		/*g_warning ("Got %s, expected 'resource'.", tree->name);*/
 		return;
 	}
@@ -422,7 +439,7 @@ old_xml_read_resource (MrpParser *parser, xmlNodePtr tree)
 			NULL);
 
 	for (child = tree->children; child; child = child->next) {
-		if (!strcmp (child->name, "properties")) {
+		if (!strcmp_ (child->name, "properties")) {
 			old_xml_read_custom_properties (parser, child, MRP_OBJECT (resource));
 		}
 	}
@@ -446,7 +463,7 @@ old_xml_read_group (MrpParser *parser, xmlNodePtr tree)
 	gchar    *mgr_name, *mgr_phone, *mgr_email;
 	MrpGroup *group;
 
-	if (strcmp (tree->name, "group")){
+	if (strcmp_ (tree->name, "group")){
 		/*g_warning ("Got %s, expected 'group'.", tree->name);*/
 		return;
 	}
@@ -483,7 +500,7 @@ old_xml_read_assignment (MrpParser *parser, xmlNodePtr tree)
 	MrpTask       *task;
 	MrpResource   *resource;
 
-	if (strcmp (tree->name, "allocation")){
+	if (strcmp_ (tree->name, "allocation")){
 		/*g_warning ("Got %s, expected 'allocation'.", tree->name);*/
 		return;
 	}
@@ -531,22 +548,23 @@ old_xml_read_day_type (MrpParser *parser, xmlNodePtr tree)
 		return;
 	}
 
-	if (strcmp (tree->name, "day-type") != 0){
+	if (strcmp_ (tree->name, "day-type") != 0){
 		return;
 	}
 
-	name = xmlGetProp (tree, "name");
+	name = xmlGetProp_ (tree, "name");
 	if (!name) {
 		return;
 	}
 
-	desc = xmlGetProp (tree, "description");
+	desc = xmlGetProp_ (tree, "description");
 	if (!desc) {
 		xmlFree (name);
 		return;
 	}
 
-	day = mrp_day_add (parser->project, name, desc);
+	day = mrp_day_add (parser->project,
+			   (const gchar *) name, (const gchar *) desc);
 
 	xmlFree (name);
 	xmlFree (desc);
@@ -580,7 +598,7 @@ old_xml_read_overridden_day_type (MrpParser   *parser,
 	GList      *intervals = NULL;
 	xmlNodePtr  child;
 
-	if (strcmp (day->name, "overridden-day-type") != 0){
+	if (strcmp_ (day->name, "overridden-day-type") != 0){
 		return;
 	}
 
@@ -588,7 +606,7 @@ old_xml_read_overridden_day_type (MrpParser   *parser,
 	mrp_day = g_hash_table_lookup (parser->day_hash, GINT_TO_POINTER (id));
 
 	for (child = day->children; child; child = child->next) {
-		if (strcmp (child->name, "interval") == 0) {
+		if (strcmp_ (child->name, "interval") == 0) {
 			MrpInterval *interval;
 			gchar       *str;
 			gint         hour, min;
@@ -630,15 +648,15 @@ old_xml_read_overridden_day (MrpParser   *parser,
 	MrpDay  *mrp_day;
 	gint     y, m, d;
 
-	if (strcmp (day->name, "day") != 0){
+	if (strcmp_ (day->name, "day") != 0){
 		return;
 	}
 
-	xml_str = xmlGetProp (day, "type");
+	xml_str = xmlGetProp_ (day, "type");
 	if (!xml_str) {
 		return;
 	}
-	if (strcmp (xml_str, "day-type") != 0) {
+	if (strcmp_ (xml_str, "day-type") != 0) {
 		xmlFree (xml_str);
 		return;
 	}
@@ -648,12 +666,12 @@ old_xml_read_overridden_day (MrpParser   *parser,
 
 	mrp_day = g_hash_table_lookup (parser->day_hash, GINT_TO_POINTER (id));
 
-	xml_str = xmlGetProp (day, "date");
+	xml_str = xmlGetProp_ (day, "date");
 	if (!xml_str) {
 		return;
 	}
 
-	if (sscanf (xml_str, "%04d%02d%02d", &y, &m, &d) == 3) {
+	if (sscanf ((gchar *) xml_str, "%04d%02d%02d", &y, &m, &d) == 3) {
 		date = mrp_time_compose (y, m, d, 0, 0, 0);
 		mrp_calendar_set_days (calendar, date, mrp_day, (mrptime) -1);
 	} else {
@@ -671,19 +689,19 @@ old_xml_read_calendar (MrpParser *parser, MrpCalendar *parent, xmlNodePtr tree)
 	xmlNodePtr   child;
 	gint         id;
 
-	if (strcmp (tree->name, "calendar") != 0){
+	if (strcmp_ (tree->name, "calendar") != 0){
 		return;
 	}
 
-	name = xmlGetProp (tree, "name");
+	name = xmlGetProp_ (tree, "name");
 	if (!name) {
 		return;
 	}
 
 	if (parent) {
-		calendar = mrp_calendar_derive (name, parent);
+		calendar = mrp_calendar_derive ((gchar *) name, parent);
 	} else {
-		calendar = mrp_calendar_new (name, parser->project);
+		calendar = mrp_calendar_new ((gchar *) name, parser->project);
 	}
 
  	xmlFree (name);
@@ -694,10 +712,10 @@ old_xml_read_calendar (MrpParser *parser, MrpCalendar *parent, xmlNodePtr tree)
 			     calendar);
 
 	for (child = tree->children; child; child = child->next) {
-		if (strcmp (child->name, "calendar") == 0) {
+		if (strcmp_ (child->name, "calendar") == 0) {
 			old_xml_read_calendar (parser, calendar, child);
 		}
-		else if (strcmp (child->name, "default-week") == 0) {
+		else if (strcmp_ (child->name, "default-week") == 0) {
 			old_xml_read_default_day (parser, child, calendar,
 						  MRP_CALENDAR_DAY_MON, "mon");
 			old_xml_read_default_day (parser, child, calendar,
@@ -713,7 +731,7 @@ old_xml_read_calendar (MrpParser *parser, MrpCalendar *parent, xmlNodePtr tree)
 			old_xml_read_default_day (parser, child, calendar,
 						  MRP_CALENDAR_DAY_SUN, "sun");
 		}
-		else if (strcmp (child->name, "overridden-day-types") == 0) {
+		else if (strcmp_ (child->name, "overridden-day-types") == 0) {
 			xmlNodePtr day;
 
 			for (day = child->children; day; day = day->next) {
@@ -722,7 +740,7 @@ old_xml_read_calendar (MrpParser *parser, MrpCalendar *parent, xmlNodePtr tree)
 								  day);
 			}
 		}
-		else if (strcmp (child->name, "days") == 0) {
+		else if (strcmp_ (child->name, "days") == 0) {
 			xmlNodePtr day;
 
 			for (day = child->children; day; day = day->next) {
@@ -794,7 +812,7 @@ old_xml_read_string_list (xmlNodePtr  node,
 
 
 	for (child = node->children; child; child = child->next) {
-		if (!strcmp (child->name, "list-item")) {
+		if (!strcmp_ (child->name, "list-item")) {
 			str = old_xml_get_string (child, "value");
 
 			if (str && str[0]) {
@@ -826,7 +844,7 @@ old_xml_read_crufty_phases (xmlNodePtr  node)
 	}
 
 	for (child = node->children; child; child = child->next) {
-		if (!strcmp (child->name, "list-item")) {
+		if (!strcmp_ (child->name, "list-item")) {
 			str = old_xml_get_string (child, "value");
 
 			if (str && str[0]) {
@@ -861,7 +879,7 @@ old_xml_read_property_specs (MrpParser *parser)
 	}
 
 	for (child = node->children; child; child = child->next) {
-		if (strcmp (child->name, "property")) {
+		if (strcmp_ (child->name, "property")) {
 			continue;
 		}
 
@@ -944,7 +962,7 @@ old_xml_read_phases (MrpParser *parser)
 	}
 
 	for (child = node->children; child; child = child->next) {
-		if (strcmp (child->name, "phase")) {
+		if (strcmp_ (child->name, "phase")) {
 			continue;
 		}
 
@@ -975,7 +993,7 @@ old_xml_read_project (MrpParser *parser)
 
 	/* Get the first "properties" node, i.e. specs. */
 	while (child) {
-		if (!strcmp (child->name, "properties")) {
+		if (!strcmp_ (child->name, "properties")) {
 			old_xml_read_property_specs (parser);
 
 			child = child->next;
@@ -987,7 +1005,7 @@ old_xml_read_project (MrpParser *parser)
 
 	/* Get the second "properties" node, i.e. values. */
 	while (child) {
-		if (!strcmp (child->name, "properties")) {
+		if (!strcmp_ (child->name, "properties")) {
 			old_xml_read_custom_properties (parser,
 							child,
 							MRP_OBJECT (parser->project));
@@ -1025,7 +1043,7 @@ old_xml_read_project (MrpParser *parser)
 		}
 
 		for (child = calendars->children; child; child = child->next) {
-			if (strcmp (child->name, "calendar") == 0) {
+			if (strcmp_ (child->name, "calendar") == 0) {
 				old_xml_read_calendar (parser, NULL, child);
 			}
 		}
@@ -1105,7 +1123,7 @@ old_xml_get_value (xmlNodePtr node, const char *name)
 	gchar      *val;
 	xmlNodePtr  child;
 
-	val = (gchar *) xmlGetProp (node, name);
+	val = (gchar *) xmlGetProp_ (node, name);
 
 	if (val != NULL) {
 		return val;
@@ -1114,11 +1132,11 @@ old_xml_get_value (xmlNodePtr node, const char *name)
 	child = node->children;
 
 	while (child != NULL) {
-		if (!strcmp (child->name, name)) {
+		if (!strcmp_ (child->name, name)) {
 		        /*
 			 * !!! Inefficient, but ...
 			 */
-			val = xmlNodeGetContent(child);
+			val = (gchar *) xmlNodeGetContent (child);
 			if (val != NULL) {
 				return val;
 			}
@@ -1161,7 +1179,7 @@ old_xml_get_date (xmlNodePtr node, const char *name)
 
 	val = old_xml_get_value (node, name);
 
-	t = mrp_time_from_string (val, NULL);
+	t = mrp_time_from_string (val);
 
 	xmlFree (val);
 
@@ -1297,7 +1315,7 @@ old_xml_search_child (xmlNodePtr node, const gchar *name)
 
 	child = node->children;
 	while (child != NULL) {
-		if (!strcmp (child->name, name))
+		if (!strcmp_ (child->name, name))
 			return child;
 		child = child->next;
 	}
@@ -1418,7 +1436,7 @@ old_xml_set_property_from_node (MrpProject *project,
 		mrp_object_set (object, name, i, NULL);
 		break;
 	case MRP_PROPERTY_TYPE_DATE:
-		date = mrp_time_from_string (str, NULL);
+		date = mrp_time_from_string (str);
 		mrp_object_set (object, name, &date, NULL);
 		break;
 	case MRP_PROPERTY_TYPE_COST:
