@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __MRP_OLD_XML_H__
-#define __MRP_OLD_XML_H__
+#pragma once
 
 #include <glib.h>
 #include <libxml/parser.h>
@@ -30,5 +29,3 @@
 gboolean mrp_old_xml_parse (MrpProject  *project,
                             xmlDoc      *doc,
                             GError     **error);
-
-#endif /* __MRP_OLD_XML_H__ */
