@@ -45,7 +45,6 @@
 /* WARNING: This code is a hack just to have a file loader/saver for the old
  * format. Don't expect to understand any of the code or anything. It sucks.
  */
-
 typedef struct {
         xmlDocPtr   doc;
 
@@ -81,6 +80,23 @@ typedef struct {
 } NodeEntry;
 
 
+/* These are wrapper functions around the xmlChar type,
+ * to prevent the signedness conversion warnings.
+ */
+static void
+xmlSetProp_ (xmlNodePtr node, const gchar * x, const gchar * y)
+{
+	xmlSetProp (node, (const xmlChar *) x, (const xmlChar *) y);
+};
+
+static xmlNodePtr
+xmlNewChild_ (xmlNodePtr node, void * a, const gchar * x, void * b)
+{
+	/* a and b are NULL wherever it's called, just a dummy arg's */
+	return xmlNewChild (node, NULL, (const xmlChar *) x, NULL);
+};
+
+
 static void             mpp_xml_set_date              (xmlNodePtr   node,
 						       const gchar *prop,
 						       mrptime      time);
@@ -119,10 +135,10 @@ mpp_write_project_properties (MrpParser *parser, xmlNodePtr node)
 		      "phase", &phase,
 		      NULL);
 
-	xmlSetProp (node, "name", name);
-	xmlSetProp (node, "company", org);
-	xmlSetProp (node, "manager", manager);
-	xmlSetProp (node, "phase", phase);
+	xmlSetProp_ (node, "name", name);
+	xmlSetProp_ (node, "company", org);
+	xmlSetProp_ (node, "manager", manager);
+	xmlSetProp_ (node, "phase", phase);
 
 	mpp_xml_set_date (node, "project-start", pstart);
 	mpp_xml_set_int (node, "mrproject-version", 2);
@@ -233,21 +249,21 @@ mpp_write_property_specs (MrpParser *parser, xmlNodePtr node)
 	properties = mrp_project_get_properties_from_type (parser->project,
 							   MRP_TYPE_PROJECT);
 
-	node = xmlNewChild (node, NULL, "properties", NULL);
+	node = xmlNewChild_ (node, NULL, "properties", NULL);
 
 	for (l = properties; l; l = l->next) {
 		property = l->data;
 
-		child = xmlNewChild (node, NULL, "property", NULL);
+		child = xmlNewChild_ (node, NULL, "property", NULL);
 
-		xmlSetProp (child, "name", mrp_property_get_name (property));
+		xmlSetProp_ (child, "name", mrp_property_get_name (property));
 
 		type = mrp_property_get_property_type (property);
-		xmlSetProp (child, "type", mpp_property_type_to_string (type));
+		xmlSetProp_ (child, "type", mpp_property_type_to_string (type));
 
-		xmlSetProp (child, "owner", "project");
-		xmlSetProp (child, "label", mrp_property_get_label (property));
-		xmlSetProp (child, "description", mrp_property_get_description (property));
+		xmlSetProp_ (child, "owner", "project");
+		xmlSetProp_ (child, "label", mrp_property_get_label (property));
+		xmlSetProp_ (child, "description", mrp_property_get_description (property));
 	}
 
 	g_list_free (properties);
@@ -258,16 +274,16 @@ mpp_write_property_specs (MrpParser *parser, xmlNodePtr node)
 	for (l = properties; l; l = l->next) {
 		property = l->data;
 
-		child = xmlNewChild (node, NULL, "property", NULL);
+		child = xmlNewChild_ (node, NULL, "property", NULL);
 
-		xmlSetProp (child, "name", mrp_property_get_name (property));
+		xmlSetProp_ (child, "name", mrp_property_get_name (property));
 
 		type = mrp_property_get_property_type (property);
-		xmlSetProp (child, "type", mpp_property_type_to_string (type));
+		xmlSetProp_ (child, "type", mpp_property_type_to_string (type));
 
-		xmlSetProp (child, "owner", "task");
-		xmlSetProp (child, "label", mrp_property_get_label (property));
-		xmlSetProp (child, "description", mrp_property_get_description (property));
+		xmlSetProp_ (child, "owner", "task");
+		xmlSetProp_ (child, "label", mrp_property_get_label (property));
+		xmlSetProp_ (child, "description", mrp_property_get_description (property));
 	}
 
 	g_list_free (properties);
@@ -278,16 +294,16 @@ mpp_write_property_specs (MrpParser *parser, xmlNodePtr node)
 	for (l = properties; l; l = l->next) {
 		property = l->data;
 
-		child = xmlNewChild (node, NULL, "property", NULL);
+		child = xmlNewChild_ (node, NULL, "property", NULL);
 
-		xmlSetProp (child, "name", mrp_property_get_name (property));
+		xmlSetProp_ (child, "name", mrp_property_get_name (property));
 
 		type = mrp_property_get_property_type (property);
-		xmlSetProp (child, "type", mpp_property_type_to_string (type));
+		xmlSetProp_ (child, "type", mpp_property_type_to_string (type));
 
-		xmlSetProp (child, "owner", "resource");
-		xmlSetProp (child, "label", mrp_property_get_label (property));
-		xmlSetProp (child, "description", mrp_property_get_description (property));
+		xmlSetProp_ (child, "owner", "resource");
+		xmlSetProp_ (child, "label", mrp_property_get_label (property));
+		xmlSetProp_ (child, "description", mrp_property_get_description (property));
 	}
 
 	g_list_free (properties);
@@ -301,12 +317,12 @@ mpp_write_phases (MrpParser *parser, xmlNodePtr node)
 
 	g_object_get (parser->project, "phases", &phases, NULL);
 
-	node = xmlNewChild (node, NULL, "phases", NULL);
+	node = xmlNewChild_ (node, NULL, "phases", NULL);
 
 	for (l = phases; l; l = l->next) {
-		child = xmlNewChild (node, NULL, "phase", NULL);
+		child = xmlNewChild_ (node, NULL, "phase", NULL);
 
-		xmlSetProp (child, "name", l->data);
+		xmlSetProp_ (child, "name", l->data);
 	}
 
 	mrp_string_list_free (phases);
@@ -321,9 +337,9 @@ mpp_write_predecessor (MrpParser   *parser,
 	NodeEntry *entry;
 	gint       lag;
 
-	node = xmlNewChild (node, NULL, "predecessor", NULL);
+	node = xmlNewChild_ (node, NULL, "predecessor", NULL);
 
-	xmlSetProp (node, "id", "1"); /* Don't need id here. */
+	xmlSetProp_ (node, "id", "1"); /* Don't need id here. */
 
 	entry = g_hash_table_lookup (parser->task_hash,
 				     mrp_relation_get_predecessor (relation));
@@ -346,7 +362,7 @@ mpp_write_predecessor (MrpParser   *parser,
 		str = "FS";
 	}
 
-	xmlSetProp (node, "type", str);
+	xmlSetProp_ (node, "type", str);
 
 	lag = mrp_relation_get_lag (relation);
 	if (lag) {
@@ -383,7 +399,7 @@ mpp_write_constraint (xmlNodePtr node, MrpConstraint *constraint)
 		return;
 	}
 
-	child = xmlNewChild (node, NULL, "constraint", NULL);
+	child = xmlNewChild_ (node, NULL, "constraint", NULL);
 
 	switch (constraint->type) {
 	case MRP_CONSTRAINT_MSO:
@@ -401,7 +417,7 @@ mpp_write_constraint (xmlNodePtr node, MrpConstraint *constraint)
 		break;
 	}
 
-	xmlSetProp (child, "type", str);
+	xmlSetProp_ (child, "type", str);
 	mpp_xml_set_date (child, "time", constraint->time);
 }
 
@@ -423,8 +439,8 @@ mpp_write_string_list (xmlNodePtr   node,
 	for (i = 0; i < array->len; i++) {
 		value = g_array_index (array, GValue *, i);
 
-		child = xmlNewChild (node, NULL, "list-item", NULL);
-		xmlSetProp (child, "value", g_value_get_string (value));
+		child = xmlNewChild_ (node, NULL, "list-item", NULL);
+		xmlSetProp_ (child, "value", g_value_get_string (value));
 	}
 
 	g_array_free (array, TRUE);
@@ -447,21 +463,21 @@ mpp_write_custom_properties (MrpParser  *parser,
 		return;
 	}
 
-	node = xmlNewChild (node, NULL, "properties", NULL);
+	node = xmlNewChild_ (node, NULL, "properties", NULL);
 
 	for (l = properties; l; l = l->next) {
 		property = l->data;
 
-		child = xmlNewChild (node, NULL, "property", NULL);
+		child = xmlNewChild_ (node, NULL, "property", NULL);
 
-		xmlSetProp (child, "name", mrp_property_get_name (property));
+		xmlSetProp_ (child, "name", mrp_property_get_name (property));
 
 		if (mrp_property_get_property_type (property) == MRP_PROPERTY_TYPE_STRING_LIST) {
 			mpp_write_string_list (child, property, object);
 		} else {
 			value = mpp_property_to_string (object, property);
 
-			xmlSetProp (child, "value", value);
+			xmlSetProp_ (child, "value", value);
 
 			g_free (value);
 		}
@@ -498,7 +514,7 @@ mpp_write_task_cb (MrpTask *task, MrpParser *parser)
 	entry = g_hash_table_lookup (parser->task_hash, parent);
 	parent_node = entry->node;
 
-	node = xmlNewChild (parent_node, NULL, "task", NULL);
+	node = xmlNewChild_ (parent_node, NULL, "task", NULL);
 
 	entry = g_hash_table_lookup (parser->task_hash, task);
 	entry->node = node;
@@ -526,8 +542,8 @@ mpp_write_task_cb (MrpTask *task, MrpParser *parser)
 	}
 
 	mpp_xml_set_int (node, "id", entry->id);
-	xmlSetProp (node, "name", name);
-	xmlSetProp (node, "note", note);
+	xmlSetProp_ (node, "name", name);
+	xmlSetProp_ (node, "note", note);
 	mpp_xml_set_int (node, "work", work);
 
 	mpp_xml_set_int (node, "duration", duration);
@@ -548,7 +564,7 @@ mpp_write_task_cb (MrpTask *task, MrpParser *parser)
 
 	predecessors = mrp_task_get_predecessor_relations (task);
 	if (predecessors != NULL) {
-		node = xmlNewChild (node, NULL, "predecessors", NULL);
+		node = xmlNewChild_ (node, NULL, "predecessors", NULL);
 		for (l = predecessors; l; l = l->next) {
 			mpp_write_predecessor (parser, node, l->data);
 		}
@@ -581,7 +597,7 @@ mpp_write_group (MrpParser *parser, xmlNodePtr parent, MrpGroup *group)
 
 	g_return_if_fail (MRP_IS_GROUP (group));
 
-	node = xmlNewChild (parent,
+	node = xmlNewChild_ (parent,
                             NULL,
 			    "group",
 			    NULL);
@@ -598,10 +614,10 @@ mpp_write_group (MrpParser *parser, xmlNodePtr parent, MrpGroup *group)
 		      "manager-email", &admin_email,
 		      NULL);
 
-	xmlSetProp (node, "name", name);
-	xmlSetProp (node, "admin-name", admin_name);
-	xmlSetProp (node, "admin-phone", admin_phone);
-	xmlSetProp (node, "admin-email", admin_email);
+	xmlSetProp_ (node, "name", name);
+	xmlSetProp_ (node, "admin-name", admin_name);
+	xmlSetProp_ (node, "admin-phone", admin_phone);
+	xmlSetProp_ (node, "admin-email", admin_email);
 
 	g_free (name);
 	g_free (admin_name);
@@ -638,7 +654,7 @@ mpp_write_resource (MrpParser   *parser,
 
 	g_return_if_fail (MRP_IS_RESOURCE (resource));
 
-	node = xmlNewChild (parent,
+	node = xmlNewChild_ (parent,
                             NULL,
 			    "resource",
 			    NULL);
@@ -666,15 +682,15 @@ mpp_write_resource (MrpParser   *parser,
 	resource_entry = g_hash_table_lookup (parser->resource_hash, resource);
 	mpp_xml_set_int (node, "id", resource_entry->id);
 
-	xmlSetProp (node, "name", name);
-	xmlSetProp (node, "short-name", short_name);
+	xmlSetProp_ (node, "name", name);
+	xmlSetProp_ (node, "short-name", short_name);
 
 	mpp_xml_set_int (node, "type", type);
 
 	mpp_xml_set_int (node, "units", units);
-	xmlSetProp (node, "email", email);
+	xmlSetProp_ (node, "email", email);
 
-	xmlSetProp (node, "note", note);
+	xmlSetProp_ (node, "note", note);
 
 	mpp_xml_set_float (node, "std-rate", std_rate);
 	/*mpp_xml_set_float (node, "ovt-rate", ovt_rate);*/
@@ -711,7 +727,7 @@ mpp_write_assignment (MrpParser     *parser,
 
 	g_return_if_fail (MRP_IS_ASSIGNMENT (assignment));
 
-	node = xmlNewChild (parent,
+	node = xmlNewChild_ (parent,
                             NULL,
 			    "allocation",
 			    NULL);
@@ -737,16 +753,16 @@ mpp_write_interval (xmlNodePtr parent, MrpInterval *interval)
 	mrptime     start, end;
 	gchar      *str;
 
-	child = xmlNewChild (parent, NULL, "interval", NULL);
+	child = xmlNewChild_ (parent, NULL, "interval", NULL);
 
 	mrp_interval_get_absolute (interval, 0, &start, &end);
 
 	str = mrp_time_format ("%H%M", start);
-	xmlSetProp (child, "start", str);
+	xmlSetProp_ (child, "start", str);
 	g_free (str);
 
 	str = mrp_time_format ("%H%M", end);
-	xmlSetProp (child, "end", str);
+	xmlSetProp_ (child, "end", str);
 	g_free (str);
 }
 
@@ -758,7 +774,7 @@ mpp_write_day (MrpParser *parser, xmlNodePtr parent, MrpDay *day)
 
 	g_return_if_fail (day != NULL);
 
-	node = xmlNewChild (parent, NULL, "day-type", NULL);
+	node = xmlNewChild_ (parent, NULL, "day-type", NULL);
 
 	day_entry = g_new0 (NodeEntry, 1);
 	if (day == mrp_day_get_work ()) {
@@ -776,8 +792,8 @@ mpp_write_day (MrpParser *parser, xmlNodePtr parent, MrpDay *day)
 	g_hash_table_insert (parser->day_hash, day, day_entry);
 
 	mpp_xml_set_int (node, "id", day_entry->id);
-	xmlSetProp (node, "name", mrp_day_get_name (day));
-	xmlSetProp (node, "description", mrp_day_get_description (day));
+	xmlSetProp_ (node, "name", mrp_day_get_name (day));
+	xmlSetProp_ (node, "description", mrp_day_get_description (day));
 }
 
 static void
@@ -811,7 +827,7 @@ mpp_write_overridden_day (MrpParser           *parser,
 
 	entry = g_hash_table_lookup (parser->day_hash, di->day);
 	if (entry) {
-		child = xmlNewChild (parent, NULL, "overridden-day-type", NULL);
+		child = xmlNewChild_ (parent, NULL, "overridden-day-type", NULL);
 		mpp_xml_set_int (child, "id", entry->id);
 
 		for (l = di->intervals; l; l = l->next) {
@@ -833,13 +849,13 @@ mpp_write_overridden_date (MrpParser      *parser,
 
 	entry = g_hash_table_lookup (parser->day_hash, dd->day);
 	if (entry) {
-		child = xmlNewChild (parent, NULL, "day", NULL);
+		child = xmlNewChild_ (parent, NULL, "day", NULL);
 
 		str = mrp_time_format ("%Y%m%d", dd->date);
-		xmlSetProp (child, "date", str);
+		xmlSetProp_ (child, "date", str);
 		g_free (str);
 
-		xmlSetProp (child, "type", "day-type");
+		xmlSetProp_ (child, "type", "day-type");
  		mpp_xml_set_int (child, "id", entry->id);
 	}
 
@@ -857,7 +873,7 @@ mpp_write_calendar (MrpParser   *parser,
 
 	g_return_if_fail (MRP_IS_CALENDAR (calendar));
 
-	node = xmlNewChild (parent, NULL, "calendar", NULL);
+	node = xmlNewChild_ (parent, NULL, "calendar", NULL);
 
 	id = parser->next_calendar_id++;
 	mpp_xml_set_int (node, "id", id);
@@ -866,10 +882,10 @@ mpp_write_calendar (MrpParser   *parser,
 			     calendar,
 			     GINT_TO_POINTER (id));
 
-	xmlSetProp (node, "name", mrp_calendar_get_name (calendar));
+	xmlSetProp_ (node, "name", mrp_calendar_get_name (calendar));
 
 	/* Write the default week */
-	child = xmlNewChild (node, NULL, "default-week", NULL);
+	child = xmlNewChild_ (node, NULL, "default-week", NULL);
 
 	mpp_write_default_day (parser, child, calendar,
 			       "mon", MRP_CALENDAR_DAY_MON);
@@ -887,7 +903,7 @@ mpp_write_calendar (MrpParser   *parser,
 			       "sun", MRP_CALENDAR_DAY_SUN);
 
 	/* Override days */
-	child = xmlNewChild (node, NULL, "overridden-day-types", NULL);
+	child = xmlNewChild_ (node, NULL, "overridden-day-types", NULL);
 	days = mrp_calendar_get_overridden_days (calendar);
 
 	for (l = days; l; l = l->next) {
@@ -898,7 +914,7 @@ mpp_write_calendar (MrpParser   *parser,
 	g_list_free (days);
 
 	/* Write the overriden dates */
-	child = xmlNewChild (node, NULL, "days", NULL);
+	child = xmlNewChild_ (node, NULL, "days", NULL);
 	dates = mrp_calendar_get_all_overridden_dates (calendar);
 	for (l = dates; l; l = l->next) {
 		MrpDateWithDay *date_day = l->data;
@@ -925,7 +941,7 @@ mpp_write_project (MrpParser *parser)
 	NodeEntry   *entry;
 	MrpCalendar *root_calendar;
 
-	node = xmlNewDocNode (parser->doc, NULL, "project", NULL);
+	node = xmlNewDocNode (parser->doc, NULL, (const xmlChar *) "project", NULL);
 	parser->doc->xmlRootNode = node;
 
 	mpp_write_property_specs (parser, node);
@@ -934,8 +950,8 @@ mpp_write_project (MrpParser *parser)
 	mpp_write_phases (parser, node);
 
 	/* Write calendars */
-	calendars_node = xmlNewChild (node, NULL, "calendars", NULL);
-	child = xmlNewChild (calendars_node, NULL, "day-types", NULL);
+	calendars_node = xmlNewChild_ (node, NULL, "calendars", NULL);
+	child = xmlNewChild_ (calendars_node, NULL, "day-types", NULL);
 
 	mpp_write_day (parser, child, mrp_day_get_work ());
 	mpp_write_day (parser, child, mrp_day_get_nonwork ());
@@ -956,7 +972,7 @@ mpp_write_project (MrpParser *parser)
 	mpp_write_project_properties (parser, node);
 
 	/* Write tasks. */
- 	child = xmlNewChild (node, NULL, "tasks",NULL);
+ 	child = xmlNewChild_ (node, NULL, "tasks",NULL);
 
 	entry = g_new0 (NodeEntry, 1);
 	entry->id = 0;
@@ -977,7 +993,7 @@ mpp_write_project (MrpParser *parser)
 				   parser);
 
 	/* Write resource groups. */
- 	child = xmlNewChild (node, NULL, "resource-groups",NULL);
+ 	child = xmlNewChild_ (node, NULL, "resource-groups",NULL);
 	list = mrp_project_get_groups (parser->project);
 
 	/* Generate IDs and hash table. */
@@ -999,7 +1015,7 @@ mpp_write_project (MrpParser *parser)
 	}
 
 	/* Write resources. */
- 	child = xmlNewChild (node, NULL, "resources",NULL);
+ 	child = xmlNewChild_ (node, NULL, "resources",NULL);
 	list = mrp_project_get_resources (parser->project);
 
 	/* Generate IDs and hash table. */
@@ -1017,7 +1033,7 @@ mpp_write_project (MrpParser *parser)
 	}
 
 	/* Write assignments. */
- 	child = xmlNewChild (node, NULL, "allocations", NULL);
+ 	child = xmlNewChild_ (node, NULL, "allocations", NULL);
 
 	for (l = assignments; l; l = l->next) {
 		mpp_write_assignment (parser, child, l->data);
@@ -1051,7 +1067,7 @@ parser_build_xml_doc (MrpStorageMrproject  *module,
 	parser.next_day_type_id = MRP_DAY_NEXT;
 	parser.next_calendar_id = 1;
 
-	parser.doc = xmlNewDoc ("1.0");
+	parser.doc = xmlNewDoc ((const xmlChar *) "1.0");
 
 	if (!mpp_write_project (&parser)) {
 		g_set_error (error,
@@ -1073,7 +1089,7 @@ parser_build_xml_doc (MrpStorageMrproject  *module,
 
 gboolean
 mrp_parser_save (MrpStorageMrproject  *module,
-		 const gchar          *filename,
+		 const gchar          *uri,
 		 gboolean              force,
 		 GError              **error)
 {
@@ -1083,12 +1099,12 @@ mrp_parser_save (MrpStorageMrproject  *module,
 	xmlDocPtr  doc;
 
 	g_return_val_if_fail (MRP_IS_STORAGE_MRPROJECT (module), FALSE);
-	g_return_val_if_fail (filename != NULL && filename[0] != 0, FALSE);
+	g_return_val_if_fail (uri != NULL && uri[0] != 0, FALSE);
 
-	if (!strstr (filename, ".mrproject") && !strstr (filename, ".planner")) {
-		real_filename = g_strconcat (filename, ".planner", NULL);
+	if (!strstr (uri, ".mrproject") && !strstr (uri, ".planner")) {
+		real_filename = g_strconcat (uri, ".planner", NULL);
 	} else {
-		real_filename = g_strdup (filename);
+		real_filename = g_strdup (uri);
 	}
 
 	file_exist = g_file_test (
@@ -1145,7 +1161,7 @@ mrp_parser_to_xml (MrpStorageMrproject  *module,
 	xmlDocDumpFormatMemory (doc, &buf, &len, 1);
 	xmlFreeDoc (doc);
 
-	*str = g_strdup (buf);
+	*str = g_strdup ((const gchar *) buf);
 	xmlFree (buf);
 
 	if (len <= 0) {
@@ -1181,7 +1197,7 @@ mpp_xml_set_date (xmlNodePtr node, const gchar *prop, mrptime time)
 	gchar *str;
 
 	str = mrp_time_to_string (time);
-	xmlSetProp (node, prop, str);
+	xmlSetProp_ (node, prop, str);
 	g_free (str);
 }
 
@@ -1191,7 +1207,7 @@ mpp_xml_set_int (xmlNodePtr node, const gchar *prop, gint value)
 	gchar *str;
 
 	str = g_strdup_printf ("%d", value);
-	xmlSetProp (node, prop, str);
+	xmlSetProp_ (node, prop, str);
 	g_free (str);
 }
 
@@ -1202,7 +1218,7 @@ mpp_xml_set_float (xmlNodePtr node, const gchar *prop, gfloat value)
 	gchar *str;
 
 	str = g_ascii_dtostr (buf, sizeof(buf) - 1, value);
-	xmlSetProp (node, prop, str);
+	xmlSetProp_ (node, prop, str);
 }
 
 static void
@@ -1221,7 +1237,7 @@ mpp_xml_set_task_type (xmlNodePtr node, const gchar *prop, MrpTaskType type)
 		break;
 	}
 
-	xmlSetProp (node, prop, str);
+	xmlSetProp_ (node, prop, str);
 }
 
 static void
@@ -1240,5 +1256,5 @@ mpp_xml_set_task_sched (xmlNodePtr node, const gchar *prop, MrpTaskSched sched)
 		break;
 	}
 
-	xmlSetProp (node, prop, str);
+	xmlSetProp_ (node, prop, str);
 }
