@@ -23,8 +23,7 @@
  * Path generation functions
  */
 
-#ifndef __MRP_PATHS_H__
-#define __MRP_PATHS_H__
+#pragma once
 
 #include <glib.h>
 
@@ -37,5 +36,3 @@ gchar *mrp_paths_get_stylesheet_dir    (const gchar *filename);
 gchar *mrp_paths_get_ui_dir            (const gchar *filename);
 gchar *mrp_paths_get_sql_dir           (void);
 gchar *mrp_paths_get_locale_dir        (void);
-
-#endif /* __MRP_PATHS_H__ */
