@@ -21,8 +21,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __MRP_PRIVATE_H__
-#define __MRP_PRIVATE_H__
+#pragma once
 
 #include <libplanner/mrp-calendar.h>
 #include <libplanner/mrp-task-manager.h>
@@ -145,8 +144,3 @@ void     mrp_application_register_writer      (MrpApplication *app,
 gboolean mrp_application_id_set_data          (gpointer        data,
 						guint           data_id);
 gboolean mrp_application_id_remove_data       (guint           object_id);
-
-
-
-
-#endif /* __MRP_PRIVATE_H__ */
