@@ -18,8 +18,34 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
+
+/**
+ * SECTION:mrp-project
+ * @Short_description: Projects.
+ * @Title: MrpProject
+ * @include: libplanner/mrp-project.h
+ *
+ * A project has got some properties.
+ * One can add custom properties.
+ *
+ * A project maintains a list of #MrpGroup and can designates one as the
+ * default. If you specify a default group, every new #MrpResource that you add
+ * will be placed in this group.
+ *
+ * A project maintains a list of resources.
+ *
+ * A project maintains a list of tasks.
+ * It can iterate over.
+ * Task management is delegated to a private @MrpTaskManager class.
+ *
+ * A project uses a calendar.
+ *
+ * Day types belong to a project.
+ *
+ * A project can define phases and switch from one to another.
  */
 
 #include <config.h>
@@ -175,6 +201,12 @@ project_class_init (MrpProjectClass *klass)
 	object_class->set_property = project_set_property;
 	object_class->get_property = project_get_property;
 
+    /**
+     * MrpProject::loaded:
+     * @project: the object which received the signal.
+     *
+     * emitted when @project is loaded.
+     */
 	signals[LOADED] = g_signal_new
 		("loaded",
 		 G_TYPE_FROM_CLASS (klass),
@@ -184,6 +216,13 @@ project_class_init (MrpProjectClass *klass)
 		 mrp_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 
+    /**
+     * MrpProject::resource-added:
+     * @project: the object which received the signal.
+     * @resource: the added #MrpResource.
+     *
+     * emitted when @resource is added.
+     */
 	signals[RESOURCE_ADDED] = g_signal_new
 		("resource_added",
 		 G_TYPE_FROM_CLASS (klass),
@@ -194,6 +233,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, MRP_TYPE_RESOURCE);
 
+    /**
+     * MrpProject::resource-removed:
+     * @project: the object which received the signal.
+     * @resource: the removed #MrpResource.
+     *
+     * emitted when @resource is removed.
+     */
 	signals[RESOURCE_REMOVED] = g_signal_new
 		("resource_removed",
 		 G_TYPE_FROM_CLASS (klass),
@@ -204,6 +250,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, MRP_TYPE_RESOURCE);
 
+    /**
+     * MrpProject::group-added:
+     * @project: the object which received the signal.
+     * @group: the added #MrpGroup.
+     *
+     * emitted when @group is added.
+     */
 	signals[GROUP_ADDED] = g_signal_new
 		("group_added",
 		 G_TYPE_FROM_CLASS (klass),
@@ -214,6 +267,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, MRP_TYPE_GROUP);
 
+    /**
+     * MrpProject::group-removed:
+     * @project: the object which received the signal.
+     * @group: the removed #MrpGroup.
+     *
+     * emitted when @group is removed.
+     */
 	signals[GROUP_REMOVED] = g_signal_new
 		("group_removed",
 		 G_TYPE_FROM_CLASS (klass),
@@ -224,6 +284,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, MRP_TYPE_GROUP);
 
+    /**
+     * MrpProject::default-group-changed:
+     * @project: the object which received the signal.
+     * @group: the changed #MrpGroup.
+     *
+     * emitted when default @group changes.
+     */
 	signals[DEFAULT_GROUP_CHANGED] = g_signal_new
 		("default_group_changed",
 		 G_TYPE_FROM_CLASS (klass),
@@ -234,6 +301,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, MRP_TYPE_GROUP);
 
+    /**
+     * MrpProject::task-inserted:
+     * @project: the object which received the signal.
+     * @task: the inserted #MrpTask.
+     *
+     * emitted when @task is inserted.
+     */
 	signals[TASK_INSERTED] = g_signal_new
 		("task_inserted",
 		 G_TYPE_FROM_CLASS (klass),
@@ -244,6 +318,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, MRP_TYPE_TASK);
 
+    /**
+     * MrpProject::task-removed:
+     * @project: the object which received the signal.
+     * @task: the removed #MrpTask.
+     *
+     * emitted when @task is removed.
+     */
 	signals[TASK_REMOVED] = g_signal_new
 		("task_removed",
 		 G_TYPE_FROM_CLASS (klass),
@@ -254,6 +335,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, MRP_TYPE_TASK);
 
+    /**
+     * MrpProject::task-moved:
+     * @project: the object which received the signal.
+     * @task: the moved #MrpTask.
+     *
+     * emitted when @task is moved.
+     */
 	signals[TASK_MOVED] = g_signal_new
 		("task_moved",
 		 G_TYPE_FROM_CLASS (klass),
@@ -264,6 +352,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, MRP_TYPE_TASK);
 
+    /**
+     * MrpProject::needs-saving-changed:
+     * @project: the object which received the signal.
+     * @needs_saving: does @project need saving?
+     *
+     * emitted when @project need saving.
+     */
 	signals[NEEDS_SAVING_CHANGED] = g_signal_new
 		("needs_saving_changed",
 		 G_TYPE_FROM_CLASS (klass),
@@ -274,6 +369,14 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, G_TYPE_BOOLEAN);
 
+    /**
+     * MrpProject::property-added:
+     * @project: the object which received the signal.
+     * @object_type: an #MrpPropertyType.
+     * @property: the added #MrpProperty.
+     *
+     * emitted when @property is added.
+     */
 	signals[PROPERTY_ADDED] = g_signal_new
 		("property_added",
 		 G_TYPE_FROM_CLASS (klass),
@@ -284,6 +387,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 2, G_TYPE_LONG, G_TYPE_POINTER);
 
+    /**
+     * MrpProject::property-changed:
+     * @project: the object which received the signal.
+     * @property: the changed #MrpProperty.
+     *
+     * emitted when @property is changed.
+     */
 	signals[PROPERTY_CHANGED] = g_signal_new
 		("property_changed",
 		 G_TYPE_FROM_CLASS (klass),
@@ -294,6 +404,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, G_TYPE_POINTER);
 
+    /**
+     * MrpProject::property-removed:
+     * @project: the object which received the signal.
+     * @property: the removed #MrpProperty.
+     *
+     * emitted when @property is removed.
+     */
 	signals[PROPERTY_REMOVED] = g_signal_new
 		("property_removed",
 		 G_TYPE_FROM_CLASS (klass),
@@ -304,6 +421,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, G_TYPE_POINTER);
 
+    /**
+     * MrpProject::calendar-tree-changed:
+     * @project: the object which received the signal.
+     * @calendar: the changed #MrpCalendar.
+     *
+     * emitted when @calendar is changed.
+     */
 	signals[CALENDAR_TREE_CHANGED] = g_signal_new
 		("calendar_tree_changed",
 		 G_TYPE_FROM_CLASS (klass),
@@ -314,6 +438,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, MRP_TYPE_CALENDAR);
 
+    /**
+     * MrpProject::day-added:
+     * @project: the object which received the signal.
+     * @day: the added #MrpDay.
+     *
+     * emitted when @day is added.
+     */
 	signals[DAY_ADDED] = g_signal_new
 		("day_added",
 		 G_TYPE_FROM_CLASS (klass),
@@ -324,6 +455,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, G_TYPE_POINTER);
 
+    /**
+     * MrpProject::day-removed:
+     * @project: the object which received the signal.
+     * @day: the removed #MrpDay.
+     *
+     * emitted when @day is removed.
+     */
 	signals[DAY_REMOVED] = g_signal_new
 		("day_removed",
 		 G_TYPE_FROM_CLASS (klass),
@@ -334,6 +472,13 @@ project_class_init (MrpProjectClass *klass)
 		 G_TYPE_NONE,
 		 1, G_TYPE_POINTER);
 
+    /**
+     * MrpProject::day-changed:
+     * @project: the object which received the signal.
+     * @day: the changed #MrpDay.
+     *
+     * emitted when @day is changed.
+     */
 	signals[DAY_CHANGED] = g_signal_new
 		("day_changed",
 		 G_TYPE_FROM_CLASS (klass),
@@ -504,7 +649,7 @@ project_set_property (GObject      *object,
 
 	switch (prop_id) {
 	case PROP_PROJECT_START:
-		priv->project_start = g_value_get_long (value);
+		priv->project_start = g_value_get_int64 (value);
 		imrp_project_set_needs_saving (project, TRUE);
 		break;
 
@@ -589,7 +734,7 @@ project_get_property (GObject    *object,
 
 	switch (prop_id) {
 	case PROP_PROJECT_START:
-		g_value_set_long (value, priv->project_start);
+		g_value_set_int64 (value, priv->project_start);
 		break;
 
 	case PROP_ORGANIZATION:
@@ -684,6 +829,7 @@ mrp_project_load (MrpProject *project, const gchar *uri, GError **error)
 	gchar          *file_str;
 	gchar          *scheme;
 	gboolean	is_file_scheme;
+	gchar          *filename;
 
 	g_return_val_if_fail (MRP_IS_PROJECT (project), FALSE);
 	g_return_val_if_fail (uri != NULL, FALSE);
@@ -706,8 +852,7 @@ mrp_project_load (MrpProject *project, const gchar *uri, GError **error)
 		g_free (scheme);
 
 		if (is_file_scheme) {
-			/* Naively strip method. */
-			uri = uri + 7;
+			filename = g_filename_from_uri(uri, NULL, NULL);
 		} else {
 			g_set_error (error,
 				     MRP_ERROR,
@@ -719,13 +864,14 @@ mrp_project_load (MrpProject *project, const gchar *uri, GError **error)
 		}
 	}
 
-	if (!g_file_get_contents (uri, &file_str, NULL, error)) {
+	if (!g_file_get_contents (filename, &file_str, NULL, error)) {
+		g_free (filename);
 		return FALSE;
 	}
 
 	mrp_task_manager_set_block_scheduling (priv->task_manager, TRUE);
 
-	l = imrp_application_get_all_file_readers (priv->app);
+	l = mrp_application_get_all_file_readers (priv->app);
 	for (; l; l = l->next) {
 		MrpFileReader *reader = l->data;
 
@@ -734,7 +880,7 @@ mrp_project_load (MrpProject *project, const gchar *uri, GError **error)
 			imrp_project_set_needs_saving (project, FALSE);
 
 			g_free (priv->uri);
-			priv->uri = g_strdup (uri);
+			priv->uri = filename;
 
 			/* Remove old calendar. */
 			mrp_calendar_remove (old_default_calendar);
@@ -747,7 +893,7 @@ mrp_project_load (MrpProject *project, const gchar *uri, GError **error)
 			return TRUE;
 		}
 	}
-
+	g_free (filename);
 	g_free (file_str);
 
 	mrp_task_manager_set_block_scheduling (priv->task_manager, FALSE);
@@ -931,7 +1077,7 @@ mrp_project_export (MrpProject   *project,
 
 	priv = project->priv;
 
-	l = imrp_application_get_all_file_writers (priv->app);
+	l = mrp_application_get_all_file_writers (priv->app);
 	for (; l; l = l->next) {
 		MrpFileWriter *writer = l->data;
 
@@ -941,7 +1087,7 @@ mrp_project_export (MrpProject   *project,
 		}
 	}
 
-	l = imrp_application_get_all_file_writers (priv->app);
+	l = mrp_application_get_all_file_writers (priv->app);
 	for (; l; l = l->next) {
 		MrpFileWriter *writer = l->data;
 
@@ -989,7 +1135,7 @@ mrp_project_load_from_xml (MrpProject *project, const gchar *str, GError **error
 
 	mrp_task_manager_set_block_scheduling (priv->task_manager, TRUE);
 
-	l = imrp_application_get_all_file_readers (priv->app);
+	l = mrp_application_get_all_file_readers (priv->app);
 	for (; l; l = l->next) {
 		MrpFileReader *reader = l->data;
 
@@ -1441,6 +1587,7 @@ mrp_project_get_uri (MrpProject *project)
 /**
  * mrp_project_set_uri:
  * @project: an #MrpProject
+ * @uri: an URI
  *
  * Sets the URI on @project.
  **/
@@ -1531,6 +1678,7 @@ imrp_project_add_calendar_day (MrpProject *project, MrpDay *day)
 /**
  * mrp_project_get_calendar_day_by_id:
  * @project: an #MrpProject
+ * @id: an id
  *
  * Semi-private function. You most likely won't need this outside of
  * Planner. Returns the day type associated with @id.
@@ -1920,7 +2068,7 @@ mrp_project_reschedule (MrpProject *project)
  * mrp_project_calculate_summary_duration:
  * @project: an #MrpProject
  * @task: an #MrpTask
- * @start: a start time, or if %-1, the task start time is to be used
+ * @start: a start time, or if -1, the task start time is to be used
  * @finish: a finish time
  *
  * Calculates the time needed to achieve the given start and finish time,
@@ -1949,7 +2097,7 @@ mrp_project_calculate_summary_duration (MrpProject *project,
  * mrp_project_calculate_task_work:
  * @project: an #MrpProject
  * @task: an #MrpTask
- * @start: a start time, or if %-1, the task start time is to be used
+ * @start: a start time, or if -1, the task start time is to be used
  * @finish: a finish time
  *
  * Calculates the work needed to achieve the given start and finish time, with
@@ -2139,7 +2287,7 @@ mrp_project_add_property (MrpProject  *project,
 /**
  * mrp_project_remove_property:
  * @project: an #MrpProject
- * @object_type: a #GType specifing object type to remove property from
+ * @object_type: a #GType specifying object type to remove property from
  * @name: the name of the property
  *
  * Removes the property corresponding to @object_type and @name from @project.
@@ -2177,7 +2325,7 @@ mrp_project_remove_property (MrpProject  *project,
 /**
  * mrp_project_has_property:
  * @project: an #MrpProperty
- * @owner_type: a #GType specifing object type look for property on
+ * @owner_type: a #GType specifying object type look for property on
  * @name: the name of the property
  *
  * Checks if @project has a property named @name applying to object of type
@@ -2314,6 +2462,13 @@ project_set_calendar (MrpProject  *project,
 	mrp_task_manager_recalc (priv->task_manager, TRUE);
 }
 
+/**
+ * mrp_project_set_block_scheduling:
+ * @project: an MrpProject.
+ * @block: new value.
+ *
+ * set block scheduling.
+ */
 void
 mrp_project_set_block_scheduling (MrpProject *project, gboolean block)
 {
@@ -2326,6 +2481,13 @@ mrp_project_set_block_scheduling (MrpProject *project, gboolean block)
 	mrp_task_manager_set_block_scheduling (priv->task_manager, block);
 }
 
+/**
+ * mrp_project_get_block_scheduling:
+ * @project: an MrpProject.
+ * @Returns: a boolean
+ *
+ * get block scheduling.
+ */
 gboolean
 mrp_project_get_block_scheduling (MrpProject *project)
 {
