@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __MRP_SQL_H__
-#define __MRP_SQL_H__
+#pragma once
 
 #include "mrp-storage-sql.h"
 
@@ -45,6 +44,3 @@ gboolean mrp_sql_save_project (MrpStorageSQL  *storage,
 			       const gchar    *password,
 			       gint           *project_id,
 			       GError        **error);
-
-
-#endif /* __MRP_SQL_H__ */
