@@ -33,8 +33,13 @@
 #include "mrp-private.h"
 #include "mrp-time.h"
 #include "mrp-error.h"
+#include <libplanner/mrp-relation.h>
 
-struct _MrpTaskManagerPriv {
+struct _MrpTaskManager {
+	GObject parent_instance;
+};
+
+typedef struct {
 	MrpProject *project;
 	MrpTask    *root;
 
@@ -48,7 +53,9 @@ struct _MrpTaskManagerPriv {
 	gboolean    in_recalc;
 
 	GList      *dependency_list;
-};
+} MrpTaskManagerPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (MrpTaskManager, mrp_task_manager, G_TYPE_OBJECT)
 
 typedef struct {
 	MrpTaskTraverseFunc func;
@@ -61,17 +68,6 @@ enum {
 	PROP_PROJECT,
 };
 
-static void task_manager_class_init       (MrpTaskManagerClass *klass);
-static void task_manager_init             (MrpTaskManager      *tm);
-static void task_manager_finalize         (GObject             *object);
-static void task_manager_set_property     (GObject             *object,
-					   guint                prop_id,
-					   const GValue        *value,
-					   GParamSpec          *pspec);
-static void task_manager_get_property     (GObject             *object,
-					   guint                prop_id,
-					   GValue              *value,
-					   GParamSpec          *pspec);
 static void
 task_manager_task_duration_notify_cb      (MrpTask             *task,
 					   GParamSpec          *spec,
@@ -119,8 +115,6 @@ static void
 task_manager_dump_task_tree               (GNode               *node);
 
 
-static GObjectClass *parent_class;
-
 static mrptime
 task_manager_calculate_task_start_from_finish (MrpTaskManager *manager,
 						MrpTask        *task,
@@ -128,93 +122,25 @@ task_manager_calculate_task_start_from_finish (MrpTaskManager *manager,
 						gint           *duration);
 
 
-GType
-mrp_task_manager_get_type (void)
-{
-	static GType object_type = 0;
-
-	if (!object_type) {
-		static const GTypeInfo object_info = {
-			sizeof (MrpTaskManagerClass),
-			NULL,		/* base_init */
-			NULL,		/* base_finalize */
-			(GClassInitFunc) task_manager_class_init,
-			NULL,		/* class_finalize */
-			NULL,		/* class_data */
-			sizeof (MrpTaskManager),
-			0,              /* n_preallocs */
-			(GInstanceInitFunc) task_manager_init,
-		};
-
-		object_type = g_type_register_static (G_TYPE_OBJECT,
-						      "MrpTaskManager",
-						      &object_info,
-						      0);
-	}
-
-	return object_type;
-}
-
 static void
-task_manager_class_init (MrpTaskManagerClass *klass)
-{
-	GObjectClass *object_class = (GObjectClass *) klass;
-
-	parent_class = g_type_class_peek_parent (klass);
-
-	object_class->finalize     = task_manager_finalize;
-	object_class->set_property = task_manager_set_property;
-	object_class->get_property = task_manager_get_property;
-
-	/* Properties. */
-	g_object_class_install_property (
-		object_class,
-		PROP_PROJECT,
-		g_param_spec_object ("project",
-				     "Project",
-				     "The project that this task manager is attached to",
-				     G_TYPE_OBJECT,
-				     G_PARAM_READWRITE |
-				     G_PARAM_CONSTRUCT_ONLY));
-}
-
-static void
-task_manager_init (MrpTaskManager *man)
-{
-	MrpTaskManagerPriv *priv;
-
-	man->priv = g_new0 (MrpTaskManagerPriv, 1);
-	priv = man->priv;
-
-	priv->needs_recalc = TRUE;
-	priv->needs_rebuild = TRUE;
-}
-
-static void
-task_manager_finalize (GObject *object)
+mrp_task_manager_finalize (GObject *object)
 {
 	MrpTaskManager *manager = MRP_TASK_MANAGER (object);
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 
-	g_object_unref (manager->priv->root);
+	g_object_unref (priv->root);
 
-	g_free (manager->priv);
-
-	if (G_OBJECT_CLASS (parent_class)->finalize) {
-		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
-	}
+	G_OBJECT_CLASS (mrp_task_manager_parent_class)->finalize (object);
 }
 
 static void
-task_manager_set_property (GObject      *object,
-			   guint         prop_id,
-			   const GValue *value,
-			   GParamSpec   *pspec)
+mrp_task_manager_set_property (GObject      *object,
+                               guint         prop_id,
+                               const GValue *value,
+                               GParamSpec   *pspec)
 {
-	MrpTaskManager     *manager;
-	MrpTaskManagerPriv *priv;
-
-	manager = MRP_TASK_MANAGER (object);
-	priv = manager->priv;
+	MrpTaskManager *manager = MRP_TASK_MANAGER (object);
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 
 	switch (prop_id) {
 	case PROP_PROJECT:
@@ -233,18 +159,17 @@ task_manager_set_property (GObject      *object,
 }
 
 static void
-task_manager_get_property (GObject    *object,
-			   guint       prop_id,
-			   GValue     *value,
-			   GParamSpec *pspec)
+mrp_task_manager_get_property (GObject    *object,
+                               guint       prop_id,
+                               GValue     *value,
+                               GParamSpec *pspec)
 {
-	MrpTaskManager *manager;
-
-	manager = MRP_TASK_MANAGER (object);
+	MrpTaskManager *manager = MRP_TASK_MANAGER (object);
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 
 	switch (prop_id) {
 	case PROP_PROJECT:
-		g_value_set_object (value, manager->priv->project);
+		g_value_set_object (value, priv->project);
 		break;
 
 	default:
@@ -253,6 +178,36 @@ task_manager_get_property (GObject    *object,
 	}
 }
 
+static void
+mrp_task_manager_class_init (MrpTaskManagerClass *klass)
+{
+	GObjectClass *object_class = (GObjectClass *) klass;
+
+	object_class->finalize     = mrp_task_manager_finalize;
+	object_class->set_property = mrp_task_manager_set_property;
+	object_class->get_property = mrp_task_manager_get_property;
+
+	/* Properties. */
+	g_object_class_install_property (
+		object_class,
+		PROP_PROJECT,
+		g_param_spec_object ("project",
+				     "Project",
+				     "The project that this task manager is attached to",
+				     G_TYPE_OBJECT,
+				     G_PARAM_READWRITE |
+				     G_PARAM_CONSTRUCT_ONLY));
+}
+
+static void
+mrp_task_manager_init (MrpTaskManager *man)
+{
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (man);
+
+	priv->needs_recalc = TRUE;
+	priv->needs_rebuild = TRUE;
+}
+
 MrpTaskManager *
 mrp_task_manager_new (MrpProject *project)
 {
@@ -319,26 +274,28 @@ mrp_task_manager_insert_task (MrpTaskManager *manager,
 			      gint            position,
 			      MrpTask        *task)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
+
 	g_return_if_fail (MRP_IS_TASK_MANAGER (manager));
 	g_return_if_fail (parent == NULL || MRP_IS_TASK (parent));
 	g_return_if_fail (MRP_IS_TASK (task));
 
 	if (parent == NULL) {
-		parent = manager->priv->root;
+		parent = priv->root;
 	}
 
 	g_object_set (task,
-		      "project", manager->priv->project,
+		      "project", priv->project,
 		      NULL);
 
 	imrp_task_insert_child (parent, position, task);
 
 	/* FIXME: implement adding the task to the dependency graph instead. */
-	manager->priv->needs_rebuild = TRUE;
+	priv->needs_rebuild = TRUE;
 
-	manager->priv->needs_recalc = TRUE;
+	priv->needs_recalc = TRUE;
 
-	imrp_project_task_inserted (manager->priv->project, task);
+	imrp_project_task_inserted (priv->project, task);
 
 	mrp_task_manager_recalc (manager, TRUE);
 
@@ -358,10 +315,12 @@ void
 mrp_task_manager_remove_task (MrpTaskManager *manager,
 			      MrpTask        *task)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
+
 	g_return_if_fail (MRP_IS_TASK_MANAGER (manager));
 	g_return_if_fail (MRP_IS_TASK (task));
 
-	if (task == manager->priv->root) {
+	if (task == priv->root) {
 		g_warning ("Can't remove root task");
 		return;
 	}
@@ -372,7 +331,7 @@ mrp_task_manager_remove_task (MrpTaskManager *manager,
 
 	imrp_task_remove_subtree (task);
 
-	manager->priv->needs_rebuild = TRUE;
+	priv->needs_rebuild = TRUE;
 	mrp_task_manager_recalc (manager, FALSE);
 }
 
@@ -398,17 +357,18 @@ task_manager_get_all_tasks_cb (GNode *node, GList **list)
 GList *
 mrp_task_manager_get_all_tasks (MrpTaskManager *manager)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	GList   *tasks;
 
 	g_return_val_if_fail (MRP_IS_TASK_MANAGER (manager), NULL);
 
-	if (manager->priv->root == NULL) {
+	if (priv->root == NULL) {
 		return NULL;
 	}
 
 	tasks = NULL;
 
-	g_node_traverse (imrp_task_get_node (manager->priv->root),
+	g_node_traverse (imrp_task_get_node (priv->root),
 			 G_PRE_ORDER,
 			 G_TRAVERSE_ALL,
 			 -1,
@@ -462,19 +422,20 @@ void
 mrp_task_manager_set_root (MrpTaskManager *manager,
 			   MrpTask        *task)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	GList      *tasks, *l;
 	MrpProject *project;
 
 	g_return_if_fail (MRP_IS_TASK_MANAGER (manager));
 	g_return_if_fail (task == NULL || MRP_IS_TASK (task));
 
-	if (manager->priv->root != NULL) {
-		imrp_task_remove_subtree (manager->priv->root);
+	if (priv->root != NULL) {
+		imrp_task_remove_subtree (priv->root);
 	}
 
-	manager->priv->root = task;
+	priv->root = task;
 
-	project = manager->priv->project;
+	project = priv->project;
 
 	tasks = mrp_task_manager_get_all_tasks (manager);
 	for (l = tasks; l; l = l->next) {
@@ -495,9 +456,11 @@ mrp_task_manager_set_root (MrpTaskManager *manager,
 MrpTask *
 mrp_task_manager_get_root (MrpTaskManager *manager)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
+
 	g_return_val_if_fail (MRP_IS_TASK_MANAGER (manager), NULL);
 
-	return manager->priv->root;
+	return priv->root;
 }
 
 gboolean
@@ -508,6 +471,7 @@ mrp_task_manager_move_task (MrpTaskManager  *manager,
 			    gboolean         before,
 			    GError         **error)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	MrpTask *old_parent;
 
 	g_return_val_if_fail (MRP_IS_TASK_MANAGER (manager), FALSE);
@@ -532,7 +496,7 @@ mrp_task_manager_move_task (MrpTaskManager  *manager,
 
 	mrp_task_manager_rebuild (manager);
 
-	imrp_project_task_moved (manager->priv->project, task);
+	imrp_project_task_moved (priv->project, task);
 
 	mrp_task_manager_recalc (manager, FALSE);
 
@@ -638,20 +602,23 @@ task_manager_dump_task_tree (GNode *node)
 void
 mrp_task_manager_dump_task_tree (MrpTaskManager *manager)
 {
-	g_return_if_fail (MRP_IS_TASK_MANAGER (manager));
-	g_return_if_fail (manager->priv->root);
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 
-	task_manager_dump_task_tree (imrp_task_get_node (manager->priv->root));
+	g_return_if_fail (MRP_IS_TASK_MANAGER (manager));
+	g_return_if_fail (priv->root);
+
+	task_manager_dump_task_tree (imrp_task_get_node (priv->root));
 }
 
 void
 mrp_task_manager_dump_task_list (MrpTaskManager *manager)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	GList       *list, *l;
 	const gchar *name;
 
 	g_return_if_fail (MRP_IS_TASK_MANAGER (manager));
-	g_return_if_fail (manager->priv->root);
+	g_return_if_fail (priv->root);
 
 	g_print ("All tasks: ");
 	list = mrp_task_manager_get_all_tasks (manager);
@@ -997,13 +964,11 @@ remove_task_from_dependency_graph (MrpTaskManager *manager,
 				   MrpTask        *task,
 				   MrpTask        *parent)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	GList              *list, *l;
 	MrpRelation        *relation;
 	MrpTask            *predecessor;
 
-	priv = manager->priv;
-
 	/* Remove predecessors. */
 	list = imrp_task_peek_predecessors (task);
 	for (l = list; l; l = l->next) {
@@ -1024,13 +989,11 @@ add_task_to_dependency_graph (MrpTaskManager *manager,
 			      MrpTask        *task,
 			      MrpTask        *parent)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	GList              *list, *l;
 	MrpRelation        *relation;
 	MrpTask            *predecessor;
 
-	priv = manager->priv;
-
 	if (task == priv->root) {
 		return;
 	}
@@ -1081,7 +1044,7 @@ task_manager_clean_graph_func (MrpTask  *task,
 static void
 task_manager_build_dependency_graph (MrpTaskManager *manager)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	GList              *tasks;
 	GList              *l;
 	GList              *deps;
@@ -1089,8 +1052,6 @@ task_manager_build_dependency_graph (MrpTaskManager *manager)
 	MrpTaskGraphNode   *node;
 	GList              *queue;
 
-	priv = manager->priv;
-
 	/* Build a directed, acyclic graph, where relation links and children ->
 	 * parent are graph links (children must be calculated before
 	 * parents). Then do topological sorting on the graph to get the order
@@ -1167,8 +1128,8 @@ task_manager_build_dependency_graph (MrpTaskManager *manager)
 				   task_manager_unset_visited_func,
 				   NULL);
 
-	manager->priv->needs_rebuild = FALSE;
-	manager->priv->needs_recalc = TRUE;
+	priv->needs_rebuild = FALSE;
+	priv->needs_recalc = TRUE;
 }
 
 /* Calculate the start time of the task by finding the latest finish of it's
@@ -1179,7 +1140,7 @@ task_manager_calculate_task_start (MrpTaskManager *manager,
 				   MrpTask        *task,
 				   gint           *duration)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	MrpTask            *tmp_task;
 	GList              *predecessors, *l;
 	MrpRelation        *relation;
@@ -1191,8 +1152,6 @@ task_manager_calculate_task_start (MrpTaskManager *manager,
 	mrptime             dep_start;
 	MrpConstraint       constraint;
 
-	priv = manager->priv;
-
 	project_start = mrp_project_get_project_start (priv->project);
 	start = project_start;
 
@@ -1339,7 +1298,7 @@ task_manager_get_task_units_intervals (MrpTaskManager *manager,
 				       MrpTask        *task,
 				       mrptime         date)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	MrpCalendar        *calendar;
 	MrpDay             *day;
 	GList              *ivals, *l;
@@ -1377,8 +1336,6 @@ task_manager_get_task_units_intervals (MrpTaskManager *manager,
 	mrptime             i_start_post, i_end_post, i_start_cmp, i_end_cmp;
 #endif
 
-	priv = manager->priv;
-
 	assignments = mrp_task_get_assignments (task);
 
 	array = g_ptr_array_new ();
@@ -1737,7 +1694,7 @@ task_manager_calculate_task_finish (MrpTaskManager *manager,
 				    mrptime         start,
 				    gint           *duration)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	mrptime             finish;
 	mrptime             t;
 	mrptime             t1, t2;
@@ -1750,8 +1707,6 @@ task_manager_calculate_task_finish (MrpTaskManager *manager,
 	MrpTaskType         type;
 	MrpTaskSched        sched;
 
-	priv = manager->priv;
-
 	if (task == priv->root) {
 		g_warning ("Tried to get duration of root task.");
 		return 0;
@@ -1900,7 +1855,7 @@ task_manager_calculate_task_start_from_finish (MrpTaskManager *manager,
 				    mrptime         finish,
 				    gint           *duration)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	mrptime             start;
 	mrptime             t;
 	mrptime             t1, t2;
@@ -1914,8 +1869,6 @@ task_manager_calculate_task_start_from_finish (MrpTaskManager *manager,
 	MrpTaskType         type;
 	MrpTaskSched        sched;
 
-	priv = manager->priv;
-
 	if (task == priv->root) {
 		g_warning ("Tried to get duration of root task.");
 		return 0;
@@ -2162,11 +2115,9 @@ static void
 task_manager_do_forward_pass (MrpTaskManager *manager,
 			      MrpTask        *start_task)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	GList              *l;
 
-	priv = manager->priv;
-
 	/* Do forward pass, start at the task and do all tasks that come after
 	 * it in the dependency list. Note: we could try to skip tasks that are
 	 * not dependent, but I don't think that's really worth it.
@@ -2192,7 +2143,7 @@ task_manager_do_forward_pass (MrpTaskManager *manager,
 static void
 task_manager_do_backward_pass (MrpTaskManager *manager)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	GList              *tasks, *l;
 	GList              *successors, *s;
 	mrptime             project_finish;
@@ -2201,8 +2152,6 @@ task_manager_do_backward_pass (MrpTaskManager *manager)
 	gboolean            critical;
 	gboolean            was_critical;
 
-	priv = manager->priv;
-
 	project_finish = mrp_task_get_finish (priv->root);
 
 	tasks = g_list_reverse (g_list_copy (priv->dependency_list));
@@ -2287,12 +2236,10 @@ task_manager_do_backward_pass (MrpTaskManager *manager)
 void
 mrp_task_manager_set_block_scheduling (MrpTaskManager *manager, gboolean block)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 
 	g_return_if_fail (MRP_IS_TASK_MANAGER (manager));
 
-	priv = manager->priv;
-
 	if (priv->block_scheduling == block) {
 		return;
 	}
@@ -2307,20 +2254,20 @@ mrp_task_manager_set_block_scheduling (MrpTaskManager *manager, gboolean block)
 gboolean
 mrp_task_manager_get_block_scheduling (MrpTaskManager *manager)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
+
 	g_return_val_if_fail (MRP_IS_TASK_MANAGER (manager), FALSE);
 
-	return manager->priv->block_scheduling;
+	return priv->block_scheduling;
 }
 
 void
 mrp_task_manager_rebuild (MrpTaskManager *manager)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 
 	g_return_if_fail (MRP_IS_TASK_MANAGER (manager));
-	g_return_if_fail (manager->priv->root != NULL);
-
-	priv = manager->priv;
+	g_return_if_fail (priv->root != NULL);
 
 	if (priv->block_scheduling) {
 		return;
@@ -2336,13 +2283,11 @@ void
 mrp_task_manager_recalc (MrpTaskManager *manager,
 			 gboolean        force)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	MrpProject         *project;
 
 	g_return_if_fail (MRP_IS_TASK_MANAGER (manager));
-	g_return_if_fail (manager->priv->root != NULL);
-
-	priv = manager->priv;
+	g_return_if_fail (priv->root != NULL);
 
 	if (priv->block_scheduling) {
 		return;
@@ -2438,6 +2383,8 @@ task_manager_task_relation_added_cb (MrpTask        *task,
 				     MrpRelation    *relation,
 				     MrpTaskManager *manager)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
+
 	/* We get a signal on both the predecessor and the successor, it's
 	 * enough with one rebuild.
 	 */
@@ -2450,7 +2397,7 @@ task_manager_task_relation_added_cb (MrpTask        *task,
 				 G_CALLBACK (task_manager_task_relation_notify_cb),
 				 manager, 0);
 
-	manager->priv->needs_rebuild = TRUE;
+	priv->needs_rebuild = TRUE;
 	mrp_task_manager_recalc (manager, FALSE);
 }
 
@@ -2459,6 +2406,8 @@ task_manager_task_relation_removed_cb (MrpTask        *task,
 				       MrpRelation    *relation,
 				       MrpTaskManager *manager)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
+
 	/* We get a signal on both the predecessor and the successor, it's
 	 * enough with one rebuild.
 	 */
@@ -2470,7 +2419,7 @@ task_manager_task_relation_removed_cb (MrpTask        *task,
 					      task_manager_task_relation_notify_cb,
 					      manager);
 
-	manager->priv->needs_rebuild = TRUE;
+	priv->needs_rebuild = TRUE;
 	mrp_task_manager_recalc (manager, FALSE);
 }
 
@@ -2479,12 +2428,14 @@ task_manager_task_assignment_added_cb (MrpTask        *task,
 				       MrpAssignment  *assignment,
 				       MrpTaskManager *manager)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
+
 	g_signal_connect_object (assignment, "notify::units",
 				 G_CALLBACK (task_manager_assignment_units_notify_cb),
 				 manager, 0);
 
 	mrp_task_invalidate_cost (task);
-	manager->priv->needs_rebuild = TRUE;
+	priv->needs_rebuild = TRUE;
 	mrp_task_manager_recalc (manager, FALSE);
 }
 
@@ -2493,12 +2444,14 @@ task_manager_task_assignment_removed_cb (MrpTask        *task,
 					 MrpAssignment  *assignment,
 					 MrpTaskManager *manager)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
+
 	g_signal_handlers_disconnect_by_func (assignment,
 					      task_manager_assignment_units_notify_cb,
 					      manager);
 
 	mrp_task_invalidate_cost (task);
-	manager->priv->needs_rebuild = TRUE;
+	priv->needs_rebuild = TRUE;
 	mrp_task_manager_recalc (manager, FALSE);
 }
 
@@ -2567,13 +2520,14 @@ mrp_task_manager_check_predecessor (MrpTaskManager  *manager,
 				    MrpTask         *predecessor,
 				    GError         **error)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	gboolean retval;
 
 	g_return_val_if_fail (MRP_IS_TASK_MANAGER (manager), FALSE);
 	g_return_val_if_fail (MRP_IS_TASK (task), FALSE);
 	g_return_val_if_fail (MRP_IS_TASK (predecessor), FALSE);
 
-	if (manager->priv->needs_rebuild) {
+	if (priv->needs_rebuild) {
 		mrp_task_manager_rebuild (manager);
 	}
 
@@ -2587,7 +2541,7 @@ mrp_task_manager_check_predecessor (MrpTaskManager  *manager,
 	}
 
 	mrp_task_manager_traverse (manager,
-				   manager->priv->root,
+				   priv->root,
 				   task_manager_unset_visited_func,
 				   NULL);
 
@@ -2613,6 +2567,7 @@ mrp_task_manager_check_move (MrpTaskManager  *manager,
 			     MrpTask         *parent,
 			     GError         **error)
 {
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	gboolean retval;
 
 	g_return_val_if_fail (MRP_IS_TASK_MANAGER (manager), FALSE);
@@ -2630,7 +2585,7 @@ mrp_task_manager_check_move (MrpTaskManager  *manager,
 	}
 
 	mrp_task_manager_traverse (manager,
-				   manager->priv->root,
+				   priv->root,
 				   task_manager_unset_visited_func,
 				   NULL);
 
@@ -2783,13 +2738,11 @@ mrp_task_manager_calculate_task_work (MrpTaskManager *manager,
 				      mrptime         start,
 				      mrptime         finish)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	gint                work = 0;
 	GList              *assignments;
 	MrpCalendar        *calendar;
 
-	priv = manager->priv;
-
 	if (task == priv->root) {
 		return 0;
 	}
@@ -2838,7 +2791,7 @@ mrp_task_manager_calculate_summary_duration (MrpTaskManager *manager,
 				      mrptime         start,
 				      mrptime         finish)
 {
-	MrpTaskManagerPriv *priv;
+	MrpTaskManagerPrivate *priv = mrp_task_manager_get_instance_private (manager);
 	mrptime             t;
 	mrptime             t1, t2;
 	gint                duration = 0;
@@ -2847,8 +2800,6 @@ mrp_task_manager_calculate_summary_duration (MrpTaskManager *manager,
 	GList              *ivals, *l;
 	MrpInterval        *ival;
 
-	priv = manager->priv;
-
 	if (task == priv->root) {
 		return 0;
 	}
