@@ -22,8 +22,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __MRP_TIME_H__
-#define __MRP_TIME_H__
+#pragma once
 
 #include <time.h>
 #include <glib.h>
@@ -113,5 +112,3 @@ GParamSpec * mrp_param_spec_time         (const gchar  *name,
 					  const gchar  *nick,
 					  const gchar  *blurb,
 					  GParamFlags   flags);
-
-#endif /* __MRP_TIME_H__ */
