@@ -45,11 +45,6 @@ static gboolean html_write               (MrpFileWriter   *writer,
 					  const gchar     *uri,
 					  gboolean         force,
 					  GError         **error);
-static gboolean xml_planner_pre012_write (MrpFileWriter   *writer,
-					  MrpProject      *project,
-					  const gchar     *uri,
-					  gboolean         force,
-					  GError         **error);
 
 
 static void xslt_module_gettext		(xmlXPathParserContextPtr ctxt,
@@ -166,54 +161,6 @@ html_write (MrpFileWriter  *writer,
 	return ret;
 }
 
-static gboolean
-xml_planner_pre012_write (MrpFileWriter  *writer,
-			  MrpProject     *project,
-			  const gchar    *uri,
-			  gboolean        force,
-			  GError        **error)
-{
-        gchar          *xml_project;
-        xsltStylesheet *stylesheet;
-        xmlDoc         *doc;
-        xmlDoc         *final_doc;
-	gboolean        ret;
-        gchar          *filename;
-
-	if (!mrp_project_save_to_xml (project, &xml_project, error)) {
-		return FALSE;
-	}
-
-        /* libxml housekeeping */
-        xmlSubstituteEntitiesDefault(1);
-        xmlLoadExtDtdDefaultValue = 1;
-        exsltRegisterAll ();
-
-	filename = mrp_paths_get_stylesheet_dir ("planner2plannerv011.xsl");
-        stylesheet = xsltParseStylesheetFile ((const xmlChar *) filename);
-	g_free (filename);
-
-        doc = xmlParseMemory (xml_project, strlen (xml_project));
-        final_doc = xsltApplyStylesheet (stylesheet, doc, NULL);
-        xmlFree (doc);
-
-	ret = TRUE;
-
-	if (!final_doc ||
-	    xsltSaveResultToFilename (uri, final_doc, stylesheet, 0) == -1) {
-		g_set_error (error,
-			     MRP_ERROR,
-			     MRP_ERROR_EXPORT_FAILED,
-			     _("Export to HTML failed"));
-		ret = FALSE;
-	}
-
-	xsltFreeStylesheet (stylesheet);
-        xmlFree (final_doc);
-
-	return ret;
-}
-
 G_MODULE_EXPORT void
 init (MrpFileModule *module, MrpApplication *application)
 {
@@ -231,18 +178,5 @@ init (MrpFileModule *module, MrpApplication *application)
         writer->write      = html_write;
 
         mrp_application_register_writer (application, writer);
-
-	/* The older Planner/Mrproject writer registration */
-
-	writer             = g_new0 (MrpFileWriter, 1);
-
-	writer->module     = module;
-	writer->identifier = "Planner XML pre-0.12";  /* Don't change unless you change plugin to match */
-	writer->mime_type  = "text/xml";
-        writer->priv       = NULL;
-
-        writer->write      = xml_planner_pre012_write;
-
-        mrp_application_register_writer (application, writer);
 }
 
