@@ -31,9 +31,7 @@
  * Author: Maurice van der Pot <griffon26@kfk4ever.com>
  */
 
-#ifndef GNOME_CANVAS_DUMMY_H
-#define GNOME_CANVAS_DUMMY_H
-
+#pragma once
 
 #include <libgnomecanvas/gnome-canvas.h>
 
@@ -82,5 +80,3 @@ GType gnome_canvas_dummy_get_type (void) G_GNUC_CONST;
 
 
 G_END_DECLS
-
-#endif
