@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_CALENDAR_SELECTOR_H__
-#define __PLANNER_CALENDAR_SELECTOR_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libplanner/mrp-project.h>
@@ -32,14 +31,3 @@ GtkWidget *  planner_calendar_selector_new          (PlannerWindow *window,
 
 
 MrpCalendar *planner_calendar_selector_get_calendar (GtkWidget    *dialog);
-
-#endif /* __PLANNER_CALENDAR_SELECTOR_H__ */
-
-
-
-
-
-
-
-
-
