@@ -18,8 +18,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_CMD_MANAGER_H__
-#define __PLANNER_CMD_MANAGER_H__
+#pragma once
 
 #include <glib-object.h>
 
@@ -85,9 +84,3 @@ PlannerCmd *       planner_cmd_new_size                  (gsize               si
 							  PlannerCmdFreeFunc  free_func);
 
 #define planner_cmd_new(t,l,d,u,f) planner_cmd_new_size(sizeof(t),l,d,u,f)
-
-
-#endif /* __PLANNER_CMD_MANAGER_H__ */
-
-
-
