@@ -18,13 +18,10 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_COLUMN_DIALOG_H__
-#define __PLANNER_COLUMN_DIALOG_H__
+#pragma once
 
 #include "planner-window.h"
 
 void planner_column_dialog_show (PlannerWindow *window,
 				 const gchar   *title,
 				 GtkTreeView   *edited_tree);
-
-#endif /* __PLANNER_COLUMN_DIALOG_H__ */
