@@ -20,22 +20,10 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_DAY_TYPE_DIALOG_H__
-#define __PLANNER_DAY_TYPE_DIALOG_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libplanner/mrp-project.h>
 #include "planner-window.h"
 
 GtkWidget * planner_day_type_dialog_new (PlannerWindow *window);
-
-#endif /* __PLANNER_DAY_TYPE_DIALOG_H__ */
-
-
-
-
-
-
-
-
-
