@@ -17,17 +17,17 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
 #include <glib/gi18n.h>
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <libplanner/mrp-project.h>
 #include "libplanner/mrp-paths.h"
 #include "planner-default-week-dialog.h"
+#include "planner-util.h"
 
 #define RESPONSE_ADD    1
 #define RESPONSE_REMOVE 2
@@ -61,8 +61,8 @@ typedef struct {
 	MrpCalendar   *calendar;
 
 	GtkWidget     *dialog;
-	GtkWidget     *weekday_option_menu;
-	GtkWidget     *day_option_menu;
+	GtkWidget     *weekday_combobox;
+	GtkWidget     *daytype_combobox;
 
 	GtkWidget     *from_label[5];
 	GtkWidget     *to_label[5];
@@ -93,14 +93,14 @@ static void        default_week_dialog_response_cb               (GtkWidget
 								  gint           response,
 								  DialogData    *data);
 static void        default_week_dialog_update_labels             (DialogData    *data);
-static void        default_week_dialog_weekday_selected_cb       (GtkOptionMenu *option_menu,
+static void        default_week_dialog_weekday_selected_cb       (GtkComboBoxText *combotext,
 								  DialogData    *data);
-static void        default_week_dialog_day_selected_cb           (GtkOptionMenu *option_menu,
+static void        default_week_dialog_day_selected_cb           (GtkComboBox   *combo,
 								  DialogData    *data);
-static void        default_week_dialog_setup_day_option_menu     (GtkOptionMenu *option_menu,
+static void        default_week_dialog_setup_daytype_combobox    (GtkComboBox   *combo,
 								  MrpProject    *project,
 								  MrpCalendar   *calendar);
-static void        default_week_dialog_setup_weekday_option_menu (GtkOptionMenu *option_menu);
+static void        default_week_dialog_setup_weekday_combobox    (GtkComboBoxText *combotext);
 static gint        default_week_dialog_get_selected_weekday      (DialogData    *data);
 static MrpDay *    default_week_dialog_get_selected_day          (DialogData    *data);
 static void        default_week_dialog_set_selected_day          (DialogData    *data,
@@ -149,32 +149,39 @@ default_week_dialog_parent_destroy_cb (GtkWidget *window, GtkWidget *dialog)
 	gtk_widget_destroy (dialog);
 }
 
+static void
+daytype_combo_name_and_sensitive (GtkCellLayout   *layout,
+                                  GtkCellRenderer *cell,
+                                  GtkTreeModel    *model,
+                                  GtkTreeIter     *iter,
+                                  gpointer         user_data)
+{
+	MrpDay      *day;
+	gboolean     sensitive;
+
+	gtk_tree_model_get (model, iter, 0, &day, 1, &sensitive, -1);
+	g_object_set (cell,
+		      "text", mrp_day_get_name (day),
+		      "sensitive", sensitive,
+		      NULL);
+}
+
 GtkWidget *
 planner_default_week_dialog_new (PlannerWindow *window,
 				 MrpCalendar  *calendar)
 {
 	DialogData *data;
-	GladeXML   *glade;
+	GtkBuilder *builder;
 	GtkWidget  *dialog;
 	GtkWidget  *w;
 	gint        i;
-	gchar	   *filename;
+	GtkCellRenderer *renderer;
 
 	g_return_val_if_fail (PLANNER_IS_WINDOW (window), NULL);
 
-	filename = mrp_paths_get_glade_dir ("calendar-dialog.glade");
-	glade = glade_xml_new (filename ,
-			       "default_week_dialog",
-			       GETTEXT_PACKAGE);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/ui/default-week-dialog.ui");
 
-	g_free (filename);
-
-	if (!glade) {
-		g_warning ("Could not create default_week dialog.");
-		return NULL;
-	}
-
-	dialog = glade_xml_get_widget (glade, "default_week_dialog");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "default_week_dialog"));
 
 	data = g_new0 (DialogData, 1);
 
@@ -194,39 +201,47 @@ planner_default_week_dialog_new (PlannerWindow *window,
 		gchar *tmp;
 
 		tmp = g_strdup_printf ("from%d_label", i + 1);
-		data->from_label[i] = glade_xml_get_widget (glade, tmp);
+		data->from_label[i] = GTK_WIDGET (gtk_builder_get_object (builder, tmp));
 		g_free (tmp);
 
 		tmp = g_strdup_printf ("to%d_label", i + 1);
-		data->to_label[i] = glade_xml_get_widget (glade, tmp);
+		data->to_label[i] = GTK_WIDGET (gtk_builder_get_object (builder, tmp));
 		g_free (tmp);
 
 		tmp = g_strdup_printf ("dash%d_label", i + 1);
-		data->dash_label[i] = glade_xml_get_widget (glade, tmp);
+		data->dash_label[i] = GTK_WIDGET (gtk_builder_get_object (builder, tmp));
 		g_free (tmp);
 	}
 
-	w = glade_xml_get_widget (glade, "name_label");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "name_label"));
 	gtk_label_set_text (GTK_LABEL (w), mrp_calendar_get_name (calendar));
 
-	data->weekday_option_menu = glade_xml_get_widget (glade, "weekday_optionmenu");
-	data->day_option_menu = glade_xml_get_widget (glade, "day_optionmenu");
+	data->weekday_combobox = GTK_WIDGET (gtk_builder_get_object (builder, "weekday_combobox"));
+	data->daytype_combobox = GTK_WIDGET (gtk_builder_get_object (builder, "daytype_combobox"));
 
-	default_week_dialog_setup_day_option_menu (GTK_OPTION_MENU (data->day_option_menu),
-						   data->project,
-						   calendar);
+	default_week_dialog_setup_daytype_combobox (GTK_COMBO_BOX (data->daytype_combobox),
+						    data->project,
+						    calendar);
 
-	g_signal_connect (data->day_option_menu,
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (data->daytype_combobox),
+				    renderer, TRUE);
+	gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (data->daytype_combobox),
+					    renderer,
+					    daytype_combo_name_and_sensitive,
+					    NULL, NULL);
+
+	g_signal_connect (data->daytype_combobox,
 			  "changed",
 			  G_CALLBACK (default_week_dialog_day_selected_cb),
 			  data);
 
-	g_signal_connect (data->weekday_option_menu,
+	g_signal_connect (data->weekday_combobox,
 			  "changed",
 			  G_CALLBACK (default_week_dialog_weekday_selected_cb),
 			  data);
 
-	default_week_dialog_setup_weekday_option_menu (GTK_OPTION_MENU (data->weekday_option_menu));
+	default_week_dialog_setup_weekday_combobox (GTK_COMBO_BOX_TEXT (data->weekday_combobox));
 
 	g_signal_connect (dialog,
 			  "response",
@@ -239,6 +254,7 @@ planner_default_week_dialog_new (PlannerWindow *window,
 
 	default_week_dialog_update_labels (data);
 
+	g_object_unref (builder);
 	return dialog;
 }
 
@@ -313,8 +329,8 @@ default_week_dialog_update_labels (DialogData *data)
 }
 
 static void
-default_week_dialog_weekday_selected_cb (GtkOptionMenu *option_menu,
-					 DialogData    *data)
+default_week_dialog_weekday_selected_cb (GtkComboBoxText *combotext,
+					 DialogData      *data)
 {
 	gint    weekday;
 	MrpDay *day;
@@ -328,62 +344,51 @@ default_week_dialog_weekday_selected_cb (GtkOptionMenu *option_menu,
 }
 
 static void
-default_week_dialog_day_selected_cb (GtkOptionMenu *option_menu,
-				     DialogData    *data)
+default_week_dialog_day_selected_cb (GtkComboBox *combo,
+				     DialogData  *data)
 {
 	default_week_dialog_update_labels (data);
 }
 
 static void
-default_week_dialog_setup_day_option_menu (GtkOptionMenu *option_menu,
-					   MrpProject    *project,
-					   MrpCalendar   *calendar)
+default_week_dialog_setup_daytype_combobox (GtkComboBox *combo,
+					    MrpProject  *project,
+					    MrpCalendar *calendar)
 {
-	GtkWidget   *menu;
-	GtkWidget   *menu_item;
-	const gchar *name;
-	GList       *days, *l;
-	MrpDay      *day;
-	MrpCalendar *parent, *root;
+	GtkListStore    *store;
+	GtkTreeIter      iter;
+	GList           *days, *l;
+
+	store = gtk_list_store_new (2, MRP_TYPE_DAY, G_TYPE_BOOLEAN);
+	gtk_combo_box_set_model (combo, GTK_TREE_MODEL (store));
+	g_object_unref (store);
+
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter,
+			    0, mrp_day_get_work (),
+			    1, TRUE,
+			    -1);
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter,
+			    0, mrp_day_get_nonwork (),
+			    1, TRUE,
+			    -1);
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter,
+			    0, mrp_day_get_use_base (),
+			    1, !(mrp_calendar_get_parent (calendar) == mrp_project_get_root_calendar (project)),
+			    -1);
 
 	days = mrp_day_get_all (project);
-	days = g_list_prepend (days, mrp_day_get_use_base ());
-	days = g_list_prepend (days, mrp_day_get_nonwork ());
-	days = g_list_prepend (days, mrp_day_get_work ());
-
-	parent = mrp_calendar_get_parent (calendar);
-	root = mrp_project_get_root_calendar (project);
-
-	menu = gtk_option_menu_get_menu (option_menu);
-
-	if (menu) {
-		gtk_widget_destroy (menu);
-	}
-
-	menu = gtk_menu_new ();
 
 	for (l = days; l; l = l->next) {
-		day = l->data;
-
-		name = mrp_day_get_name (day);
-
-		menu_item = gtk_menu_item_new_with_label (name);
-		gtk_widget_show (menu_item);
-		gtk_menu_append (GTK_MENU (menu), menu_item);
-
-		/* "Use base" is not possible for toplevel calendars. */
-		if (parent == root && day == mrp_day_get_use_base ()) {
-			gtk_widget_set_sensitive (menu_item, FALSE);
-		}
-
-		g_object_set_data (G_OBJECT (menu_item),
-				   "data",
-				   l->data);
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+				    0, MRP_DAY (l->data),
+				    1, TRUE,
+				    -1);
 	}
 
-	gtk_widget_show (menu);
-	gtk_option_menu_set_menu (option_menu, menu);
-
 	/* Need to unref the days here? */
 	g_list_free (days);
 }
@@ -391,81 +396,54 @@ default_week_dialog_setup_day_option_menu (GtkOptionMenu *option_menu,
 static gint
 default_week_dialog_get_selected_weekday (DialogData *data)
 {
-	GtkWidget *menu;
-	GtkWidget *item;
-	gint       id;
-
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (data->weekday_option_menu));
-
-	item = gtk_menu_get_active (GTK_MENU (menu));
-
-	id = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "data"));
-
-	return id;
+	return days[gtk_combo_box_get_active (GTK_COMBO_BOX (data->weekday_combobox))].day;
 }
 
 static void
-default_week_dialog_setup_weekday_option_menu (GtkOptionMenu *option_menu)
+default_week_dialog_setup_weekday_combobox (GtkComboBoxText *combotext)
 {
-	GtkWidget *menu;
-	GtkWidget *menu_item;
-	gint       i;
+	gint i;
 
-	menu = gtk_option_menu_get_menu (option_menu);
-	if (menu) {
-		gtk_widget_destroy (menu);
+	for (i = 0; i < G_N_ELEMENTS(days); i++) {
+		gtk_combo_box_text_append_text (combotext, _(days[i].name));
 	}
-
-	menu = gtk_menu_new ();
-
-	for (i = 0; i < 7; i++) {
-		menu_item = gtk_menu_item_new_with_label (_(days[i].name));
-
-		gtk_widget_show (menu_item);
-		gtk_menu_append (GTK_MENU (menu), menu_item);
-
-		g_object_set_data (G_OBJECT (menu_item),
-				   "data",
-				   GINT_TO_POINTER (days[i].day));
-	}
-
-	gtk_widget_show (menu);
-	gtk_option_menu_set_menu (option_menu, menu);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combotext), 0);
 }
 
 static MrpDay *
 default_week_dialog_get_selected_day (DialogData *data)
 {
-	GtkWidget *menu;
-	GtkWidget *item;
+	GtkTreeIter  iter;
+	MrpDay      *day;
 
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (data->day_option_menu));
-
-	item = gtk_menu_get_active (GTK_MENU (menu));
-
-	return g_object_get_data (G_OBJECT (item), "data");
+	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (data->daytype_combobox), &iter);
+	gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (data->daytype_combobox)),
+			    &iter,
+			    0, &day,
+			    -1);
+	return day;
 }
 
 static void
 default_week_dialog_set_selected_day (DialogData *data,
 				      MrpDay     *day)
 {
-	GtkWidget *menu;
-	GtkWidget *item;
-	GList     *children, *l;
-	gint       i;
+	GtkComboBox  *combo;
+	GtkTreeModel *model;
+	GtkTreeIter   iter;
+	MrpDay       *iter_day;
 
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (data->day_option_menu));
+	combo = GTK_COMBO_BOX (data->daytype_combobox);
+	model = gtk_combo_box_get_model (combo);
+	gtk_tree_model_get_iter_first (model, &iter);
 
-	children = GTK_MENU_SHELL (menu)->children;
-	for (i = 0, l = children; l; i++, l = l->next) {
-		item = l->data;
-
-		if (day == g_object_get_data (G_OBJECT (item), "data")) {
-			gtk_option_menu_set_history (GTK_OPTION_MENU (data->day_option_menu), i);
-			break;
+	do {
+		gtk_tree_model_get (model, &iter, 0, &iter_day, -1);
+		if (iter_day == day) {
+			gtk_combo_box_set_active_iter (combo, &iter);
+			return;
 		}
-	}
+	} while (gtk_tree_model_iter_next (model, &iter));
 }
 
 static gboolean
