@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_DEFAULT_WEEK_DIALOG_H__
-#define __PLANNER_DEFAULT_WEEK_DIALOG_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libplanner/mrp-project.h>
@@ -30,14 +29,3 @@
 
 GtkWidget * planner_default_week_dialog_new (PlannerWindow *window,
 					MrpCalendar  *calendar);
-
-#endif /* __PLANNER_DEFAULT_WEEK_DIALOG_H__ */
-
-
-
-
-
-
-
-
-
