@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_GANTT_BACKGROUND_H__
-#define __PLANNER_GANTT_BACKGROUND_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libgnomecanvas/gnome-canvas.h>
@@ -49,7 +48,3 @@ struct _PlannerGanttBackgroundClass {
 
 
 GType planner_gantt_background_get_type (void) G_GNUC_CONST;
-
-
-#endif /* __PLANNER_GANTT_BACKGROUND_H__ */
-
