@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_GANTT_CHART_H__
-#define __PLANNER_GANTT_CHART_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libgnomecanvas/gnome-canvas.h>
@@ -101,6 +100,3 @@ planner_gantt_chart_set_nonstandard_days             (PlannerGanttChart *chart,
 							   gboolean           state);
 gboolean
 planner_gantt_chart_get_nonstandard_days             (PlannerGanttChart *chart);
-
-
-#endif /* __PLANNER_GANTT_CHART_H__ */
