@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -37,6 +37,8 @@ struct _PlannerGanttHeaderPriv {
 	GdkWindow          *bin_window;
 
 	GtkAdjustment      *hadjustment;
+	guint               hscroll_policy : 1;
+	guint               vscroll_policy : 1;
 
 	PangoLayout        *layout;
 
@@ -64,7 +66,12 @@ enum {
 	PROP_X1,
 	PROP_X2,
 	PROP_SCALE,
-	PROP_ZOOM
+	PROP_ZOOM,
+	/* Scrollable interface */
+	PROP_HADJUSTMENT,
+	PROP_VADJUSTMENT,
+	PROP_HSCROLL_POLICY,
+	PROP_VSCROLL_POLICY
 };
 
 enum {
@@ -83,21 +90,19 @@ static void     gantt_header_get_property        (GObject                 *objec
 						  guint                    prop_id,
 						  GValue                  *value,
 						  GParamSpec              *pspec);
-static void     gantt_header_destroy             (GtkObject               *object);
 static void     gantt_header_map                 (GtkWidget               *widget);
 static void     gantt_header_realize             (GtkWidget               *widget);
 static void     gantt_header_unrealize           (GtkWidget               *widget);
 static void     gantt_header_size_allocate       (GtkWidget               *widget,
 						  GtkAllocation           *allocation);
-static gboolean gantt_header_expose_event        (GtkWidget               *widget,
-						  GdkEventExpose          *event);
+static gboolean gantt_header_draw                (GtkWidget               *widget,
+						  cairo_t                 *cr);
 static gboolean gantt_header_motion_notify_event (GtkWidget               *widget,
 						  GdkEventMotion          *event);
 static gboolean gantt_header_leave_notify_event  (GtkWidget	          *widget,
 						  GdkEventCrossing        *event);
-static void     gantt_header_set_adjustments     (PlannerGanttHeader      *header,
-						  GtkAdjustment           *hadj,
-						  GtkAdjustment           *vadj);
+static void     gantt_header_set_hadjustment     (PlannerGanttHeader      *header,
+						  GtkAdjustment           *hadj);
 static void     gantt_header_adjustment_changed  (GtkAdjustment           *adjustment,
 						  PlannerGanttHeader      *header);
 
@@ -107,10 +112,10 @@ static GtkWidgetClass *parent_class = NULL;
 static guint           signals[LAST_SIGNAL];
 
 
-GtkType
+GType
 planner_gantt_header_get_type (void)
 {
-	static GtkType planner_gantt_header_type = 0;
+	static GType planner_gantt_header_type = 0;
 
 	if (!planner_gantt_header_type) {
 		static const GTypeInfo planner_gantt_header_info = {
@@ -125,11 +130,21 @@ planner_gantt_header_get_type (void)
 			(GInstanceInitFunc) gantt_header_init
 		};
 
+		static const GInterfaceInfo scrollable_info = {
+			(GInterfaceInitFunc) NULL,
+			NULL,
+			NULL
+		};
+
 		planner_gantt_header_type = g_type_register_static (
 			GTK_TYPE_WIDGET,
 			"PlannerGanttHeader",
 			&planner_gantt_header_info,
 			0);
+
+		g_type_add_interface_static (planner_gantt_header_type,
+					     GTK_TYPE_SCROLLABLE,
+					     &scrollable_info);
 	}
 
 	return planner_gantt_header_type;
@@ -139,13 +154,11 @@ static void
 gantt_header_class_init (PlannerGanttHeaderClass *class)
 {
 	GObjectClass      *o_class;
-	GtkObjectClass    *object_class;
 	GtkWidgetClass    *widget_class;
 
 	parent_class = g_type_class_peek_parent (class);
 
 	o_class = (GObjectClass *) class;
-	object_class = (GtkObjectClass *) class;
 	widget_class = (GtkWidgetClass *) class;
 
 	/* GObject methods. */
@@ -153,30 +166,21 @@ gantt_header_class_init (PlannerGanttHeaderClass *class)
 	o_class->get_property = gantt_header_get_property;
 	o_class->finalize = gantt_header_finalize;
 
-	/* GtkObject methods. */
-	object_class->destroy = gantt_header_destroy;
-
 	/* GtkWidget methods. */
 	widget_class->map = gantt_header_map;;
 	widget_class->realize = gantt_header_realize;
 	widget_class->unrealize = gantt_header_unrealize;
 	widget_class->size_allocate = gantt_header_size_allocate;
-	widget_class->expose_event = gantt_header_expose_event;
+	widget_class->draw = gantt_header_draw;
 	widget_class->leave_notify_event = gantt_header_leave_notify_event;
 
 	widget_class->motion_notify_event = gantt_header_motion_notify_event;
 
-	class->set_scroll_adjustments = gantt_header_set_adjustments;
-
-	widget_class->set_scroll_adjustments_signal =
-		g_signal_new ("set_scroll_adjustments",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (PlannerGanttHeaderClass, set_scroll_adjustments),
-			      NULL, NULL,
-			      planner_marshal_VOID__OBJECT_OBJECT,
-			      G_TYPE_NONE, 2,
-			      GTK_TYPE_ADJUSTMENT, GTK_TYPE_ADJUSTMENT);
+	/* GtkScrollable interface properties */
+	g_object_class_override_property (o_class, PROP_HADJUSTMENT,    "hadjustment");
+	g_object_class_override_property (o_class, PROP_VADJUSTMENT,    "vadjustment");
+	g_object_class_override_property (o_class, PROP_HSCROLL_POLICY, "hscroll-policy");
+	g_object_class_override_property (o_class, PROP_VSCROLL_POLICY, "vscroll-policy");
 
 	/* Properties. */
 	g_object_class_install_property (
@@ -245,8 +249,6 @@ gantt_header_init (PlannerGanttHeader *header)
 	priv = g_new0 (PlannerGanttHeaderPriv, 1);
 	header->priv = priv;
 
-	gantt_header_set_adjustments (header, NULL, NULL);
-
 	priv->hscale = 1.0;
 	priv->x1 = 0;
 	priv->x2 = 0;
@@ -324,6 +326,20 @@ gantt_header_set_property (GObject      *object,
 	case PROP_ZOOM:
 		gantt_header_set_zoom (header, g_value_get_double (value));
 		break;
+	case PROP_HADJUSTMENT:
+		gantt_header_set_hadjustment (header, g_value_get_object (value));
+		break;
+	case PROP_VADJUSTMENT:
+		/* TODO: g_assert_not_reached (); */
+		break;
+	case PROP_HSCROLL_POLICY:
+		priv->hscroll_policy = g_value_get_enum (value);
+		gtk_widget_queue_resize (GTK_WIDGET (header));
+		break;
+	case PROP_VSCROLL_POLICY:
+		priv->hscroll_policy = g_value_get_enum (value);
+		gtk_widget_queue_resize (GTK_WIDGET (header));
+		break;
 	default:
 		break;
 	}
@@ -348,7 +364,7 @@ gantt_header_set_property (GObject      *object,
 					     priv->height);
 	}
 
-	if ((change_width || change_height || change_scale) && GTK_WIDGET_REALIZED (header)) {
+	if ((change_width || change_height || change_scale) && gtk_widget_get_realized (GTK_WIDGET (header))) {
 		gdk_window_invalidate_rect (priv->bin_window,
 					    NULL,
 					    FALSE);
@@ -361,7 +377,23 @@ gantt_header_get_property (GObject    *object,
 			   GValue     *value,
 			   GParamSpec *pspec)
 {
+	PlannerGanttHeader     *header;
+
+	header = PLANNER_GANTT_HEADER (object);
+
 	switch (prop_id) {
+	case PROP_HADJUSTMENT:
+		g_value_set_object (value, header->priv->hadjustment);
+		break;
+	case PROP_VADJUSTMENT:
+		/* TODO: g_assert_not_reached (); */
+		break;
+	case PROP_HSCROLL_POLICY:
+		g_value_set_enum (value, header->priv->hscroll_policy);
+		break;
+	case PROP_VSCROLL_POLICY:
+		g_value_set_enum (value, header->priv->vscroll_policy);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -384,16 +416,6 @@ gantt_header_finalize (GObject *object)
 	}
 }
 
-static void
-gantt_header_destroy (GtkObject *object)
-{
-	/*PlannerGanttHeader *header = PLANNER_GANTT_HEADER (object);*/
-
-	if (GTK_OBJECT_CLASS (parent_class)->destroy) {
-		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
-	}
-}
-
 static void
 gantt_header_map (GtkWidget *widget)
 {
@@ -401,46 +423,50 @@ gantt_header_map (GtkWidget *widget)
 
 	header = PLANNER_GANTT_HEADER (widget);
 
-	GTK_WIDGET_SET_FLAGS (widget, GTK_MAPPED);
+	gtk_widget_set_mapped (widget, TRUE);
 
 	gdk_window_show (header->priv->bin_window);
-	gdk_window_show (widget->window);
+	gdk_window_show (gtk_widget_get_window (widget));
 }
 
 static void
 gantt_header_realize (GtkWidget *widget)
 {
 	PlannerGanttHeader *header;
+	GtkAllocation       allocation;
 	GdkWindowAttr       attributes;
 	gint                attributes_mask;
+	GdkWindow          *window;
 
 	header = PLANNER_GANTT_HEADER (widget);
 
-	GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
+	gtk_widget_set_realized (widget, TRUE);
+	gtk_widget_get_allocation (widget, &allocation);
 
 	/* Create the main, clipping window. */
 	attributes.window_type = GDK_WINDOW_CHILD;
-	attributes.x = widget->allocation.x;
-	attributes.y = widget->allocation.y;
-	attributes.width = widget->allocation.width;
-	attributes.height = widget->allocation.height;
+	attributes.x = allocation.x;
+	attributes.y = allocation.y;
+	attributes.width = allocation.width;
+	attributes.height = allocation.height;
 	attributes.wclass = GDK_INPUT_OUTPUT;
 	attributes.visual = gtk_widget_get_visual (widget);
-	attributes.colormap = gtk_widget_get_colormap (widget);
 	attributes.event_mask = GDK_VISIBILITY_NOTIFY_MASK;
 
-	attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
+	attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL;
 
-	widget->window = gdk_window_new (gtk_widget_get_parent_window (widget),
-					 &attributes, attributes_mask);
-	gdk_window_set_user_data (widget->window, widget);
+	window = gdk_window_new (gtk_widget_get_parent_window (widget),
+				 &attributes, attributes_mask);
+	gtk_widget_set_window (widget, window);
+	gdk_window_set_user_data (window, widget);
 
 	/* Bin window. */
 	attributes.x = 0;
 	attributes.y = header->priv->height;
 	attributes.width = header->priv->width;
-	attributes.height = widget->allocation.height;
-	attributes.event_mask = GDK_EXPOSURE_MASK |
+	gtk_widget_get_allocation (widget, &allocation);
+	attributes.height = allocation.height;
+	attributes.event_mask = GDK_EXPOSURE_MASK | /* TODO: Do we need exposure mask anymore? */
 		GDK_SCROLL_MASK |
 		GDK_POINTER_MOTION_MASK |
 		GDK_ENTER_NOTIFY_MASK |
@@ -449,16 +475,10 @@ gantt_header_realize (GtkWidget *widget)
 		GDK_BUTTON_RELEASE_MASK |
 		gtk_widget_get_events (widget);
 
-	header->priv->bin_window = gdk_window_new (widget->window,
+	header->priv->bin_window = gdk_window_new (gtk_widget_get_window (widget),
 						   &attributes,
 						   attributes_mask);
 	gdk_window_set_user_data (header->priv->bin_window, widget);
-
-	widget->style = gtk_style_attach (widget->style, widget->window);
-	gdk_window_set_background (widget->window,
-				   &widget->style->base[widget->state]);
-	gdk_window_set_background (header->priv->bin_window,
-				   &widget->style->base[widget->state]);
 }
 
 static void
@@ -485,12 +505,14 @@ gantt_header_size_allocate (GtkWidget     *widget,
 
 	header = PLANNER_GANTT_HEADER (widget);
 
-	if (GTK_WIDGET_REALIZED (widget)) {
-		gdk_window_move_resize (widget->window,
+	gtk_widget_set_allocation (widget, allocation);
+
+	if (gtk_widget_get_realized (widget)) {
+		gdk_window_move_resize (gtk_widget_get_window (widget),
 					allocation->x, allocation->y,
 					allocation->width, allocation->height);
 		gdk_window_move_resize (header->priv->bin_window,
-					- (gint) header->priv->hadjustment->value,
+					- (gint) gtk_adjustment_get_value (header->priv->hadjustment),
 					0,
 					MAX (header->priv->width, allocation->width),
 					allocation->height);
@@ -498,53 +520,68 @@ gantt_header_size_allocate (GtkWidget     *widget,
 }
 
 static gboolean
-gantt_header_expose_event (GtkWidget      *widget,
-			   GdkEventExpose *event)
+gantt_header_draw (GtkWidget *widget,
+                   cairo_t   *cr)
 {
 	PlannerGanttHeader     *header;
 	PlannerGanttHeaderPriv *priv;
-	gint                    width, height;
+	GdkWindow              *bin_window;
+	GdkRectangle            clip;
+	gint                    height;
 	gdouble                 hscale;
-	gint                    x;
+	gint                    x, tr_x, tr_y;
 	mrptime                 t0;
 	mrptime                 t1;
 	mrptime                 t;
 	gchar                  *str;
 	gint                    minor_width;
 	gint                    major_width;
-	GdkGC                  *gc;
-	GdkRectangle            rect;
+	GdkRGBA text_color = { 0.0, 0.0, 0.0, 1.0 }; /* Fallback to black */
+	GdkRGBA insensitive_fg_color = { 0.980392, 0.976471, 0.972549, 1.000000 }; /* Fallback to #faf9f8 */
 
 	header = PLANNER_GANTT_HEADER (widget);
 	priv = header->priv;
 	hscale = priv->hscale;
 
-	t0 = floor ((priv->x1 + event->area.x) / hscale + 0.5);
-	t1 = floor ((priv->x1 + event->area.x + event->area.width) / hscale + 0.5);
+	bin_window = priv->bin_window;
+	if (!gtk_cairo_should_draw_window (cr, bin_window)) {
+		return FALSE;
+	}
+	gdk_window_get_position (bin_window, &tr_x, &tr_y);
+	cairo_translate (cr, tr_x, tr_y);
 
-	gdk_drawable_get_size (event->window, &width, &height);
+	gdk_cairo_get_clip_rectangle (cr, &clip);
+
+	cairo_set_line_width (cr, 1.0);
+	cairo_set_line_cap (cr, CAIRO_LINE_CAP_SQUARE);
+
+	gtk_style_context_lookup_color (gtk_widget_get_style_context (widget),
+					"theme_text_color", &text_color);
+	/* TODO: Use same theming methods as GtkTreeView column headers do (they end up different shade of grey) */
+	gtk_style_context_lookup_color (gtk_widget_get_style_context (widget),
+					"insensitive_fg_color", &insensitive_fg_color);
+
+	t0 = floor ((priv->x1 + clip.x) / hscale + 0.5);
+	t1 = floor ((priv->x1 + clip.x + clip.width) / hscale + 0.5);
+
+	height = gdk_window_get_height (bin_window);
 
 	/* Draw background. We only draw over the exposed area, padding with +/-
 	 * 5 so we don't mess up the header with button edges all over.
 	 */
-	gtk_paint_box (widget->style,
-		       event->window,
-		       GTK_STATE_NORMAL,
-		       GTK_SHADOW_OUT,
-		       &event->area,
-		       widget,
-		       "button",
-		       event->area.x - 5,
-		       0,
-		       event->area.width + 10,
-		       height);
+	/* TODO: Just leaving out this step seems to render OK result too - investigate */
+	gtk_render_background (gtk_widget_get_style_context (widget),
+			       cr,
+			       clip.x - 5,
+			       0,
+			       clip.width + 10,
+			       height);
 
-	gdk_draw_line (event->window,
-		       widget->style->fg_gc[GTK_STATE_INSENSITIVE],
-		       event->area.x,
-		       height / 2,
-		       event->area.x + event->area.width,
-		       height / 2);
+	// Horizontal full width line between week number and date rows
+	gdk_cairo_set_source_rgba (cr, &insensitive_fg_color);
+	cairo_move_to (cr, clip.x + 0.5, height / 2 + 0.5);
+	cairo_line_to (cr, clip.x + clip.width + 0.5, height / 2 + 0.5);
+	cairo_stroke (cr);
 
 	/* Get the widths of major/minor ticks so that we know how wide to make
 	 * the clip region.
@@ -555,12 +592,6 @@ gantt_header_expose_event (GtkWidget      *widget,
 	minor_width = hscale * (mrp_time_align_next (t0, priv->minor_unit) -
 				mrp_time_align_prev (t0, priv->minor_unit));
 
-	gc = gdk_gc_new (widget->window);
-	gdk_gc_copy (gc, widget->style->text_gc[GTK_STATE_NORMAL]);
-
-	rect.y = 0;
-	rect.height = height;
-
 	/* Draw the major scale. */
 	if (major_width < 2 || priv->major_unit == MRP_TIME_UNIT_NONE) {
 		/* Unless it's too thin to make sense. */
@@ -572,10 +603,11 @@ gantt_header_expose_event (GtkWidget      *widget,
 	while (t <= t1) {
 		x = floor (t * hscale - priv->x1 + 0.5);
 
-		gdk_draw_line (event->window,
-			       widget->style->fg_gc[GTK_STATE_INSENSITIVE],
-			       x, 0,
-			       x, height / 2);
+		// Vertical lines between different weeks
+		gdk_cairo_set_source_rgba (cr, &insensitive_fg_color);
+		cairo_move_to (cr, x + 0.5, 0.5);
+		cairo_line_to (cr, x + 0.5, height / 2 + 1);
+		cairo_stroke (cr);
 
 		str = planner_scale_format_time (t,
 					    priv->major_unit,
@@ -585,15 +617,14 @@ gantt_header_expose_event (GtkWidget      *widget,
 				       -1);
 		g_free (str);
 
-		rect.x = x;
-		rect.width = major_width;
-		gdk_gc_set_clip_rectangle (gc, &rect);
+		cairo_save (cr);
+		cairo_rectangle (cr, x, 0, major_width, height);
+		cairo_clip (cr);
 
-		gdk_draw_layout (event->window,
-				 gc,
-				 x + 3,
-				 2,
-				 priv->layout);
+		gdk_cairo_set_source_rgba (cr, &text_color);
+		cairo_move_to (cr, x + 3, 2);
+		pango_cairo_show_layout (cr, priv->layout);
+		cairo_restore (cr);
 
 		t = mrp_time_align_next (t, priv->major_unit);
 	}
@@ -611,10 +642,11 @@ gantt_header_expose_event (GtkWidget      *widget,
 	while (t <= t1) {
 		x = floor (t * hscale - priv->x1 + 0.5);
 
-		gdk_draw_line (event->window,
-			       widget->style->fg_gc[GTK_STATE_INSENSITIVE],
-			       x, height / 2,
-			       x, height);
+		// NOTE: Vertical lines between dates
+		gdk_cairo_set_source_rgba (cr, &insensitive_fg_color);
+		cairo_move_to (cr, x + 0.5, height / 2 + 0.5);
+		cairo_line_to (cr, x + 0.5, height + 0.5);
+		cairo_stroke (cr);
 
 		str = planner_scale_format_time (t,
 					    priv->minor_unit,
@@ -624,22 +656,18 @@ gantt_header_expose_event (GtkWidget      *widget,
 				       -1);
 		g_free (str);
 
-		rect.x = x;
-		rect.width = minor_width;
-		gdk_gc_set_clip_rectangle (gc, &rect);
-
-		gdk_draw_layout (event->window,
-				 gc,
-				 x + 3,
-				 height / 2 + 2,
-				 priv->layout);
+		cairo_save (cr);
+		cairo_rectangle (cr, x, 0, minor_width, height);
+		cairo_clip (cr);
+		gdk_cairo_set_source_rgba (cr, &text_color);
+		cairo_move_to (cr, x + 3, height / 2 + 2);
+		pango_cairo_show_layout (cr, priv->layout);
+		cairo_restore (cr);
 
 		t = mrp_time_align_next (t, priv->minor_unit);
 	}
 
  done:
-	gdk_gc_unref (gc);
-
 	return TRUE;
 }
 
@@ -692,41 +720,42 @@ gantt_header_leave_notify_event (GtkWidget	  *widget,
 
 /* Callbacks */
 static void
-gantt_header_set_adjustments (PlannerGanttHeader *header,
-			      GtkAdjustment      *hadj,
-			      GtkAdjustment      *vadj)
+gantt_header_set_hadjustment (PlannerGanttHeader *header,
+			      GtkAdjustment      *hadj)
 {
-	if (hadj == NULL) {
+	if (hadj && header->priv->hadjustment == hadj)
+		return;
+
+	if (hadj)
+		g_return_if_fail (GTK_IS_ADJUSTMENT (hadj));
+	else
 		hadj = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 0.0, 0.0, 0.0, 0.0));
+
+	if (header->priv->hadjustment != NULL) {
+		g_signal_handlers_disconnect_matched (header->priv->hadjustment,
+						      G_SIGNAL_MATCH_DATA,
+						      0, 0, NULL, NULL,
+						      header);
+		g_object_unref (header->priv->hadjustment);
 	}
 
-	if (header->priv->hadjustment && (header->priv->hadjustment != hadj)) {
-		gtk_object_unref (GTK_OBJECT (header->priv->hadjustment));
-	}
+	g_signal_connect (hadj,
+			  "value-changed",
+			  G_CALLBACK (gantt_header_adjustment_changed),
+			  header);
+	header->priv->hadjustment = g_object_ref_sink (hadj);
+	/* TODO: Do we need to set the initial hadj values? */
 
-	if (header->priv->hadjustment != hadj) {
-		header->priv->hadjustment = hadj;
-		gtk_object_ref (GTK_OBJECT (header->priv->hadjustment));
-		gtk_object_sink (GTK_OBJECT (header->priv->hadjustment));
-
-		g_signal_connect (hadj,
-				  "value_changed",
-				  G_CALLBACK (gantt_header_adjustment_changed),
-				  header);
-
-		gtk_widget_set_scroll_adjustments (GTK_WIDGET (header),
-						   hadj,
-						   NULL);
-	}
+	g_object_notify (G_OBJECT (header), "hadjustment");
 }
 
 static void
 gantt_header_adjustment_changed (GtkAdjustment *adjustment,
 				 PlannerGanttHeader *header)
 {
-	if (GTK_WIDGET_REALIZED (header)) {
+	if (gtk_widget_get_realized (GTK_WIDGET (header))) {
 		gdk_window_move (header->priv->bin_window,
-				 -header->priv->hadjustment->value,
+				 - gtk_adjustment_get_value (header->priv->hadjustment),
 				 0);
 	}
 }
