@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_GANTT_MODEL_H__
-#define __PLANNER_GANTT_MODEL_H__
+#pragma once
 
 #include <libplanner/mrp-project.h>
 #include <libplanner/mrp-task.h>
@@ -75,7 +74,3 @@ MrpTask      *     planner_gantt_model_get_task               (PlannerGanttModel
 							       GtkTreeIter       *iter);
 MrpTask           *planner_gantt_model_get_task_from_path     (PlannerGanttModel *model,
 							       GtkTreePath       *path);
-
-
-#endif /* __PLANNER_GANTT_MODEL_H__ */
-
