@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_GANTT_ROW_H__
-#define __PLANNER_GANTT_ROW_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libgnomecanvas/gnome-canvas.h>
@@ -57,5 +56,3 @@ void  planner_gantt_row_get_geometry (PlannerGanttRow *row,
 				 gdouble    *y2);
 void  planner_gantt_row_set_visible  (PlannerGanttRow *row,
 				 gboolean    is_visible);
-
-#endif /* __PLANNER_GANTT_ROW_H__ */
