@@ -24,12 +24,12 @@
 #include <config.h>
 #include <stdlib.h>
 #include <glib/gi18n.h>
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include "libplanner/mrp-paths.h"
 #include "planner-marshal.h"
 #include "planner-group-model.h"
 #include "planner-group-dialog.h"
+#include "planner-util.h"
 
 /* GtkCellRenderer types */
 enum {
@@ -179,11 +179,10 @@ static GtkWidget *
 group_dialog_create (PlannerView *view)
 {
 	DialogData *data;
-	GladeXML   *gui;
+	GtkBuilder *builder;
 	GtkWidget  *dialog;
 	GtkWidget  *button;
 	MrpProject *project;
-	gchar      *filename;
 
 	data = g_new0 (DialogData, 1);
 
@@ -192,28 +191,26 @@ group_dialog_create (PlannerView *view)
 
 	data->project = g_object_ref (project);
 
-	filename = mrp_paths_get_glade_dir ( "group-dialog.glade");
-	gui = glade_xml_new (filename, NULL, NULL);
-	g_free (filename);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/ui/group-dialog.ui");
 
-	dialog = glade_xml_get_widget (gui, "dialog_group_editor");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_group_editor"));
 
 	data->tree_view = GTK_TREE_VIEW (
-		glade_xml_get_widget (gui,
-				      "group_edit_treeview"));
+		gtk_builder_get_object (builder,
+					"group_edit_treeview"));
 
-	button = glade_xml_get_widget (gui, "add_group");
+	button = GTK_WIDGET (gtk_builder_get_object (builder, "add_group"));
 	g_signal_connect (button, "clicked",
 			  G_CALLBACK (group_dialog_insert_group_cb),
 			  dialog);
 
-	data->remove_button = glade_xml_get_widget (gui, "remove_group");
+	data->remove_button = GTK_WIDGET (gtk_builder_get_object (builder, "remove_group"));
 	g_signal_connect (data->remove_button,
 			  "clicked",
 			  G_CALLBACK (group_dialog_remove_group_cb),
 			  dialog);
 
-	button = glade_xml_get_widget (gui, "close_editor");
+	button = GTK_WIDGET (gtk_builder_get_object (builder, "close_editor"));
 	g_signal_connect (button,
 			  "clicked",
 			  G_CALLBACK (group_dialog_close_editor_cb),
@@ -223,6 +220,7 @@ group_dialog_create (PlannerView *view)
 
 	group_dialog_setup_tree_view (dialog);
 
+	g_object_unref (builder);
 	return dialog;
 }
 
