@@ -21,8 +21,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_GROUP_MODEL_H__
-#define __PLANNER_GROUP_MODEL_H__
+#pragma once
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
@@ -66,5 +65,3 @@ enum {
 
 GType           planner_group_model_get_type        (void) G_GNUC_CONST;
 PlannerGroupModel *  planner_group_model_new             (MrpProject      *project);
-
-#endif /* __PLANNER_GROUP_MODEL_H__ */
