@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_PLUGIN_H__
-#define __PLANNER_PLUGIN_H__
+#pragma once
 
 #include <gmodule.h>
 #include <gtk/gtk.h>
@@ -58,6 +57,3 @@ struct _PlannerPluginClass {
 GType        planner_plugin_get_type          (void) G_GNUC_CONST;
 void         planner_plugin_setup             (PlannerPlugin     *plugin,
 					       PlannerWindow     *main_window);
-
-#endif /* __PLANNER_PLUGIN_H__ */
-
