@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_PREDECESSOR_MODEL_H__
-#define __PLANNER_PREDECESSOR_MODEL_H__
+#pragma once
 
 #include <libplanner/mrp-project.h>
 #include "planner-list-model.h"
@@ -58,5 +57,3 @@ enum {
 
 GType         planner_predecessor_model_get_type (void) G_GNUC_CONST;
 GtkTreeModel *planner_predecessor_model_new      (MrpTask    *task);
-
-#endif /* __PLANNER_PREDECESSOR_MODEL_H__ */
