@@ -19,8 +19,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_PRINT_DIALOG_H__
-#define __PLANNER_PRINT_DIALOG_H__
+#pragma once
 
 #include "planner-window.h"
 
@@ -36,18 +35,3 @@ void              planner_print_dialog_save_page_setup     (GtkPageSetup *page_s
 GtkPageSetup     *planner_print_dialog_load_page_setup     (void);
 void              planner_print_dialog_save_print_settings (GtkPrintSettings *settings);
 GtkPrintSettings *planner_print_dialog_load_print_settings (void);
-
-
-#endif /* __PLANNER_PRINT_DIALOG_H__ */
-
-
-
-
-
-
-
-
-
-
-
-
