@@ -6,6 +6,7 @@
  * Copyright (C) 2001-2002 Mikael Hallendal <micke@imendio.com>
  * Copyright (C) 2001-2002 Alvaro del Castillo <acs@barrapunto.com>
  * Copyright (C) 2004      Lincoln Phipps <lincoln.phipps@openmutual.net>
+ * Copyright (C) 2022      Mart Raudsepp <mart@leio.tech>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,8 +20,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -28,16 +29,16 @@
 #include <string.h>
 #include <stdlib.h>
 #include <time.h>
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libplanner/mrp-project.h>
 #include <libplanner/mrp-time.h>
 #include "libplanner/mrp-paths.h"
+#include "planner-calendar-popover.h"
 #include "planner-calendar-selector.h"
 #include "planner-format.h"
-#include "planner-popup-button.h"
 #include "planner-project-properties.h"
+#include "planner-util.h"
 
 typedef struct {
 	PlannerWindow *main_window;
@@ -47,13 +48,10 @@ typedef struct {
 	GtkWidget     *org_entry;
 	GtkWidget     *manager_entry;
 	GtkWidget     *start_entry;
-	GtkWidget     *start_button;
-	GtkWidget     *phase_option_menu;
+	GtkWidget     *start_popover;
+	GtkWidget     *phase_combo_box_text;
 	GtkWidget     *calendar_label;
 
-	GtkWidget     *calendar;
-	GtkWidget     *calendar_window;
-
 	GtkTreeView   *properties_tree;
 	GtkWidget     *add_property_button;
 	GtkWidget     *remove_property_button;
@@ -132,13 +130,11 @@ static void     mpp_project_calendar_notify_cb        (MrpProject          *proj
 static void     mpp_project_calendar_notify_cb        (MrpProject          *project,
 						       GParamSpec          *pspec,
 						       GtkWidget           *dialog);
-static void     mpp_phase_option_menu_changed_cb      (GtkOptionMenu       *option_menu,
+static void     mpp_phase_combo_box_text_changed_cb   (GtkComboBoxText     *combo_box_text,
 						       GtkWidget           *dialog);
 static void     mpp_project_phases_notify_cb          (MrpProject          *project,
 						       GParamSpec          *pspec,
 						       GtkWidget           *dialog);
-static void     mpp_phase_set_from_widget             (GtkWidget           *dialog);
-
 static void     mpp_project_phase_notify_cb           (MrpProject          *project,
 						       GParamSpec          *pspec,
 						       GtkWidget           *dialog);
@@ -628,6 +624,9 @@ mpp_start_set_from_widget (GtkWidget *dialog)
 		return;
 	}
 
+	g_object_set (data->start_popover,
+		      "mrptime", start,
+		      NULL);
 	property_cmd_edit (data, _("Edit Project Start"), PROP_DATE, "project-start", NULL, start, NULL);
 }
 
@@ -642,147 +641,20 @@ mpp_start_focus_out_event_cb (GtkWidget *widget,
 }
 
 static void
-mpp_start_cancel_clicked_cb (GtkWidget          *button,
-				PlannerPopupButton *popup_button)
-{
-	planner_popup_button_popdown (popup_button, FALSE);
-}
-
-static void
-mpp_start_save_date (GtkWidget *dialog)
+mpp_start_popover_closed_cb (GtkWidget              *dialog,
+                             PlannerCalendarPopover *popover)
 {
 	DialogData *data;
 	mrptime     start;
-	gint        year, month, day;
 
 	data = DIALOG_GET_DATA (dialog);
-
-	gtk_calendar_get_date (GTK_CALENDAR (data->calendar), &year, &month, &day);
-
-	month++;
-	start = mrp_time_compose (year, month, day, 0, 0, 0);
-
+	g_object_get (popover,
+		      "mrptime", &start,
+		      NULL);
 	property_cmd_edit (data, _("Edit Project Start"), PROP_DATE, "project-start", NULL, start, NULL);
-
 	mpp_set_start (dialog, start);
 }
 
-static void
-mpp_start_ok_clicked_cb (GtkWidget          *button,
-			 PlannerPopupButton *popup_button)
-{
-	planner_popup_button_popdown (popup_button, TRUE);
-}
-
-static void
-mpp_start_set_date (GtkCalendar *calendar, mrptime t)
-{
-	gint year, month, day;
-
-	if (!mrp_time_decompose (t, &year, &month, &day, NULL, NULL, NULL)) {
-		return;
-	}
-
-	gtk_calendar_select_month (calendar, month - 1, year);
-	gtk_calendar_select_day (calendar, day);
-}
-
-static void
-mpp_start_today_clicked_cb (GtkWidget *button,
-			    GtkWidget *dialog)
-{
-	DialogData *data;
-	mrptime     today;
-
-	data = DIALOG_GET_DATA (dialog);
-
-	today = mrp_time_current_time ();
-	mpp_start_set_date (GTK_CALENDAR (data->calendar), today);
-}
-
-static void
-mpp_start_double_click_cb (GtkWidget          *calendar,
-			   PlannerPopupButton *popup_button)
-{
-	planner_popup_button_popdown (popup_button, TRUE);
-}
-
-static GtkWidget *
-mpp_start_button_popup_cb (PlannerPopupButton *popup_button,
-			   GtkWidget          *dialog)
-{
-	DialogData *data;
-	GtkWidget  *frame;
-	GtkWidget  *vbox;
-	GtkWidget  *bbox;
-	GtkWidget  *button;
-	mrptime     start;
-
-	data = DIALOG_GET_DATA (dialog);
-
-	frame = gtk_frame_new (NULL);
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
-
-	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_container_add (GTK_CONTAINER (frame), vbox);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
-
-	data->calendar = gtk_calendar_new ();
-	gtk_box_pack_start (GTK_BOX (vbox), data->calendar, TRUE, TRUE, 0);
-
-	start = mrp_project_get_project_start (data->project);
-	mpp_start_set_date (GTK_CALENDAR (data->calendar), start);
-
-	bbox = gtk_hbutton_box_new ();
-	gtk_box_set_spacing (GTK_BOX (bbox), 6);
-	gtk_box_pack_start (GTK_BOX (vbox), bbox, FALSE, FALSE, 0);
-
-	button = gtk_button_new_with_label (_("Today"));
-	gtk_container_add (GTK_CONTAINER (bbox), button);
-	g_signal_connect (button,
-			  "clicked",
-			  G_CALLBACK (mpp_start_today_clicked_cb),
-			  dialog);
-
-	button = gtk_button_new_with_label (_("Cancel"));
-	gtk_container_add (GTK_CONTAINER (bbox), button);
-	g_signal_connect (button,
-			  "clicked",
-			  G_CALLBACK (mpp_start_cancel_clicked_cb),
-			  popup_button);
-
-	button = gtk_button_new_with_label (_("OK"));
-	gtk_container_add (GTK_CONTAINER (bbox), button);
-	g_signal_connect (button, "clicked",
-			  G_CALLBACK (mpp_start_ok_clicked_cb),
-			  popup_button);
-
-	g_signal_connect (data->calendar,
-			  "day-selected-double-click",
-			  G_CALLBACK (mpp_start_double_click_cb),
-			  popup_button);
-
-	return frame;
-}
-
-static void
-mpp_start_button_popdown_cb (PlannerPopupButton *button,
-			     GtkWidget          *widget,
-			     gboolean            ok,
-			     GtkWidget          *dialog)
-{
-	DialogData *data;
-
-	data = DIALOG_GET_DATA (dialog);
-
-	if (ok) {
-		mpp_start_save_date (dialog);
-	}
-
-	data->calendar = NULL;
-	gtk_widget_destroy (widget);
-}
-
 static void
 mpp_project_calendar_notify_cb (MrpProject *project,
 				GParamSpec *pspec,
@@ -800,10 +672,15 @@ mpp_project_calendar_notify_cb (MrpProject *project,
 }
 
 static void
-mpp_phase_option_menu_changed_cb (GtkOptionMenu *option_menu,
-				  GtkWidget     *dialog)
+mpp_phase_combo_box_text_changed_cb (GtkComboBoxText *combo_box_text,
+				     GtkWidget       *dialog)
 {
-	mpp_phase_set_from_widget (dialog);
+	property_cmd_edit (DIALOG_GET_DATA (dialog),
+			   _("Edit Project Phase"), PROP_STRING, "phase",
+			   gtk_combo_box_get_active (GTK_COMBO_BOX (combo_box_text))
+			   ? gtk_combo_box_text_get_active_text (combo_box_text)
+			   : NULL, /* First item is always "None", meaning no phase is selected */
+			   0, NULL);
 }
 
 static void
@@ -813,35 +690,17 @@ mpp_project_phases_notify_cb (MrpProject  *project,
 {
 	DialogData *data = DIALOG_GET_DATA (dialog);
 
-	g_signal_handlers_block_by_func (data->phase_option_menu,
-					 mpp_phase_option_menu_changed_cb,
+	g_signal_handlers_block_by_func (data->phase_combo_box_text,
+					 mpp_phase_combo_box_text_changed_cb,
 					 dialog);
 
 	mpp_setup_phases (data);
 
-	g_signal_handlers_unblock_by_func (data->phase_option_menu,
-					   mpp_phase_option_menu_changed_cb,
+	g_signal_handlers_unblock_by_func (data->phase_combo_box_text,
+					   mpp_phase_combo_box_text_changed_cb,
 					   dialog);
 }
 
-static void
-mpp_phase_set_from_widget (GtkWidget *dialog)
-{
-	DialogData  *data;
-	GtkWidget    *menu;
-	GtkWidget    *item;
-	const gchar *phase;
-
-	data = DIALOG_GET_DATA (dialog);
-
-       	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (data->phase_option_menu));
-	item = gtk_menu_get_active (GTK_MENU (menu));
-
-	phase = g_object_get_data (G_OBJECT (item), "data");
-
-	property_cmd_edit (data, _("Edit Project Phase"), PROP_STRING, "phase", phase, 0, NULL);
-}
-
 static void
 mpp_project_phase_notify_cb (MrpProject  *project,
 			     GParamSpec  *pspec,
@@ -860,81 +719,58 @@ mpp_project_phase_notify_cb (MrpProject  *project,
 static void
 mpp_setup_phases (DialogData *data)
 {
-	GtkOptionMenu *option_menu;
-	GList         *phases, *l;
-	GtkWidget     *menu;
-	GtkWidget     *menu_item;
-	gchar         *phase;
+	GtkComboBoxText *combo_text;
+	GList           *phases, *l;
+	gchar           *phase;
 
 	phases = NULL;
 
-	g_object_get (data->project, "phases", &phases, NULL);
+	g_object_get (data->project,
+		      "phases", &phases,
+		      "phase", &phase,
+		      NULL);
 
-	option_menu = GTK_OPTION_MENU (data->phase_option_menu);
-	menu = gtk_option_menu_get_menu (option_menu);
+	combo_text = GTK_COMBO_BOX_TEXT (data->phase_combo_box_text);
+	/* TODO-GTK3: Use gtk_combo_box_text_remove_all */
+	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (combo_text))));
 
-	if (menu) {
-		gtk_widget_destroy (menu);
-	}
-
-	menu = gtk_menu_new ();
-
-	menu_item = gtk_menu_item_new_with_label (_("None"));
-	gtk_widget_show (menu_item);
-	gtk_menu_append (GTK_MENU (menu), menu_item);
+	gtk_combo_box_text_append_text (combo_text, _("None"));
 
 	for (l = phases; l; l = l->next) {
-		menu_item = gtk_menu_item_new_with_label (l->data);
-		gtk_widget_show (menu_item);
-		gtk_menu_append (GTK_MENU (menu), menu_item);
-
-		g_object_set_data_full (G_OBJECT (menu_item),
-					"data",
-					g_strdup (l->data),
-					g_free);
+		gtk_combo_box_text_append_text (combo_text, (l->data));
 	}
 
-	gtk_widget_show (menu);
-	gtk_option_menu_set_menu (option_menu, menu);
-
-	mrp_string_list_free (phases);
-
-	g_object_get (data->project, "phase", &phase, NULL);
 	mpp_set_phase (data, phase);
+
 	g_free (phase);
+	mrp_string_list_free (phases);
 }
 
 static void
 mpp_set_phase (DialogData  *data,
 	       const gchar *phase)
 {
-	GtkOptionMenu *option_menu;
-	GtkWidget     *menu;
-	GtkWidget     *item;
-	GList         *children, *l;
-	gint           i;
-	gchar         *name;
-
-	option_menu = GTK_OPTION_MENU (data->phase_option_menu);
-
 	if (phase) {
-		menu = gtk_option_menu_get_menu (option_menu);
+		GtkComboBox  *combo;
+		GtkTreeModel *model;
+		GtkTreeIter   iter;
+		gchar        *name;
 
-		children = GTK_MENU_SHELL (menu)->children;
-		for (i = 0, l = children; l; i++, l = l->next) {
-			item = l->data;
+		combo = GTK_COMBO_BOX (data->phase_combo_box_text);
+		model = gtk_combo_box_get_model (combo);
+		gtk_tree_model_get_iter_first (model, &iter);
 
-			name = g_object_get_data (G_OBJECT (item), "data");
-
-			if (name && !strcmp (phase, name)) {
-				gtk_option_menu_set_history (option_menu, i);
+		while (gtk_tree_model_iter_next (model, &iter)) { /* Skips the first "None" item */
+			gtk_tree_model_get (model, &iter, 0, &name, -1);
+			if (!strcmp (phase, name)) {
+				gtk_combo_box_set_active_iter (combo, &iter);
 				return;
 			}
 		}
 	}
 
 	/* If we didn't match, set "None". */
-	gtk_option_menu_set_history (option_menu, 0);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (data->phase_combo_box_text), 0);
 }
 
 static void
@@ -949,6 +785,7 @@ mpp_setup_properties_list (GtkWidget *dialog)
 	model = GTK_TREE_MODEL (
 		gtk_list_store_new (NUM_OF_COLS, G_TYPE_POINTER));
 	gtk_tree_view_set_model (data->properties_tree, model);
+	g_object_unref (model);
 
 	properties = mrp_project_get_properties_from_type (data->project,
 							   MRP_TYPE_PROJECT);
@@ -1243,73 +1080,70 @@ mpp_property_dialog_label_changed_cb (GtkWidget *label_entry,
 }
 
 static void
-mpp_property_dialog_setup_option_menu (GtkWidget     *option_menu,
-				       GCallback      func,
-				       gpointer       user_data,
-				       gconstpointer  str1, ...)
+type_combo_get_name (GtkCellLayout   *layout,
+                     GtkCellRenderer *cell,
+                     GtkTreeModel    *model,
+                     GtkTreeIter     *iter,
+                     gpointer         user_data)
 {
-	GtkWidget     *menu;
-	GtkWidget     *menu_item;
-	gint           i;
-	va_list        args;
-	gconstpointer  str;
-	gint           type;
-
-       	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-	if (menu) {
-		gtk_widget_destroy (menu);
-	}
-
-	menu = gtk_menu_new ();
-
-	va_start (args, str1);
-	for (str = str1, i = 0; str != NULL; str = va_arg (args, gpointer), i++) {
-		menu_item = gtk_menu_item_new_with_label (str);
-		gtk_widget_show (menu_item);
-		gtk_menu_append (GTK_MENU (menu), menu_item);
-
-		type = va_arg (args, gint);
-
-		g_object_set_data (G_OBJECT (menu_item),
-				   "data",
-				   GINT_TO_POINTER (type));
-		if (func) {
-			g_signal_connect (menu_item,
-					  "activate",
-					  func,
-					  user_data);
-		}
-	}
-	va_end (args);
-
-	gtk_widget_show (menu);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-}
-
-static gint
-mpp_property_dialog_get_selected (GtkWidget *option_menu)
-{
-	GtkWidget *menu;
-	GtkWidget *item;
-	gint       ret;
-
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-
-	item = gtk_menu_get_active (GTK_MENU (menu));
-
-	ret = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "data"));
-
-	return ret;
+	gchar *name;
+	gtk_tree_model_get (model, iter, 0, &name, -1);
+	g_object_set (cell, "text", name, NULL);
 }
 
 static void
-mpp_property_dialog_type_selected_cb (GtkWidget *widget, GtkWidget *dialog)
+mpp_property_dialog_setup_combobox (GtkWidget     *combo,
+                                    gconstpointer  str1,
+                                    ...)
 {
-	gint type;
+	GtkListStore    *store;
+	GtkTreeIter      iter;
+	gint             i;
+	va_list          args;
+	gconstpointer    str;
+	gint             type;
+	GtkCellRenderer *renderer;
 
-	type = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "data"));
+	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
+	gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+	g_object_unref (store);
 
-	g_object_set_data (G_OBJECT (dialog), "type", GINT_TO_POINTER (type));
+	va_start (args, str1);
+	for (str = str1, i = 0; str != NULL; str = va_arg (args, gpointer), i++) {
+		type = va_arg (args, gint);
+
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+				    0, str,
+				    1, type,
+				    -1);
+	}
+	va_end (args);
+
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo),
+				    renderer, TRUE);
+	gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
+					    renderer,
+					    type_combo_get_name,
+					    NULL, NULL);
+}
+
+static gint
+mpp_property_dialog_get_selected (GtkWidget *combo)
+{
+	GtkTreeIter iter;
+	gint        ret;
+
+	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter);
+	gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (combo)),
+			    &iter,
+			    1, &ret,
+			    -1);
+
+	return ret;
 }
 
 static void
@@ -1320,35 +1154,28 @@ mpp_add_property_button_clicked_cb (GtkButton *button, GtkWidget *dialog)
 	const gchar     *label;
 	const gchar     *name;
 	const gchar     *description;
-	GladeXML        *glade;
+	GtkBuilder      *builder;
 	GtkWidget       *label_entry;
 	GtkWidget       *name_entry;
 	GtkWidget       *add_dialog;
 	GtkWidget       *w;
 	gint             response;
 	gboolean         finished = FALSE;
-	gchar           *filename;
 
-	filename = mrp_paths_get_glade_dir ("new-property.glade");
-	glade = glade_xml_new (filename,
-			       NULL,
-			       NULL);
-	g_free (filename);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/ui/new-property.ui");
 
-	add_dialog = glade_xml_get_widget (glade, "add_dialog");
+	add_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "add_dialog"));
 
-	label_entry = glade_xml_get_widget (glade, "label_entry");
-	name_entry = glade_xml_get_widget (glade, "name_entry");
+	label_entry = GTK_WIDGET (gtk_builder_get_object (builder, "label_entry"));
+	name_entry = GTK_WIDGET (gtk_builder_get_object (builder, "name_entry"));
 
 	g_signal_connect (label_entry,
 			  "focus_out_event",
 			  G_CALLBACK (mpp_property_dialog_label_changed_cb),
 			  name_entry);
 
-	mpp_property_dialog_setup_option_menu (
-		glade_xml_get_widget (glade, "type_menu"),
-		G_CALLBACK (mpp_property_dialog_type_selected_cb),
-		add_dialog,
+	mpp_property_dialog_setup_combobox (
+		GTK_WIDGET (gtk_builder_get_object (builder, "type_menu")),
 		mrp_property_type_as_string (MRP_PROPERTY_TYPE_STRING),
 		MRP_PROPERTY_TYPE_STRING,
 		mrp_property_type_as_string (MRP_PROPERTY_TYPE_INT),
@@ -1397,10 +1224,10 @@ mpp_add_property_button_clicked_cb (GtkButton *button, GtkWidget *dialog)
 				break;
 			}
 
-			w = glade_xml_get_widget (glade, "description_entry");
+			w = GTK_WIDGET (gtk_builder_get_object (builder, "description_entry"));
 			description = gtk_entry_get_text (GTK_ENTRY (w));
 
-			w = glade_xml_get_widget (glade, "type_menu");
+			w = GTK_WIDGET (gtk_builder_get_object (builder, "type_menu"));
 
 			type = mpp_property_dialog_get_selected (w);
 
@@ -1428,7 +1255,8 @@ mpp_add_property_button_clicked_cb (GtkButton *button, GtkWidget *dialog)
 		}
 	}
 
- 	gtk_widget_destroy (add_dialog);
+	gtk_widget_destroy (add_dialog);
+	g_object_unref (builder);
 }
 
 static void
@@ -1535,30 +1363,19 @@ mpp_dialog_destroy_cb (GtkWidget *dialog,
 GtkWidget *
 planner_project_properties_new (PlannerWindow *window)
 {
-	GladeXML    *glade;
+	GtkBuilder  *builder;
 	GtkWidget   *dialog;
 	GtkWidget   *w;
 	DialogData  *data;
 	mrptime      start;
 	gchar       *name, *org, *manager;
 	MrpCalendar *calendar;
-	GtkWidget   *hbox;
-	gchar       *filename;
 
 	g_return_val_if_fail (PLANNER_IS_WINDOW (window), NULL);
 
-	filename = mrp_paths_get_glade_dir ("project-properties.glade");
-	glade = glade_xml_new (filename,
-			       "project_properties",
-			       GETTEXT_PACKAGE);
-	g_free (filename);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/ui/project-properties.ui");
 
-	if (!glade) {
-		g_warning (_("Could not create properties dialog."));
-		return NULL;
-	}
-
-	dialog = glade_xml_get_widget (glade, "project_properties");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "project_properties"));
 
 	data = g_new0 (DialogData, 1);
 
@@ -1566,7 +1383,7 @@ planner_project_properties_new (PlannerWindow *window)
 	data->project = planner_window_get_project (window);
 	data->dialog = dialog;
 
-	g_signal_connect_object (glade_xml_get_widget (glade, "close_button"),
+	g_signal_connect_object (GTK_WIDGET (gtk_builder_get_object (builder, "close_button")),
 				 "clicked",
 				 G_CALLBACK (mpp_parent_destroy_cb),
 				 dialog,
@@ -1583,32 +1400,25 @@ planner_project_properties_new (PlannerWindow *window)
 			  G_CALLBACK (mpp_dialog_destroy_cb),
 			  NULL);
 
-	data->name_entry = glade_xml_get_widget (glade, "entry_name");
-	data->org_entry = glade_xml_get_widget (glade, "entry_org");
-	data->manager_entry = glade_xml_get_widget (glade, "entry_manager");
-	hbox = glade_xml_get_widget (glade, "hbox_start");
-	data->start_entry = glade_xml_get_widget (glade, "entry_start");
-	data->start_button = planner_popup_button_new (_("Date..."));
-	data->phase_option_menu = glade_xml_get_widget (glade, "optionmenu_phase");
-	data->calendar_label = glade_xml_get_widget (glade, "label_calendar");
-	data->properties_tree = GTK_TREE_VIEW (glade_xml_get_widget (glade, "properties_tree"));
+	data->name_entry = GTK_WIDGET (gtk_builder_get_object (builder, "entry_name"));
+	data->org_entry = GTK_WIDGET (gtk_builder_get_object (builder, "entry_org"));
+	data->manager_entry = GTK_WIDGET (gtk_builder_get_object (builder, "entry_manager"));
+	data->start_entry = GTK_WIDGET (gtk_builder_get_object (builder, "entry_start"));
+	data->start_popover = GTK_WIDGET (gtk_builder_get_object (builder, "calendar_popover"));
+	data->phase_combo_box_text = GTK_WIDGET (gtk_builder_get_object (builder, "comboboxtext_phase"));
+	data->calendar_label = GTK_WIDGET (gtk_builder_get_object (builder, "label_calendar"));
+	data->properties_tree = GTK_TREE_VIEW (gtk_builder_get_object (builder, "properties_tree"));
 
-	data->add_property_button = glade_xml_get_widget (glade,
-							  "add_property_button");
-	data->remove_property_button = glade_xml_get_widget (glade,
-							     "remove_property_button");
+	data->add_property_button = GTK_WIDGET (gtk_builder_get_object (builder,
+									"add_property_button"));
+	data->remove_property_button = GTK_WIDGET (gtk_builder_get_object (builder,
+									   "remove_property_button"));
 
-	gtk_box_pack_start (GTK_BOX (hbox), data->start_button, FALSE, FALSE, 0);
-
-	g_signal_connect (data->start_button,
-			  "popup",
-			  G_CALLBACK (mpp_start_button_popup_cb),
-			  dialog);
-
-	g_signal_connect (data->start_button,
-			  "popdown",
-			  G_CALLBACK (mpp_start_button_popdown_cb),
-			  dialog);
+	g_signal_connect_object (data->start_popover,
+				 "closed",
+				 G_CALLBACK (mpp_start_popover_closed_cb),
+				 dialog,
+				 G_CONNECT_SWAPPED);
 
 	g_object_set_data_full (G_OBJECT (dialog), "data", data, g_free);
 	g_object_set_data (G_OBJECT (dialog), "project", data->project);
@@ -1621,6 +1431,9 @@ planner_project_properties_new (PlannerWindow *window)
 
 	start = mrp_project_get_project_start (data->project);
 	mpp_set_start (dialog, start);
+	g_object_set (data->start_popover,
+		      "mrptime", start,
+		      NULL);
 	g_signal_connect (data->start_entry,
 			  "focus_out_event",
 			  G_CALLBACK (mpp_start_focus_out_event_cb),
@@ -1653,9 +1466,9 @@ planner_project_properties_new (PlannerWindow *window)
 	/* Project phase. */
 	mpp_setup_phases (data);
 
-	g_signal_connect (data->phase_option_menu,
+	g_signal_connect (data->phase_combo_box_text,
 			  "changed",
-			  G_CALLBACK (mpp_phase_option_menu_changed_cb),
+			  G_CALLBACK (mpp_phase_combo_box_text_changed_cb),
 			  dialog);
 	g_signal_connect (data->add_property_button,
 			  "clicked",
@@ -1674,7 +1487,7 @@ planner_project_properties_new (PlannerWindow *window)
 	gtk_label_set_text (GTK_LABEL (data->calendar_label),
 			    mrp_calendar_get_name (calendar));
 
-	w = glade_xml_get_widget (glade, "button_calendar");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "button_calendar"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (mpp_select_calendar_clicked_cb),
@@ -1688,7 +1501,7 @@ planner_project_properties_new (PlannerWindow *window)
 
 	gtk_widget_show_all (dialog);
 
-	g_object_unref (glade);
+	g_object_unref (builder);
 
 	return dialog;
 }
