@@ -20,11 +20,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_PROJECT_PROPERTIES_H__
-#define __PLANNER_PROJECT_PROPERTIES_H__
+#pragma once
 
 #include "planner-window.h"
 
 GtkWidget * planner_project_properties_new (PlannerWindow *window);
-
-#endif /* __PLANNER_PROJECT_PROPERTIES_H__ */
