@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -28,14 +28,13 @@
 #include <string.h>
 #include <stdlib.h>
 #include <glib/gi18n.h>
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <libplanner/mrp-object.h>
 #include <libplanner/mrp-property.h>
 #include "libplanner/mrp-paths.h"
-#include "planner-cell-renderer-list.h"
 #include "planner-property-dialog.h"
 #include "planner-property-model.h"
+#include "planner-util.h"
 
 #define GET_PRIV(d) (g_object_get_data (G_OBJECT (d), "priv"))
 
@@ -90,16 +89,12 @@ typedef struct {
 } PropertyCmdLabelEdited;
 
 
-static void        property_dialog_setup_option_menu    (GtkWidget           *option_menu,
-							 GCallback            func,
-							 gpointer             user_data,
+static void        property_dialog_setup_combobox       (GtkWidget           *combo,
 							 gconstpointer        str1,
 							 ...);
-static gint        property_dialog_get_selected         (GtkWidget           *option_menu);
+static gint        property_dialog_get_selected         (GtkWidget           *combo);
 static void        property_dialog_close_cb             (GtkWidget           *button,
 							 GtkWidget           *dialog);
-static void        property_dialog_type_selected_cb     (GtkWidget           *widget,
-							 GtkWidget           *dialog);
 static gboolean    property_dialog_label_changed_cb     (GtkWidget           *label_entry,
 							 GdkEvent            *event,
 							 GtkWidget           *name_entry);
@@ -113,7 +108,7 @@ static void        property_dialog_label_edited         (GtkCellRendererText *ce
 							 GtkWidget           *dialog);
 static void        property_dialog_setup_list           (GtkWidget           *dialog);
 static void        property_dialog_setup_widgets        (GtkWidget           *dialog,
-							 GladeXML            *glade);
+							 GtkBuilder          *builder);
 static PlannerCmd *property_cmd_add                     (PlannerWindow       *window,
 							 MrpProject          *project,
 							 GType                owner,
@@ -143,61 +138,68 @@ static void        property_cmd_label_edited_free       (PlannerCmd          *cm
 
 
 static void
-property_dialog_setup_option_menu (GtkWidget     *option_menu,
-				   GCallback      func,
-				   gpointer       user_data,
-				   gconstpointer  str1, ...)
+type_combo_get_name (GtkCellLayout   *layout,
+                     GtkCellRenderer *cell,
+                     GtkTreeModel    *model,
+                     GtkTreeIter     *iter,
+                     gpointer         user_data)
 {
-	GtkWidget     *menu;
-	GtkWidget     *menu_item;
-	gint           i;
-	va_list        args;
-	gconstpointer  str;
-	gint           type;
+	gchar *name;
+	gtk_tree_model_get (model, iter, 0, &name, -1);
+	g_object_set (cell, "text", name, NULL);
+}
 
-       	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-	if (menu) {
-		gtk_widget_destroy (menu);
-	}
+static void
+property_dialog_setup_combobox (GtkWidget     *combo,
+                                gconstpointer  str1,
+                                ...)
+{
+	GtkListStore    *store;
+	GtkTreeIter      iter;
+	gint             i;
+	va_list          args;
+	gconstpointer    str;
+	gint             type;
+	GtkCellRenderer *renderer;
 
-	menu = gtk_menu_new ();
+	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
+	gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+	g_object_unref (store);
 
 	va_start (args, str1);
 	for (str = str1, i = 0; str != NULL; str = va_arg (args, gpointer), i++) {
-		menu_item = gtk_menu_item_new_with_label (str);
-		gtk_widget_show (menu_item);
-		gtk_menu_append (GTK_MENU (menu), menu_item);
-
 		type = va_arg (args, gint);
 
-		g_object_set_data (G_OBJECT (menu_item),
-				   "data",
-				   GINT_TO_POINTER (type));
-		if (func) {
-			g_signal_connect (menu_item,
-					  "activate",
-					  func,
-					  user_data);
-		}
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+				    0, str,
+				    1, type,
+				    -1);
 	}
 	va_end (args);
 
-	gtk_widget_show (menu);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo),
+				    renderer, TRUE);
+	gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
+					    renderer,
+					    type_combo_get_name,
+					    NULL, NULL);
 }
 
 static gint
-property_dialog_get_selected (GtkWidget *option_menu)
+property_dialog_get_selected (GtkWidget *combo)
 {
-	GtkWidget *menu;
-	GtkWidget *item;
-	gint       ret;
+	GtkTreeIter iter;
+	gint        ret;
 
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-
-	item = gtk_menu_get_active (GTK_MENU (menu));
-
-	ret = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "data"));
+	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter);
+	gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (combo)),
+			    &iter,
+			    1, &ret,
+			    -1);
 
 	return ret;
 }
@@ -209,17 +211,6 @@ property_dialog_close_cb (GtkWidget *button,
 	gtk_widget_destroy (dialog);
 }
 
-static void
-property_dialog_type_selected_cb (GtkWidget *widget,
-				  GtkWidget *dialog)
-{
-	gint type;
-
-	type = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "data"));
-
-	g_object_set_data (G_OBJECT (dialog), "type", GINT_TO_POINTER (type));
-}
-
 static gboolean
 property_dialog_label_changed_cb (GtkWidget *label_entry,
 				  GdkEvent  *event,
@@ -247,7 +238,7 @@ property_dialog_add_cb (GtkWidget *button,
 	const gchar               *label;
 	const gchar               *name;
 	const gchar               *description;
-	GladeXML                  *glade;
+	GtkBuilder                *builder;
 	GtkWidget                 *label_entry;
 	GtkWidget                 *name_entry;
 	GtkWidget                 *add_dialog;
@@ -255,30 +246,22 @@ property_dialog_add_cb (GtkWidget *button,
 	gint                       response;
 	gboolean                   finished = FALSE;
 	gunichar                   c;
-	gchar                     *filename;
 
 	priv = GET_PRIV (dialog);
 
-	filename = mrp_paths_get_glade_dir ("new-property.glade");
-	glade = glade_xml_new (filename,
-			       NULL,
-			       NULL);
-	g_free (filename);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/ui/new-property.ui");
 
-	add_dialog = glade_xml_get_widget (glade, "add_dialog");
-
-	label_entry = glade_xml_get_widget (glade, "label_entry");
-	name_entry = glade_xml_get_widget (glade, "name_entry");
+	add_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "add_dialog"));
+	label_entry = GTK_WIDGET (gtk_builder_get_object (builder, "label_entry"));
+	name_entry = GTK_WIDGET (gtk_builder_get_object (builder, "name_entry"));
 
 	g_signal_connect (label_entry,
 			  "focus_out_event",
 			  G_CALLBACK (property_dialog_label_changed_cb),
 			  name_entry);
 
-	property_dialog_setup_option_menu (
-		glade_xml_get_widget (glade, "type_menu"),
-		G_CALLBACK (property_dialog_type_selected_cb),
-		add_dialog,
+	property_dialog_setup_combobox (
+		GTK_WIDGET (gtk_builder_get_object (builder, "type_menu")),
 		mrp_property_type_as_string (MRP_PROPERTY_TYPE_STRING),
 		MRP_PROPERTY_TYPE_STRING,
 		mrp_property_type_as_string (MRP_PROPERTY_TYPE_INT),
@@ -329,10 +312,10 @@ property_dialog_add_cb (GtkWidget *button,
 				break;
 			}
 
-			w = glade_xml_get_widget (glade, "description_entry");
+			w = GTK_WIDGET (gtk_builder_get_object (builder, "description_entry"));
 			description = gtk_entry_get_text (GTK_ENTRY (w));
 
-			w = glade_xml_get_widget (glade, "type_menu");
+			w = GTK_WIDGET (gtk_builder_get_object (builder, "type_menu"));
 			type = property_dialog_get_selected (w);
 
 			if (type != MRP_PROPERTY_TYPE_NONE) {
@@ -359,8 +342,8 @@ property_dialog_add_cb (GtkWidget *button,
 		}
 	}
 
- 	gtk_widget_destroy (add_dialog);
-	g_object_unref (glade);
+	gtk_widget_destroy (add_dialog);
+	g_object_unref (builder);
 }
 
 static void
@@ -519,33 +502,33 @@ property_dialog_setup_list (GtkWidget *dialog)
 }
 
 static void
-property_dialog_setup_widgets (GtkWidget *dialog,
-			       GladeXML  *glade)
+property_dialog_setup_widgets (GtkWidget  *dialog,
+			       GtkBuilder *builder)
 {
 	PlannerPropertyDialogPriv *priv;
 	GtkWidget            *w;
 
 	priv = GET_PRIV (dialog);
 
-	w = glade_xml_get_widget (glade, "close_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "close_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (property_dialog_close_cb),
 			  dialog);
 
-	w = glade_xml_get_widget (glade, "add_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "add_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (property_dialog_add_cb),
 			  dialog);
 
-	w = glade_xml_get_widget (glade, "remove_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "remove_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (property_dialog_remove_cb),
 			  dialog);
 
-	w = glade_xml_get_widget (glade, "treeview");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "treeview"));
 	priv->tree = w;
 
 	property_dialog_setup_list (dialog);
@@ -557,21 +540,17 @@ planner_property_dialog_new (PlannerWindow *main_window,
 			     GType          owner,
 			     const gchar   *title)
 {
-	GladeXML                  *glade;
+	GtkBuilder                *builder;
 	GtkWidget                 *dialog;
 	PlannerPropertyDialogPriv *priv;
-	gchar                     *filename;
 
 	g_return_val_if_fail (MRP_IS_PROJECT (project), NULL);
 
 	priv = g_new0 (PlannerPropertyDialogPriv, 1);
 
-	filename = mrp_paths_get_glade_dir ("property-dialog.glade");
-	glade = glade_xml_new (filename,
-			       NULL, NULL);
-	g_free (filename);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/ui/property-dialog.ui");
 
-	dialog = glade_xml_get_widget (glade, "dialog");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "dialog"));
 
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
 
@@ -581,9 +560,9 @@ planner_property_dialog_new (PlannerWindow *main_window,
 	priv->project = project;
 	priv->owner = owner;
 
-	property_dialog_setup_widgets (dialog, glade);
+	property_dialog_setup_widgets (dialog, builder);
 
-	g_object_unref (glade);
+	g_object_unref (builder);
 
 	return dialog;
 }
