@@ -19,8 +19,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_PROPERTY_DIALOG_H__
-#define __PLANNER_PROPERTY_DIALOG_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libplanner/mrp-project.h>
@@ -34,6 +33,3 @@ void       planner_property_dialog_value_edited (GtkCellRendererText *cell,
 						 gchar               *path_str,
 						 gchar               *new_text,
 						 gpointer             data);
-
-
-#endif /* __PLANNER_PROPERTY_DIALOG_H__ */
