@@ -29,8 +29,6 @@
 #include "planner-gantt-row.h"
 #include "planner-relation-arrow.h"
 
-#undef USE_AFFINE
-
 #define MIN_SPACING 4
 #define ARROW_SIZE 6
 
@@ -129,21 +127,19 @@ static void    relation_arrow_set_property (GObject               *object,
 					    const GValue          *value,
 					    GParamSpec            *pspec);
 static void    relation_arrow_update       (GnomeCanvasItem       *item,
-					    gdouble               *affine,
-					    ArtSVP                *clip_path,
+					    const cairo_matrix_t  *i2c,
 					    gint                   flags);
 static void    relation_arrow_draw         (GnomeCanvasItem       *item,
-					    GdkDrawable           *drawable,
+					    cairo_t               *cr,
 					    gint                   x,
 					    gint                   y,
 					    gint                   width,
 					    gint                   height);
-static gdouble relation_arrow_point        (GnomeCanvasItem       *item,
-					    gdouble                x,
-					    gdouble                y,
-					    gint                   cx,
-					    gint                   cy,
-					    GnomeCanvasItem      **actual_item);
+static GnomeCanvasItem * relation_arrow_point (GnomeCanvasItem  *item,
+                                               gdouble           x,
+                                               gdouble           y,
+                                               gint              cx,
+                                               gint              cy);
 
 /* Properties */
 enum {
@@ -638,10 +634,9 @@ relation_arrow_get_bounds (PlannerRelationArrow *arrow,
 }
 
 static void
-relation_arrow_update (GnomeCanvasItem *item,
-		       double          *affine,
-		       ArtSVP          *clip_path,
-		       gint             flags)
+relation_arrow_update (GnomeCanvasItem      *item,
+                       const cairo_matrix_t *i2c,
+                       gint                  flags)
 {
 	PlannerRelationArrow *arrow;
 	gdouble               x1, y1, x2, y2;
@@ -649,8 +644,7 @@ relation_arrow_update (GnomeCanvasItem *item,
 	arrow = PLANNER_RELATION_ARROW (item);
 
 	GNOME_CANVAS_ITEM_CLASS (parent_class)->update (item,
-							affine,
-							clip_path,
+							i2c,
 							flags);
 
 	relation_arrow_get_bounds (arrow, &x1, &y1, &x2, &y2);
@@ -660,52 +654,34 @@ relation_arrow_update (GnomeCanvasItem *item,
 
 static void
 relation_arrow_setup_arrow (PlannerArrowDir dir,
-			    GdkPoint        points[4],
-			    gdouble         cx1,
-			    gdouble         cy1,
-			    gdouble         cx2,
-			    gdouble         cy2)
+			    cairo_t        *cr,
+			    gdouble         x,
+			    gdouble         y)
 {
 	switch (dir) {
 	case PLANNER_ARROW_DOWN:
-		points[0].x = cx2;
-		points[0].y = cy2;
-		points[1].x = cx2 - ARROW_SIZE / 2;
-		points[1].y = cy2 - ARROW_SIZE;
-		points[2].x = cx2 + ARROW_SIZE / 2;
-		points[2].y = cy2 - (ARROW_SIZE - 1);
-		points[3].x = cx2;
-		points[3].y = cy2 + 1;
+		cairo_move_to (cr, x, y + 0.5);
+		cairo_rel_line_to (cr, - (ARROW_SIZE / 2 + 0.5), - (ARROW_SIZE + 1.0));
+		cairo_rel_line_to (cr, ARROW_SIZE + 1.0, 0.0);
+		cairo_close_path (cr);
 		break;
 	case PLANNER_ARROW_UP:
-		points[0].x = cx2;
-		points[0].y = cy2 + 1;
-		points[1].x = cx2 + ARROW_SIZE / 2;
-		points[1].y = cy2 + ARROW_SIZE;
-		points[2].x = cx2 - ARROW_SIZE / 2;
-		points[2].y = cy2 + ARROW_SIZE;
-		points[3].x = cx2 + 1;
-		points[3].y = cy2;
+		cairo_move_to (cr, x, y - 0.5);
+		cairo_rel_line_to (cr, - (ARROW_SIZE / 2 + 0.5), ARROW_SIZE + 1.0);
+		cairo_rel_line_to (cr, ARROW_SIZE + 1.0, 0.0);
+		cairo_close_path (cr);
 		break;
 	case PLANNER_ARROW_RIGHT:
-		points[0].x = cx2;
-		points[0].y = cy2;
-		points[1].x = cx2 - ARROW_SIZE;
-		points[1].y = cy2 + ARROW_SIZE / 2;
-		points[2].x = cx2 - ARROW_SIZE;
-		points[2].y = cy2 - ARROW_SIZE / 2;
-		points[3].x = cx2;
-		points[3].y = cy2;
+		cairo_move_to (cr, x + 0.5, y);
+		cairo_rel_line_to (cr, -(ARROW_SIZE + 1.0), - (ARROW_SIZE / 2 + 0.5));
+		cairo_rel_line_to (cr, 0.0, ARROW_SIZE + 1.0);
+		cairo_close_path (cr);
 		break;
 	case PLANNER_ARROW_LEFT:
-		points[0].x = cx2;
-		points[0].y = cy2;
-		points[1].x = cx2 + (ARROW_SIZE - 0);
-		points[1].y = cy2 + ARROW_SIZE / 2;
-		points[2].x = cx2 + (ARROW_SIZE - 0);
-		points[2].y = cy2 - ARROW_SIZE / 2;
-		points[3].x = cx2;
-		points[3].y = cy2;
+		cairo_move_to (cr, x - 0.5, y);
+		cairo_rel_line_to (cr, ARROW_SIZE + 1.0, - (ARROW_SIZE / 2 + 0.5));
+		cairo_rel_line_to (cr, 0.0, ARROW_SIZE + 1.0);
+		cairo_close_path (cr);
 		break;
 	default:
 		g_assert_not_reached ();
@@ -715,7 +691,7 @@ relation_arrow_setup_arrow (PlannerArrowDir dir,
 
 static void
 relation_arrow_draw (GnomeCanvasItem *item,
-		     GdkDrawable     *drawable,
+		     cairo_t         *cr,
 		     gint             x,
 		     gint             y,
 		     gint             width,
@@ -723,28 +699,19 @@ relation_arrow_draw (GnomeCanvasItem *item,
 {
 	PlannerRelationArrow     *arrow;
 	PlannerRelationArrowPriv *priv;
-#ifdef USE_AFFINE
-	gdouble                   i2c[6];
-	ArtPoint                  i1, i2, c1, c2;
-#else
 	gdouble                   i2w_dx;
 	gdouble                   i2w_dy;
 	gdouble                   dx1, dy1, dx2, dy2;
-#endif
 	gint                      cx1, cy1, cx2, cy2;
-	GdkGC                    *gc;
-	GdkPoint                  points[4];
 	gint                      i;
 
 	arrow = PLANNER_RELATION_ARROW (item);
 	priv = arrow->priv;
 
-	gc = gdk_gc_new (drawable);
-	gdk_gc_set_line_attributes (gc,
-				    0,
-				    GDK_LINE_SOLID,
-				    GDK_CAP_BUTT,
-				    GDK_JOIN_MITER);
+	cairo_save (cr);
+	cairo_set_line_width (cr, 1.0);
+	cairo_set_line_cap (cr, CAIRO_LINE_CAP_SQUARE);
+	cairo_set_line_join (cr, CAIRO_LINE_JOIN_MITER);
 
 	/* Silence warning. */
 	cx1 = 0;
@@ -752,24 +719,7 @@ relation_arrow_draw (GnomeCanvasItem *item,
 	cx2 = 0;
 	cy2 = 0;
 
-#ifdef USE_AFFINE
-	/* Get item area in canvas coordinates. */
-	gnome_canvas_item_i2c_affine (item, i2c);
-#endif
-
 	for (i = 0; i < priv->num_points - 1; i++) {
-#ifdef USE_AFFINE
-		i1.x = priv->points[i].x;
-		i1.y = priv->points[i].y;
-		i2.x = priv->points[i+1].x;
-		i2.y = priv->points[i+1].y;
-		art_affine_point (&c1, &i1, i2c);
-		art_affine_point (&c2, &i2, i2c);
-		cx1 = floor (c1.x + 0.5) - x;
-		cy1 = floor (c1.y + 0.5) - y;
-		cx2 = floor (c2.x + 0.5) - x;
-		cy2 = floor (c2.y + 0.5) - y;
-#else
 		i2w_dx = 0.0;
 		i2w_dy = 0.0;
 		gnome_canvas_item_i2w (item, &i2w_dx, &i2w_dy);
@@ -795,42 +745,29 @@ relation_arrow_draw (GnomeCanvasItem *item,
 		cy1 -= y;
 		cx2 -= x;
 		cy2 -= y;
-#endif
 
-		gdk_draw_line (drawable,
-			       gc,
-			       cx1,
-			       cy1,
-			       cx2,
-			       cy2);
+		cairo_move_to (cr, cx1 + 0.5, cy1 + 0.5);
+		cairo_line_to (cr, cx2 + 0.5, cy2 + 0.5);
+		cairo_stroke (cr);
 	}
 
 	relation_arrow_setup_arrow (priv->arrow_dir,
-					points,
-					cx1,
-					cy1,
-					cx2,
-					cy2);
+				    cr,
+				    cx2 + 0.5, cy2 + 0.5);
+	cairo_fill (cr);
 
-	gdk_draw_polygon (drawable,
-			  gc,
-			  TRUE,
-			  (GdkPoint *) &points,
-			  4);
-
-	g_object_unref (gc);
+	cairo_restore (cr);
 }
 
-static double
+static GnomeCanvasItem *
 relation_arrow_point (GnomeCanvasItem  *item,
 		      gdouble           x,
 		      gdouble           y,
 		      gint              cx,
-		      gint              cy,
-		      GnomeCanvasItem **actual_item)
+		      gint              cy)
 {
-	*actual_item = item;
-
-	return 10.0;
+	/* TODO: Test over the behaviour from gnomecanvas gtk3 port;
+	 * it was reporting distance of 10.0 before */
+	return NULL;
 }
 
