@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_RELATION_ARROW_H__
-#define __PLANNER_RELATION_ARROW_H__
+#pragma once
 
 #include <glib-object.h>
 #include <libgnomecanvas/gnome-canvas.h>
@@ -60,7 +59,3 @@ planner_relation_arrow_set_successor             (PlannerRelationArrow *arrow,
 void
 planner_relation_arrow_set_predecessor           (PlannerRelationArrow *arrow,
 					     PlannerGanttRow      *predecessor);
-
-
-#endif /* __PLANNER_RELATION_ARROW_H__ */
-
