@@ -21,12 +21,9 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_RESOURCE_DIALOG_H__
-#define __PLANNER_RESOURCE_DIALOG_H__
+#pragma once
 
 #include "planner-window.h"
 
 GtkWidget * planner_resource_dialog_new (PlannerWindow *window,
 					 MrpResource  *resource);
-
-#endif /* __PLANNER_RESOURCE_DIALOG_H__ */
