@@ -21,20 +21,9 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_RESOURCE_INPUT_DIALOG_H__
-#define __PLANNER_RESOURCE_INPUT_DIALOG_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include "planner-window.h"
 
 GtkWidget * planner_resource_input_dialog_new (PlannerWindow *main_window);
-
-#endif /* __PLANNER_RESOURCE_INPUT_DIALOG_H__ */
-
-
-
-
-
-
-
-
