@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_SIDEBAR_H__
-#define __PLANNER_SIDEBAR_H__
+#pragma once
 
 #include <gtk/gtk.h>
 
@@ -58,7 +57,3 @@ void       planner_sidebar_append       (PlannerSidebar   *sidebar,
 
 void       planner_sidebar_set_active   (PlannerSidebar   *sidebar,
 				    gint         index);
-
-
-#endif /* __PLANNER_SIDEBAR_H__ */
-
