@@ -27,17 +27,16 @@
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <libgda/libgda.h>
+#include <libgda/sql-parser/gda-sql-parser.h>
 #include <libplanner/mrp-paths.h>
 
-#include "planner-conf.h"
+#include <gio/gio.h>
 #include "planner-window.h"
 #include "planner-application.h"
 #include "planner-plugin.h"
-
-#define d(x)
+#include "app.drey.Planner.plugin.sql.h"
 
 #define SERVER     "sql-plugin-server"
 #define DATABASE   "sql-plugin-database"
@@ -46,11 +45,13 @@
 #define PASSWORD   "sql-plugin-password"
 #define PROJECT_ID "sql-plugin-project-id"
 
-#define CONF_SERVER "/plugins/sql/server"
-#define CONF_DATABASE "/plugins/sql/database"
-#define CONF_USERNAME "/plugins/sql/username"
+static const gchar *SQL_PLUGIN_SCHEMA_ID = "app.drey.Planner.plugins.sql";
+static const gchar *CONF_SERVER = "server";
+static const gchar *CONF_DATABASE = "database";
+static const gchar *CONF_USERNAME = "username";
 
 #define CONNECTION_FORMAT_STRING "HOST=%s;DB_NAME=%s"
+#define AUTH_FORMAT_STRING "USERNAME=%s;PASSWORD=%s"
 
 struct _PlannerPluginPriv {
 	GtkActionGroup *actions;
@@ -73,10 +74,10 @@ static void          sql_plugin_open                (GtkAction      *action,
 						     gpointer        user_data);
 static void          sql_plugin_save                (GtkAction      *action,
 						     gpointer        user_data);
-static GdaDataModel *sql_execute_query              (GdaConnection  *con,
-						     gchar          *query);
-static gboolean      sql_execute_command            (GdaConnection  *con,
-						     gchar          *command);
+static GdaDataModel *sql_execute_query              (GdaConnection  *cnc,
+						     gchar          *sql);
+static gboolean      sql_execute_command            (GdaConnection  *cnc,
+						     gchar          *sql);
 static const gchar * sql_get_last_error             (GdaConnection  *connection);
 void                 plugin_init                    (PlannerPlugin  *plugin);
 void                 plugin_exit                    (PlannerPlugin  *plugin);
@@ -98,46 +99,94 @@ static const GtkActionEntry entries[] = {
 	  G_CALLBACK (sql_plugin_save) }
 };
 
+/*
+ * sql_execute_batch:
+ * @cnc: a opened connection
+ * @sql: an SQL batch
+ *
+ * Executes all the statements contained in an SQL script over an opened connection.
+ *
+ * Returns: %TRUE on success, %FALSE on failure.
+ */
 static gboolean
-sql_execute_command (GdaConnection *con, gchar *command)
+sql_execute_batch (GdaConnection *cnc, gchar *sql)
 {
-	GdaCommand *cmd;
-	GList      *list;
-	GError     *error = NULL;
-
-	cmd = gda_command_new (command, GDA_COMMAND_TYPE_SQL, GDA_COMMAND_OPTION_STOP_ON_ERRORS);
-	list = gda_connection_execute_command (con, cmd, NULL, &error);
-	gda_command_free (cmd);
-
-	while (list) {
-		if (list->data) {
-			g_object_unref (list->data);
-		}
-		list = list->next;
-	}
-	g_list_free (list);
-
-	if(error != NULL) {
-		g_error_free (error);
-		return FALSE;
-	}
-	else
-	{
-		return TRUE;
-	}
+    GdaSqlParser *parser;
+    GdaBatch *batch;
+    GSList *list;
+    GError *error = NULL;
+    parser = gda_sql_parser_new ();
+    batch = gda_sql_parser_parse_string_as_batch (parser, sql, NULL, &error);
+    if (error) {
+        g_warning ("%s", error->message);
+        g_clear_error (&error);
+        g_object_unref (parser);
+        return FALSE;
+    }
+    list = gda_connection_batch_execute (cnc, batch, NULL, GDA_STATEMENT_MODEL_RANDOM_ACCESS, &error);
+    if (error) {
+        g_warning ("%s", error->message);
+        g_clear_error (&error);
+        g_object_unref (batch);
+        g_object_unref (parser);
+        return FALSE;
+    }
+    g_slist_free_full (list, g_object_unref);
+    g_object_unref (batch);
+    g_object_unref (parser);
+    return TRUE;
 }
 
-static GdaDataModel *
-sql_execute_query (GdaConnection *con, gchar *query)
+/*
+ * sql_execute_command:
+ * @cnc: an opened connection
+ * @sql: a query statement that must not begin with "SELECT"
+ *
+ * Execute a single non-SELECT SQL statement over an opened connection.
+ *
+ * libplanner/mrp-sql.c duplicates the code.
+ *
+ * Returns: %TRUE on success, %FALSE on failure.
+ *
+ * Deprecated: 0.14.6: Use gda_connection_execute_non_select_command() instead.
+ */
+static gboolean
+sql_execute_command (GdaConnection *cnc, gchar *sql)
 {
-	GdaCommand    *cmd;
-	GdaDataModel  *result;
+    GError *error = NULL;
+    gda_connection_execute_non_select_command (cnc, sql, &error);
+    if (error) {
+        g_warning ("%s", error->message);
+        g_clear_error (&error);
+        return FALSE;
+    }
+    return TRUE;
+}
 
-	cmd = gda_command_new (query, GDA_COMMAND_TYPE_SQL, GDA_COMMAND_OPTION_STOP_ON_ERRORS);
-	result = gda_connection_execute_select_command (con, cmd, NULL, NULL);
-	gda_command_free (cmd);
-
-	return result;
+/*
+ * sql_execute_query:
+ * @cnc: an opened connection
+ * @sql: a query statement that must begin with "SELECT"
+ *
+ * Execute an SQL SELECT command over an opened connection.
+ *
+ * libplanner/mrp-sql.c duplicates the code.
+ *
+ * Returns: (transfer full): a new #GdaDataModel if successful, %NULL otherwise
+ *
+ * Deprecated: 0.14.6: Use gda_connection_execute_select_command() instead.
+ */
+static GdaDataModel *
+sql_execute_query (GdaConnection *cnc, gchar *sql)
+{
+    GdaDataModel *result;
+    GError *error = NULL;
+    result = gda_connection_execute_select_command (cnc, sql, &error);
+    if (error) {
+        g_warning ("%s", error->message);
+        g_clear_error (&error);
+    }
+    return result;
 }
 
 static const gchar *
@@ -175,7 +224,7 @@ get_int (GdaDataModel *res, gint row, gint column)
 	GValue   *value;
 	gint      i;
 
-	value = (GValue *) gda_data_model_get_value_at (res, column, row);
+	value = (GValue *) gda_data_model_get_value_at (res, column, row, NULL);
 	if (value == NULL) {
 		g_warning ("Failed to get a value: (%d,%d)", column, row);
 		return INT_MAX;
@@ -199,7 +248,7 @@ get_string (GdaDataModel *res, gint row, gint column)
 	gsize     len;
 	GValue   *value;
 
-	value = (GValue *) gda_data_model_get_value_at (res, column, row);
+	value = (GValue *) gda_data_model_get_value_at (res, column, row, NULL);
 	if (value == NULL) {
 		g_warning ("Failed to get a value: (%d,%d)", column, row);
 		return "";
@@ -308,7 +357,6 @@ show_error_dialog (PlannerPlugin *plugin,
 {
 	GtkWindow *window;
 	GtkWidget *dialog;
-	gint       response;
 
 	window = GTK_WINDOW (plugin->main_window);
 
@@ -318,7 +366,7 @@ show_error_dialog (PlannerPlugin *plugin,
 					 GTK_BUTTONS_CLOSE,
 					 "%s", str);
 
-	response = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
 
@@ -407,10 +455,13 @@ check_database_tables (GdaConnection *conn,
 	const gchar  *database_name;
 	gboolean      retval = FALSE;
 	gchar        *sql_dir = mrp_paths_get_sql_dir ();
+	GSettings    *sql_settings;
 
 	max_version_database = g_strdup ("0.0");
 	max_version_upgrade = g_strdup ("0.0");
-	database_name = gda_connection_get_database (conn);
+	sql_settings = g_settings_new (SQL_PLUGIN_SCHEMA_ID);
+	database_name = g_settings_get_string (sql_settings, CONF_SERVER);
+	g_clear_object (&sql_settings);
 
 	window = GTK_WINDOW (plugin->main_window);
 
@@ -534,7 +585,7 @@ check_database_tables (GdaConnection *conn,
 		gtk_widget_destroy (dialog);
 		if (result == GTK_RESPONSE_YES) {
 			g_file_get_contents (upgrade_file, &contents, NULL, NULL);
-			success = sql_execute_command (conn, contents);
+			success = sql_execute_batch (conn, contents);
 			g_free (contents);
 			if (!success) {
 				dialog = gtk_message_dialog_new (window,
@@ -574,7 +625,7 @@ check_database_tables (GdaConnection *conn,
 		gchar  *contents;
 
 		g_file_get_contents (database_file, &contents, NULL, NULL);
-		success = sql_execute_command (conn, contents);
+		success = sql_execute_batch (conn, contents);
 		g_free (contents);
 		if (!success) {
 			dialog = gtk_message_dialog_new (window,
@@ -616,28 +667,29 @@ create_database (const gchar   *dsn_name,
 	guint              result;
 	gboolean           retval;
 	GdaConnection     *conn;
-	GdaClient         *client;
-	GdaDataSourceInfo *dsn;
-	gchar             *cnc_string_orig;
+	const GdaDsnInfo  *dsn;
+	gchar             *init_cnc;
 	/* FIXME: In postgresql we use template1 as the connection database */
 	gchar             *init_database = "template1";
 	gchar             *query;
-	GError            *error;
+	GError            *error = NULL;
 
-	dsn = gda_config_find_data_source (dsn_name);
-	cnc_string_orig = dsn->cnc_string;
+	dsn = gda_config_get_dsn_info (dsn_name);
 	retval = FALSE;
 
 	window = GTK_WINDOW (plugin->main_window);
 
 	/* Use same data but changing the database */
-	dsn->cnc_string = g_strdup_printf (CONNECTION_FORMAT_STRING, host, init_database);
-	gda_config_save_data_source_info (dsn);
+	init_cnc = g_strdup_printf (CONNECTION_FORMAT_STRING, host, init_database);
 
-	client = gda_client_new ();
-	conn = gda_client_open_connection (client, dsn_name, NULL, NULL, 0, &error);
+	conn = gda_connection_open_from_string(dsn->provider, init_cnc, dsn->auth_string, 0, &error);
+	if (error) {
+		g_warning ("%s", error->message);
+		g_clear_error (&error);
+	}
+	g_free(init_cnc);
 	if (conn == NULL) {
-		g_warning ("Can't connect to database server in order to check/create the database: %s", cnc_string_orig);
+		g_warning ("Can't connect to database server in order to check/create the database: %s", dsn->cnc_string);
 	} else {
 		dialog = gtk_message_dialog_new (window,
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -660,11 +712,7 @@ create_database (const gchar   *dsn_name,
 			retval = FALSE;
 		}
 		gda_connection_close (conn);
-		g_object_unref (client);
 	}
-	g_free (dsn->cnc_string);
-	dsn->cnc_string = cnc_string_orig;
-	gda_config_save_data_source_info (dsn);
 
 	return retval;
 }
@@ -674,24 +722,31 @@ static GdaConnection *
 sql_get_tested_connection (const gchar   *dsn_name,
 			   const gchar   *host,
 			   const gchar   *db_name,
-			   GdaClient     *client,
 			   PlannerPlugin *plugin)
 {
 	GdaConnection *conn = NULL;
 	gboolean       success;
 	gchar         *str;
-	GError        *error;
+	GError        *error = NULL;
 
-	conn = gda_client_open_connection (client, dsn_name, NULL, NULL, 0, &error);
+	conn = gda_connection_open_from_dsn (dsn_name, NULL, 0, &error);
+	if (error) {
+	    g_warning ("%s", error->message);
+	    g_clear_error (&error);
+	}
 
 	if (conn == NULL) {
 		if (!create_database (dsn_name, host, db_name, plugin)) {
 			str = g_strdup_printf (_("Connection to database '%s@%s' failed."),
 					       db_name, host);
 			show_error_dialog (plugin, str);
-			conn = NULL;
+			g_free (str);
 		} else {
-			conn = gda_client_open_connection (client, dsn_name, NULL, NULL, 0, &error);
+			conn = gda_connection_open_from_dsn (dsn_name, NULL, 0, &error);
+			if (error) {
+		            g_warning ("%s", error->message);
+		            g_clear_error (&error);
+			}
 		}
 	}
 
@@ -713,7 +768,6 @@ sql_get_tested_connection (const gchar   *dsn_name,
 		}
 	}
 
-	/* g_object_unref (client); */
 	return conn;
 
 out:
@@ -739,8 +793,7 @@ sql_plugin_retrieve_project_id (PlannerPlugin *plugin,
 	GdaConnection     *conn;
 	GdaDataModel      *model;
 	gboolean           success;
-	GdaClient         *client;
-	GladeXML          *gui;
+	GtkBuilder        *builder;
 	GtkWidget         *dialog;
 	GtkWidget         *treeview;
 	GtkWidget         *ok_button;
@@ -752,20 +805,9 @@ sql_plugin_retrieve_project_id (PlannerPlugin *plugin,
 	gint               project_id;
 	GtkTreeSelection  *selection;
 	GtkTreeIter        iter;
-	gchar             *db_txt;
 	const gchar       *dsn_name = "planner-auto";
-	const gchar       *provider = "PostgreSQL";
-	gchar             *filename;
 
-	db_txt = g_strdup_printf (CONNECTION_FORMAT_STRING,server,database);
-	gda_config_save_data_source (dsn_name,
-                                     provider,
-                                     db_txt,
-                                     "planner project", login, password, FALSE);
-	g_free (db_txt);
-
-	client = gda_client_new ();
-	conn = sql_get_tested_connection (dsn_name, server, database, client, plugin);
+	conn = sql_get_tested_connection (dsn_name, server, database, plugin);
 
 	if (conn == NULL) {
 		return -1;
@@ -793,18 +835,17 @@ sql_plugin_retrieve_project_id (PlannerPlugin *plugin,
 		return -1;
 	}
 
-	filename = mrp_paths_get_glade_dir ("sql.glade");
-	gui = glade_xml_new (filename, "select_dialog", NULL);
-	g_free (filename);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/plugin/sql/ui/sql-select-dialog.ui");
 
-	dialog = glade_xml_get_widget (gui, "select_dialog");
-	treeview = glade_xml_get_widget (gui, "project_treeview");
-	ok_button = glade_xml_get_widget (gui, "ok_button");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "select_dialog"));
+	treeview = GTK_WIDGET (gtk_builder_get_object (builder, "project_treeview"));
+	ok_button = GTK_WIDGET (gtk_builder_get_object (builder, "ok_button"));
 
-	g_object_unref (gui);
+	g_object_unref (builder);
 
 	liststore = gtk_list_store_new (4, G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL (liststore));
+	g_object_unref (liststore);
 
 	cell = gtk_cell_renderer_text_new ();
 	col = gtk_tree_view_column_new_with_attributes (_("ID"),
@@ -914,6 +955,7 @@ sql_plugin_retrieve_project_id (PlannerPlugin *plugin,
 	};
 
 	gtk_widget_destroy (dialog);
+	g_object_unref (builder);
 
 	return project_id;
 }
@@ -927,9 +969,7 @@ sql_plugin_retrieve_db_values (PlannerPlugin  *plugin,
 			       gchar         **login,
 			       gchar         **password)
 {
-	PlannerApplication *application;
-	gchar              *filename;
-	GladeXML           *gui;
+	GtkBuilder         *builder;
 	GtkWidget          *dialog;
 	gchar              *str;
 	gint                response;
@@ -938,41 +978,42 @@ sql_plugin_retrieve_db_values (PlannerPlugin  *plugin,
 	GtkWidget          *user_entry;
 	GtkWidget          *password_entry;
 	gboolean            ret;
+	GSettings          *sql_settings;
 
-	application = planner_window_get_application (plugin->main_window);
+	planner_window_get_application (plugin->main_window);
 
-	filename = mrp_paths_get_glade_dir ("sql.glade");
-	gui = glade_xml_new (filename, "open_dialog" , NULL);
-	g_free (filename);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/plugin/sql/ui/sql-open-dialog.ui");
 
-	dialog = glade_xml_get_widget (gui, "open_dialog");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "open_dialog"));
 
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
 
-	server_entry   = glade_xml_get_widget (gui, "server_entry");
-	db_entry       = glade_xml_get_widget (gui, "db_entry");
-	user_entry     = glade_xml_get_widget (gui, "user_entry");
-	password_entry = glade_xml_get_widget (gui, "password_entry");
+	server_entry   = GTK_WIDGET (gtk_builder_get_object (builder, "server_entry"));
+	db_entry       = GTK_WIDGET (gtk_builder_get_object (builder, "db_entry"));
+	user_entry     = GTK_WIDGET (gtk_builder_get_object (builder, "user_entry"));
+	password_entry = GTK_WIDGET (gtk_builder_get_object (builder, "password_entry"));
 
-	str = planner_conf_get_string (CONF_SERVER, NULL);
+	sql_settings = g_settings_new (SQL_PLUGIN_SCHEMA_ID);
+
+	str = g_settings_get_string (sql_settings, CONF_SERVER);
 	if (str) {
 		gtk_entry_set_text (GTK_ENTRY (server_entry), str);
 		g_free (str);
 	}
 
-	str = planner_conf_get_string (CONF_DATABASE, NULL);
+	str = g_settings_get_string (sql_settings, CONF_DATABASE);
 	if (str) {
 		gtk_entry_set_text (GTK_ENTRY (db_entry), str);
 		g_free (str);
 	}
 
-	str = planner_conf_get_string (CONF_USERNAME, NULL);
+	str = g_settings_get_string (sql_settings, CONF_USERNAME);
 	if (str) {
 		gtk_entry_set_text (GTK_ENTRY (user_entry), str);
 		g_free (str);
 	}
 
-	g_object_unref (gui);
+	g_object_unref (builder);
 
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -984,17 +1025,11 @@ sql_plugin_retrieve_db_values (PlannerPlugin  *plugin,
 		*login = strdup_null_if_empty (gtk_entry_get_text (GTK_ENTRY (user_entry)));
 		*password = strdup_null_if_empty (gtk_entry_get_text (GTK_ENTRY (password_entry)));
 
-		planner_conf_set_string (CONF_SERVER,
-					 *server ? *server : "",
-					 NULL);
+		g_settings_set_string (sql_settings, CONF_SERVER, *server ? *server : "");
 
-		planner_conf_set_string (CONF_DATABASE,
-					 *database ? *database : "",
-					 NULL);
+		g_settings_set_string (sql_settings, CONF_DATABASE, *database ? *database : "");
 
-		planner_conf_set_string (CONF_USERNAME,
-					 *login ? *login : "",
-					 NULL);
+		g_settings_set_string (sql_settings, CONF_USERNAME, *login ? *login : "");
 		ret = TRUE;
 		break;
 
@@ -1002,12 +1037,48 @@ sql_plugin_retrieve_db_values (PlannerPlugin  *plugin,
 		ret = FALSE;
 		break;
 	}
+	g_clear_object (&sql_settings);
 
 	gtk_widget_destroy (dialog);
 
 	return ret;
 }
 
+/*
+ * define_dsn:
+ * @server: a server
+ * @port: unused
+ * @database: a database
+ * @login: a login
+ * @password: a password
+ *
+ * Define "planner-auto" libgda DSN.
+ * Once defined, connections to the database can be made using the DSN name alone.
+ * provider, host, database, login, password are retrieved.
+ */
+static void
+define_dsn (const gchar *server, const gchar *port, const gchar *database, const gchar *login, const gchar *password)
+{
+    GdaDsnInfo dsn_info = {
+        "planner-auto",
+        "PostgreSQL",
+        "planner project",
+        NULL,
+        NULL,
+        FALSE
+    };
+    GError *error = NULL;
+    dsn_info.cnc_string = g_strdup_printf (CONNECTION_FORMAT_STRING, server, database);
+    dsn_info.auth_string = g_strdup_printf (AUTH_FORMAT_STRING, login, password);
+    gda_config_define_dsn (&dsn_info, &error);
+    if (error) {
+        g_warning ("%s", error->message);
+        g_clear_error (&error);
+    }
+    g_free (dsn_info.cnc_string);
+    g_free (dsn_info.auth_string);
+}
+
 static void
 sql_plugin_open (GtkAction *action,
 		 gpointer   user_data)
@@ -1034,6 +1105,7 @@ sql_plugin_open (GtkAction *action,
 					    &password)) {
 		return;
 	}
+	define_dsn (server, port, database, login, password);
 
 	project_id = sql_plugin_retrieve_project_id (plugin,
 						     server,
@@ -1118,7 +1190,6 @@ static void
 sql_plugin_save (GtkAction *action,
 		 gpointer   user_data)
 {
-	GdaClient     *client;
 	GdaConnection *conn;
 	PlannerPlugin *plugin   = user_data;
 	MrpProject    *project;
@@ -1131,9 +1202,7 @@ sql_plugin_save (GtkAction *action,
 	gchar         *uri      = NULL;
 	const gchar   *uri_plan = NULL;
 	GError        *error    = NULL;
-	gchar         *db_txt;
 	const gchar   *dsn_name = "planner-auto";
-	const gchar   *provider = "PostgreSQL";
 
 	project = planner_window_get_project (plugin->main_window);
 
@@ -1147,20 +1216,12 @@ sql_plugin_save (GtkAction *action,
 		return;
 	}
 
-	db_txt = g_strdup_printf (CONNECTION_FORMAT_STRING,server,database);
-	gda_config_save_data_source (dsn_name,
-                                     provider,
-                                     db_txt,
-                                     "planner project", login, password, FALSE);
-	g_free (db_txt);
-	client = gda_client_new ();
-	conn = sql_get_tested_connection (dsn_name, server, database, client, plugin);
+	define_dsn (server, port, database, login, password);
+	conn = sql_get_tested_connection (dsn_name, server, database, plugin);
 	if (conn == NULL) {
-		g_object_unref (client);
 		return;
 	}
 	gda_connection_close (conn);
-	g_object_unref (client);
 
 	/* This code is prepared for getting support for selecting a project to
 	 * save over. Needs finishing though. Pass project id -1 for now (always
@@ -1242,7 +1303,7 @@ plugin_init (PlannerPlugin *plugin)
 	priv = g_new0 (PlannerPluginPriv, 1);
 	plugin->priv = priv;
 
-	gda_init (PACKAGE, VERSION, 0, NULL);
+	gda_init ();
 
 	g_object_set_data (G_OBJECT (plugin->main_window),
 			   PROJECT_ID,
