@@ -18,8 +18,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_TASK_CMD_H__
-#define __PLANNER_TASK_CMD_H__
+#pragma once
 
 #include "planner-window.h"
 #include "planner-task-tree.h"
@@ -38,5 +37,3 @@ PlannerCmd *planner_task_cmd_insert        (PlannerWindow    *main_window,
 					    gint              work,
 					    gint              duration,
 					    MrpTask          *new_task);
-
-#endif /* __PLANNER_TASK_CMD_H__ */
