@@ -3,8 +3,9 @@
  * Copyright (C) 2004-2005 Imendio AB
  * Copyright (C) 2002-2003 CodeFactory AB
  * Copyright (C) 2002-2003 Richard Hult <richard@imendio.com>
- * Copyright (C) 2002 Mikael Hallendal <micke@imendio.com>
+ * Copyright (C) 2002      Mikael Hallendal <micke@imendio.com>
  * Copyright (C) 2002-2004 Alvaro del Castillo <acs@barrapunto.com>
+ * Copyright (C) 2022      Mart Raudsepp <mart@leio.tech>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,20 +28,19 @@
 #include <string.h>
 #include <stdlib.h> /* for atoi */
 #include <glib/gi18n.h>
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <libplanner/mrp-object.h>
 #include <libplanner/mrp-project.h>
 #include <libplanner/mrp-private.h>
 #include "libplanner/mrp-paths.h"
-#include "planner-cell-renderer-list.h"
+#include <libplanner/mrp-relation.h>
 #include "planner-assignment-model.h"
+#include "planner-calendar-popover.h"
 #include "planner-predecessor-model.h"
 #include "planner-task-cmd.h"
 #include "planner-format.h"
-#include "planner-popup-button.h"
-#include "planner-task-date-widget.h"
 #include "planner-task-dialog.h"
+#include "planner-util.h"
 
 
 typedef struct {
@@ -56,12 +56,19 @@ typedef struct {
 	GtkWidget     *duration_entry;
 	GtkWidget     *schedule_label;
 	GtkWidget     *schedule_button;
+	GtkWidget     *schedule_popover;
 	GtkWidget     *complete_spinbutton;
 	GtkWidget     *priority_spinbutton;
 	GtkWidget     *note_textview;
 	GtkTextBuffer *note_buffer;
 } DialogData;
 
+enum {
+	COLUMN_RELATION_TEXT,
+	COLUMN_RELATION_RELATION,
+	NUM_RELATION_COLUMNS
+};
+
 
 static void            task_dialog_close_clicked_cb               (GtkWidget               *w,
 								   DialogData              *data);
@@ -149,7 +156,7 @@ static void            task_dialog_note_stamp_cb                  (GtkWidget
 static void            task_dialog_task_child_added_or_removed_cb (MrpTask                 *task,
 								   GtkWidget               *dialog);
 static void            task_dialog_setup_widgets                  (DialogData              *data,
-								   GladeXML                *glade);
+								   GtkBuilder              *builder);
 static void            task_dialog_assignment_toggled_cb          (GtkCellRendererText     *cell,
 								   gchar                   *path_str,
 								   DialogData              *data);
@@ -159,20 +166,16 @@ static void            task_dialog_resource_units_cell_edited     (GtkCellRender
 								   gchar                   *path_str,
 								   gchar                   *new_text,
 								   DialogData              *data);
-static void            task_dialog_pred_cell_edited               (GtkCellRendererText     *cell,
+static void            task_dialog_pred_relation_cell_changed     (GtkCellRendererCombo    *combo,
+								   gchar                   *path_string,
+								   GtkTreeIter             *new_iter,
+								   DialogData              *data);
+static void            task_dialog_pred_lag_cell_edited           (GtkCellRendererText     *cell,
 								   gchar                   *path_str,
 								   gchar                   *new_text,
 								   DialogData              *data);
 static MrpRelationType cell_index_to_relation_type                (gint                     i);
-static void            task_dialog_cell_type_show_popup           (PlannerCellRendererList *cell,
-								   const gchar             *path_string,
-								   gint                     x1,
-								   gint                     y1,
-								   gint                     x2,
-								   gint                     y2,
-								   DialogData              *data);
-static void            task_dialog_cell_type_hide_popup           (PlannerCellRendererList *cell,
-								   GtkWidget               *view);
+static GtkTreeModel *  task_dialog_cell_type_create_model         ();
 static void            task_dialog_add_predecessor_cb             (GtkWidget               *widget,
 								   DialogData              *data);
 static void            task_dialog_remove_predecessor_cb          (GtkWidget               *widget,
@@ -268,90 +271,32 @@ typedef struct {
 } TaskCmdEditNote;
 
 static void
-task_dialog_setup_option_menu (GtkWidget     *option_menu,
-			       GCallback      func,
-			       gpointer       user_data,
-			       gconstpointer  str1, ...)
+task_dialog_setup_relation_combo (GtkComboBoxText *combo_text)
 {
-	GtkWidget     *menu;
-	GtkWidget     *menu_item;
-	gint           i;
-	va_list        args;
-	gconstpointer  str;
-	gint           type;
-
-       	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-	if (menu) {
-		gtk_widget_destroy (menu);
-	}
-
-	menu = gtk_menu_new ();
-
-	va_start (args, str1);
-	for (str = str1, i = 0; str != NULL; str = va_arg (args, gpointer), i++) {
-		menu_item = gtk_menu_item_new_with_label (str);
-		gtk_widget_show (menu_item);
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
-
-		type = va_arg (args, gint);
-
-		g_object_set_data (G_OBJECT (menu_item),
-				   "data",
-				   GINT_TO_POINTER (type));
-		if (func) {
-			g_signal_connect (menu_item,
-					  "activate",
-					  func,
-					  user_data);
-		}
-	}
-	va_end (args);
-
-	gtk_widget_show (menu);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
+	gtk_combo_box_text_append_text (combo_text, _("Finish to start (FS)"));
+	gtk_combo_box_text_append_text (combo_text, _("Finish to finish (FF)"));
+	gtk_combo_box_text_append_text (combo_text, _("Start to start (SS)"));
+	gtk_combo_box_text_append_text (combo_text, _("Start to finish (SF)"));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo_text), 0);
 }
 
-static gint
-task_dialog_option_menu_get_selected (GtkWidget *option_menu)
+static MrpRelationType
+task_dialog_relation_get_selected (GtkComboBox *combo)
 {
-	GtkWidget *menu;
-	GtkWidget *item;
-	gint       ret;
-
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-
-	item = gtk_menu_get_active (GTK_MENU (menu));
-
-	ret = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "data"));
-
-	return ret;
+	return cell_index_to_relation_type (gtk_combo_box_get_active (combo));
 }
 
 #if 0
 static void
-task_dialog_option_menu_set_selected (GtkWidget *option_menu, gint data)
+task_dialog_relation_set_selected (GtkComboBox     *combo,
+                                   MrpRelationType  relation)
 {
-	GtkWidget *menu;
-	GtkWidget *item;
-	GList     *children, *l;
-	gint       i;
-
-       	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-
-	children = GTK_MENU_SHELL (menu)->children;
-	for (i = 0, l = children; l; i++, l = l->next) {
-		item = l->data;
-
-		if (GINT_TO_POINTER (data) == g_object_get_data (G_OBJECT (item), "data")) {
-			gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), i);
-			break;
-		}
-	}
+	gtk_combo_box_set_active (relation_type_to_cell_index (relation));
 }
 #endif
 
 static void
-task_dialog_setup_task_combo (GtkComboBoxEntry *combo,
+task_dialog_setup_task_combo (GtkComboBox *combo,
 			      GList    *tasks)
 {
 	GtkListStore *store;
@@ -396,8 +341,9 @@ task_dialog_setup_task_combo (GtkComboBoxEntry *combo,
 
 	gtk_combo_box_set_model (GTK_COMBO_BOX (combo),
 	                         GTK_TREE_MODEL (store));
+	g_object_unref (store);
 
-	gtk_combo_box_entry_set_text_column (combo, 0);
+	gtk_combo_box_set_entry_text_column (combo, 0);
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
@@ -1838,11 +1784,10 @@ task_dialog_predecessor_dialog_new (MrpTask       *task,
 				    PlannerWindow *main_window)
 {
 	MrpProject		*project;
-	GladeXML		*glade;
+	GtkBuilder		*builder;
 	GtkWidget		*dialog;
 	GtkWidget  		*w;
 	GList      		*tasks;
-	gchar      		*filename;
 	GList			*relations, *l;
 	MrpRelationType		 rel_type;
 	MrpConstraint		 constraint;
@@ -1885,48 +1830,40 @@ task_dialog_predecessor_dialog_new (MrpTask       *task,
 
 	mrp_object_get (task, "project", &project, NULL);
 
-	filename = mrp_paths_get_glade_dir ("add-predecessor.glade");
-	glade = glade_xml_new (filename, NULL, NULL);
-	g_free (filename);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/ui/add-predecessor.ui");
 
-	dialog = glade_xml_get_widget (glade, "add_predecessor_dialog");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "add_predecessor_dialog"));
 
 	g_object_set_data (G_OBJECT (dialog), "task_main", task);
 	g_object_set_data (G_OBJECT (dialog), "main_window", main_window);
-	w = glade_xml_get_widget (glade, "predecessor_combo");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "predecessor_combo"));
 	g_object_set_data (G_OBJECT (dialog), "predecessor_combo", w);
 
 	tasks = mrp_project_get_all_tasks (project);
 	tasks = g_list_remove (tasks, task);
-	task_dialog_setup_task_combo (GTK_COMBO_BOX_ENTRY (w), tasks);
+	task_dialog_setup_task_combo (GTK_COMBO_BOX (w), tasks);
 
-	w = glade_xml_get_widget (glade, "type_optionmenu");
-	g_object_set_data (G_OBJECT (dialog), "type_optionmenu", w);
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "type_relation"));
+	g_object_set_data (G_OBJECT (dialog), "type_relation", w);
 
-	task_dialog_setup_option_menu (w,
-				       NULL,
-				       NULL,
-				       _("Finish to start (FS)"), MRP_RELATION_FS,
-				       _("Finish to finish (FF)"), MRP_RELATION_FF,
-				       _("Start to start (SS)"), MRP_RELATION_SS,
-				       _("Start to finish (SF)"), MRP_RELATION_SF,
-				       NULL);
+	task_dialog_setup_relation_combo (GTK_COMBO_BOX_TEXT (w));
 
-	w = glade_xml_get_widget (glade, "lag_entry");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "lag_entry"));
 	g_object_set_data (G_OBJECT (dialog), "lag_entry", w);
 
-	w = glade_xml_get_widget (glade, "cancel_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "cancel_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (task_dialog_new_pred_cancel_clicked_cb),
 			  dialog);
 
-	w = glade_xml_get_widget (glade, "ok_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "ok_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (task_dialog_new_pred_ok_clicked_cb),
 			  dialog);
 
+	g_object_unref (builder);
 	return dialog;
 }
 
@@ -1942,7 +1879,7 @@ task_dialog_new_pred_ok_clicked_cb (GtkWidget *button,
 	MrpTask       *new_task_pred = NULL;
 	MrpProject    *project;
 	gint           lag;
-	gint           pred_type;
+	MrpRelationType pred_type;
 	GtkTreeIter    iter;
 	const gchar   *str;
 
@@ -1957,8 +1894,8 @@ task_dialog_new_pred_ok_clicked_cb (GtkWidget *button,
 	lag = planner_parse_duration_with_day_length (str, 24*60*60);
 
 	/* Predecessor type. */
-	w = g_object_get_data (G_OBJECT(dialog), "type_optionmenu");
-	pred_type = task_dialog_option_menu_get_selected (w);
+	w = g_object_get_data (G_OBJECT(dialog), "type_relation");
+	pred_type = task_dialog_relation_get_selected (GTK_COMBO_BOX (w));
 
 	/* Predecessor task. */
 	w = g_object_get_data (G_OBJECT (dialog), "predecessor_combo");
@@ -2071,28 +2008,27 @@ task_dialog_resource_units_cell_edited (GtkCellRendererText *cell,
 }
 
 static void
-task_dialog_pred_cell_edited (GtkCellRendererText *cell,
-			      gchar               *path_str,
-			      gchar               *new_text,
-			      DialogData          *data)
+task_dialog_pred_relation_cell_changed (GtkCellRendererCombo *combo,
+                                        gchar                *path_string,
+                                        GtkTreeIter          *new_iter,
+                                        DialogData           *data)
 {
-	GtkTreeView             *tree;
-	GtkTreePath             *path;
-	GtkTreeIter              iter;
-	GtkTreeModel            *model;
-	MrpRelation             *relation;
-	MrpTask                 *task_main;
-	MrpTask                 *task_pred;
-	PlannerCellRendererList *planner_cell;
-	gint                     column;
-	gint                     lag;
-	MrpRelationType          type, new_type;
+	GtkTreeView     *tree;
+	GtkTreePath     *path;
+	GtkTreeIter      iter;
+	GtkTreeModel    *model, *combo_model;
+	MrpRelation     *relation;
+	MrpTask         *task_main;
+	MrpTask         *task_pred;
+	gint             lag;
+	MrpRelationType  type, new_type;
+	GError          *error = NULL;
+	PlannerCmd      *cmd;
 
 	tree = GTK_TREE_VIEW (data->predecessor_list);
 
 	model = gtk_tree_view_get_model (tree);
-	path = gtk_tree_path_new_from_string (path_str);
-	column = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (cell), "column"));
+	path = gtk_tree_path_new_from_string (path_string);
 
 	gtk_tree_model_get_iter (model, &iter, path);
 
@@ -2104,58 +2040,72 @@ task_dialog_pred_cell_edited (GtkCellRendererText *cell,
 	lag = mrp_relation_get_lag (relation) / (60*60);
 	type = mrp_relation_get_relation_type (relation);
 
-	switch (column) {
-	case PREDECESSOR_COL_NAME:
-		g_assert_not_reached ();
-		break;
+	g_object_get (combo, "model", &combo_model, NULL);
+	gtk_tree_model_get (combo_model, new_iter,
+			    COLUMN_RELATION_RELATION, &new_type,
+			    -1);
+	cmd = planner_task_cmd_edit_predecessor (data->main_window,
+						 task_main, task_pred,
+						 task_pred,
+						 new_type,
+						 lag, &error);
 
-	case PREDECESSOR_COL_TYPE: {
-		GError     *error = NULL;
-		PlannerCmd *cmd;
+	if (!cmd) {
+		GtkWidget *dialog;
 
-		planner_cell = PLANNER_CELL_RENDERER_LIST (cell);
+		dialog = gtk_message_dialog_new (
+			NULL,
+			GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_MESSAGE_ERROR,
+			GTK_BUTTONS_OK,
+			"%s", error->message);
 
-		new_type = cell_index_to_relation_type (planner_cell->selected_index);
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
 
-		cmd = planner_task_cmd_edit_predecessor (data->main_window,
-							 task_main, task_pred,
-							 task_pred,
-							 new_type,
-							 lag, &error);
+		g_error_free (error);
 
-		if (!cmd) {
-			GtkWidget *dialog;
-
-			dialog = gtk_message_dialog_new (
-				NULL,
-				GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_MESSAGE_ERROR,
-				GTK_BUTTONS_OK,
-				"%s", error->message);
-
-			gtk_dialog_run (GTK_DIALOG (dialog));
-			gtk_widget_destroy (dialog);
-
-			g_error_free (error);
-
-			/* Restore the previous state. */
-			mrp_task_add_predecessor (task_main,
-						  task_pred,
-						  type,
-						  lag,
-						  NULL);
-		}
-		break;
+		/* Restore the previous state. */
+		mrp_task_add_predecessor (task_main,
+					  task_pred,
+					  type,
+					  lag,
+					  NULL);
 	}
-	case PREDECESSOR_COL_LAG:
-		lag = planner_parse_duration_with_day_length (new_text, 24*60*60);
-		task_cmd_edit_lag (data->main_window, relation, lag);
-		break;
 
-	default:
-		g_assert_not_reached ();
-		break;
-	}
+	gtk_tree_path_free (path);
+}
+
+static void
+task_dialog_pred_lag_cell_edited (GtkCellRendererText *cell,
+                             gchar               *path_str,
+                             gchar               *new_text,
+                             DialogData          *data)
+{
+	GtkTreeView  *tree;
+	GtkTreePath  *path;
+	GtkTreeIter   iter;
+	GtkTreeModel *model;
+	MrpRelation  *relation;
+	MrpTask      *task_main;
+	MrpTask      *task_pred;
+	gint          lag;
+
+	tree = GTK_TREE_VIEW (data->predecessor_list);
+
+	model = gtk_tree_view_get_model (tree);
+	path = gtk_tree_path_new_from_string (path_str);
+
+	gtk_tree_model_get_iter (model, &iter, path);
+
+	task_pred = MRP_TASK (planner_list_model_get_object (PLANNER_LIST_MODEL (model),
+							     &iter));
+	task_main = data->task;
+
+	relation = mrp_task_get_relation (task_main, task_pred);
+
+	lag = planner_parse_duration_with_day_length (new_text, 24*60*60);
+	task_cmd_edit_lag (data->main_window, relation, lag);
 
 	gtk_tree_path_free (path);
 }
@@ -2178,16 +2128,62 @@ cell_index_to_relation_type (gint i)
 	}
 }
 
-static void
-task_dialog_cell_type_show_popup (PlannerCellRendererList *cell,
-				  const gchar        *path_string,
-				  gint                x1,
-				  gint                y1,
-				  gint                x2,
-				  gint                y2,
-				  DialogData         *data)
+#if 0
+static gint
+relation_type_to_cell_index (MrpRelationType relation)
 {
-	GtkTreeView       *tree;
+	switch (relation) {
+	case MRP_RELATION_FS:
+		return 0;
+	case MRP_RELATION_FF:
+		return 1;
+	case MRP_RELATION_SS:
+		return 2;
+	case MRP_RELATION_SF:
+		return 3;
+	default:
+		g_warning ("Unknown cell index for conversion to relation type");
+		return MRP_RELATION_FS;
+	}
+}
+#endif
+
+static GtkTreeModel *
+task_dialog_cell_type_create_model ()
+{
+	GtkListStore *model;
+	GtkTreeIter   iter;
+
+	model = gtk_list_store_new (NUM_RELATION_COLUMNS, G_TYPE_STRING, G_TYPE_INT);
+
+	gtk_list_store_append (model, &iter);
+	gtk_list_store_set (model, &iter,
+			    COLUMN_RELATION_TEXT, _("FS"),
+			    COLUMN_RELATION_RELATION, MRP_RELATION_FS,
+			    -1);
+
+	gtk_list_store_append (model, &iter);
+	gtk_list_store_set (model, &iter,
+			    COLUMN_RELATION_TEXT, _("FF"),
+			    COLUMN_RELATION_RELATION, MRP_RELATION_FF,
+			    -1);
+
+	gtk_list_store_append (model, &iter);
+	gtk_list_store_set (model, &iter,
+			    COLUMN_RELATION_TEXT, _("SS"),
+			    COLUMN_RELATION_RELATION, MRP_RELATION_SS,
+			    -1);
+
+	gtk_list_store_append (model, &iter);
+	gtk_list_store_set (model, &iter,
+			    COLUMN_RELATION_TEXT, _("SF"),
+			    COLUMN_RELATION_RELATION, MRP_RELATION_SF,
+			    -1);
+
+	return GTK_TREE_MODEL (model);
+}
+
+/*
 	GtkTreeModel      *model;
 	PlannerListModel  *list_model;
 	GtkTreeIter        iter;
@@ -2233,135 +2229,91 @@ task_dialog_cell_type_show_popup (PlannerCellRendererList *cell,
 		break;
 	}
 }
+*/
 
 static void
-task_dialog_cell_type_hide_popup (PlannerCellRendererList *cell,
-				  GtkWidget          *view)
+task_dialog_schedule_button_toggled_cb (GtkToggleButton  *button,
+                                        DialogData *data)
 {
-       GList *l;
-
-       for (l = cell->user_data; l; l = l->next) {
-               if (l->data) {
-                       g_object_unref (l->data);
-               }
-       }
-
-       g_list_free (cell->user_data);
-       /* cell->user_data = NULL; */
-}
-
-static void
-task_dialog_schedule_date_selected_cb (GtkWidget          *button,
-				       PlannerPopupButton *popup_button)
-{
-	planner_popup_button_popdown (popup_button, TRUE);
-}
-
-static void
-task_dialog_schedule_cancelled_cb (GtkWidget          *button,
-				   PlannerPopupButton *popup_button)
-{
-	planner_popup_button_popdown (popup_button, FALSE);
-}
-
-static GtkWidget *
-task_dialog_schedule_popup_cb (PlannerPopupButton *popup_button,
-			       DialogData         *data)
-{
-	GtkWidget     *widget;
 	MrpConstraint *constraint;
 
-	widget = planner_task_date_widget_new ();
+	if (!gtk_toggle_button_get_active (button)) {
+		return;
+	}
 
 	g_object_get (data->task, "constraint", &constraint, NULL);
 
-	planner_task_date_widget_set_constraint_type (PLANNER_TASK_DATE_WIDGET (widget),
-						      constraint->type);
-
-	if (constraint->type != MRP_CONSTRAINT_ASAP) {
-		planner_task_date_widget_set_date (PLANNER_TASK_DATE_WIDGET (widget),
-						   constraint->time);
+	if (constraint->type == MRP_CONSTRAINT_ASAP) {
+		constraint->time = mrp_time_current_time ();
 	}
 
+	g_object_set (data->schedule_popover,
+		      "mrptime", constraint->time,
+		      "constraint-type", constraint->type,
+		      NULL);
+
 	g_free (constraint);
-
-	g_signal_connect (widget,
-			  "date_selected",
-			  G_CALLBACK (task_dialog_schedule_date_selected_cb),
-			  popup_button);
-	g_signal_connect (widget,
-			  "cancelled",
-			  G_CALLBACK (task_dialog_schedule_cancelled_cb),
-			  popup_button);
-
-	return widget;
 }
 
 static void
-task_dialog_schedule_popdown_cb (PlannerPopupButton *popup_button,
-				 GtkWidget          *widget,
-				 gboolean            ok,
-				 DialogData         *data)
+task_dialog_schedule_popover_closed_cb (PlannerCalendarPopover *popover,
+                                        DialogData             *data)
 {
 	MrpConstraint	 constraint;
 	GList		*relations, *l;
 	GtkWidget	*dialog;
 	MrpRelationType  rel_type;
 
-	if (ok) {
-		constraint.time = planner_task_date_widget_get_date (PLANNER_TASK_DATE_WIDGET (widget));
-		constraint.type = planner_task_date_widget_get_constraint_type (PLANNER_TASK_DATE_WIDGET (widget));
+	g_object_get (popover,
+		      "mrptime", &constraint.time,
+		      "constraint-type", &constraint.type,
+		      NULL);
 
-		relations = mrp_task_get_predecessor_relations (data->task);
+	relations = mrp_task_get_predecessor_relations (data->task);
 
-		/* check for attempt to add MSO constraint when relations are present */
-		if (constraint.type == MRP_CONSTRAINT_MSO && relations) {
+	/* check for attempt to add MSO constraint when relations are present */
+	if (constraint.type == MRP_CONSTRAINT_MSO && relations) {
+		/* TODO: This errors here, but not when changing it as such in the treeview */
+		dialog = gtk_message_dialog_new (GTK_WINDOW (data->main_window),
+						 GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 "You cannot add a Must Start On constraint with predecessor relations defined for this task.");
 
-			dialog = gtk_message_dialog_new (GTK_WINDOW (data->main_window),
-							 GTK_DIALOG_DESTROY_WITH_PARENT,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE,
-							 "You cannot add a Must Start On constraint with predecessor relations defined for this task.");
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
 
-			gtk_dialog_run (GTK_DIALOG (dialog));
-			gtk_widget_destroy (dialog);
-			gtk_widget_destroy (widget);
-
-			return;
-		}
-
-		/* check for attempt to add MSO constraint when relations are present */
-		if (constraint.type == MRP_CONSTRAINT_SNET && relations) {
-			for (l = relations; l; l = l->next) {
-
-				rel_type = mrp_relation_get_relation_type (l->data);
-				if (rel_type == MRP_RELATION_SF || rel_type == MRP_RELATION_FF) {
-					dialog = gtk_message_dialog_new (GTK_WINDOW (data->main_window),
-									 GTK_DIALOG_DESTROY_WITH_PARENT,
-									 GTK_MESSAGE_ERROR,
-									 GTK_BUTTONS_CLOSE,
-									 "You cannot add a Start No Earlier Than constraint because a Start to Finish or Finish to Finish predecessor relationship exists for this task.");
-
-					gtk_dialog_run (GTK_DIALOG (dialog));
-					gtk_widget_destroy (dialog);
-					gtk_widget_destroy (widget);
-
-					return;
-				}
-			}
-		}
-
-		task_cmd_edit_constraint (data->main_window,
-					  data->task,
-					  &constraint);
+		return;
 	}
 
-	gtk_widget_destroy (widget);
+	/* check for attempt to add MSO constraint when relations are present */
+	if (constraint.type == MRP_CONSTRAINT_SNET && relations) {
+		for (l = relations; l; l = l->next) {
+
+			rel_type = mrp_relation_get_relation_type (l->data);
+			if (rel_type == MRP_RELATION_SF || rel_type == MRP_RELATION_FF) {
+				dialog = gtk_message_dialog_new (GTK_WINDOW (data->main_window),
+								 GTK_DIALOG_DESTROY_WITH_PARENT,
+								 GTK_MESSAGE_ERROR,
+								 GTK_BUTTONS_CLOSE,
+								 "You cannot add a Start No Earlier Than constraint because a Start to Finish or Finish to Finish predecessor relationship exists for this task.");
+
+				gtk_dialog_run (GTK_DIALOG (dialog));
+				gtk_widget_destroy (dialog);
+
+				return;
+			}
+		}
+	}
+
+	task_cmd_edit_constraint (data->main_window,
+				  data->task,
+				  &constraint);
 }
 
 static void
 task_dialog_setup_widgets (DialogData *data,
-			   GladeXML   *glade)
+			   GtkBuilder *builder)
 {
 	GtkWidget    *w;
 	gchar        *name;
@@ -2370,15 +2322,14 @@ task_dialog_setup_widgets (DialogData *data,
 	gchar        *note;
 	gint          int_value;
 	gchar        *str;
-	GtkWidget    *hbox;
 
-	w = glade_xml_get_widget (glade, "close_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "close_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (task_dialog_close_clicked_cb),
 			  data);
 
-	data->name_entry = glade_xml_get_widget (glade, "name_entry");
+	data->name_entry = GTK_WIDGET (gtk_builder_get_object (builder, "name_entry"));
 
 	g_object_get (data->task, "name", &name, NULL);
 	if (name) {
@@ -2401,7 +2352,7 @@ task_dialog_setup_widgets (DialogData *data,
 			  G_CALLBACK (task_dialog_name_focus_out_cb),
 			  data);
 
-	data->milestone_checkbutton = glade_xml_get_widget (glade, "milestone_checkbutton");
+	data->milestone_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "milestone_checkbutton"));
 	g_object_get (data->task, "type", &type, NULL);
 	if (type == MRP_TASK_TYPE_MILESTONE) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->milestone_checkbutton), TRUE);
@@ -2411,7 +2362,7 @@ task_dialog_setup_widgets (DialogData *data,
 			  G_CALLBACK (task_dialog_type_toggled_cb),
 			  data);
 
-	data->fixed_checkbutton = glade_xml_get_widget (glade, "fixed_checkbutton");
+	data->fixed_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "fixed_checkbutton"));
 	g_object_get (data->task, "sched", &sched, NULL);
 	if (sched == MRP_TASK_SCHED_FIXED_DURATION) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->fixed_checkbutton), TRUE);
@@ -2421,7 +2372,7 @@ task_dialog_setup_widgets (DialogData *data,
 			  G_CALLBACK (task_dialog_fixed_toggled_cb),
 			  data);
 
-	data->work_entry = glade_xml_get_widget (glade, "work_entry");
+	data->work_entry = GTK_WIDGET (gtk_builder_get_object (builder, "work_entry"));
 	g_object_get (data->task, "work", &int_value, NULL);
 	str = planner_format_duration (mrp_object_get_project (MRP_OBJECT (data->task)), int_value);
 	gtk_entry_set_text (GTK_ENTRY (data->work_entry), str);
@@ -2435,7 +2386,7 @@ task_dialog_setup_widgets (DialogData *data,
 			  G_CALLBACK (task_dialog_work_focus_out_cb),
 			  data);
 
-	data->duration_entry = glade_xml_get_widget (glade, "duration_entry");
+	data->duration_entry = GTK_WIDGET (gtk_builder_get_object (builder, "duration_entry"));
 	g_object_get (data->task, "duration", &int_value, NULL);
 	str = planner_format_duration (mrp_object_get_project (MRP_OBJECT (data->task)), int_value);
 	gtk_entry_set_text (GTK_ENTRY (data->duration_entry), str);
@@ -2450,25 +2401,21 @@ task_dialog_setup_widgets (DialogData *data,
 			  data);
 
 	/* Schedule. */
-	data->schedule_label = glade_xml_get_widget (glade, "schedule_label");
+	data->schedule_label = GTK_WIDGET (gtk_builder_get_object (builder, "schedule_label"));
 	task_dialog_update_schedule_label (data);
 
-	hbox = glade_xml_get_widget (glade, "schedule_hbox");
-	data->schedule_button = planner_popup_button_new (_("Change..."));
-	gtk_widget_show (data->schedule_button);
-	gtk_box_pack_start (GTK_BOX (hbox), data->schedule_button, FALSE, FALSE, 0);
-
+	data->schedule_button = GTK_WIDGET (gtk_builder_get_object (builder, "calendar_button"));
+	data->schedule_popover = GTK_WIDGET (gtk_builder_get_object (builder, "calendar_popover"));
 	g_signal_connect (data->schedule_button,
-			  "popup",
-			  G_CALLBACK (task_dialog_schedule_popup_cb),
+			  "toggled",
+			  G_CALLBACK (task_dialog_schedule_button_toggled_cb),
+			  data);
+	g_signal_connect (data->schedule_popover,
+			  "closed",
+			  G_CALLBACK (task_dialog_schedule_popover_closed_cb),
 			  data);
 
-	g_signal_connect (data->schedule_button,
-			  "popdown",
-			  G_CALLBACK (task_dialog_schedule_popdown_cb),
-			  data);
-
-	data->complete_spinbutton = glade_xml_get_widget (glade, "complete_spinbutton");
+	data->complete_spinbutton = GTK_WIDGET (gtk_builder_get_object (builder, "complete_spinbutton"));
 	g_object_get (data->task, "percent_complete", &int_value, NULL);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (data->complete_spinbutton), int_value);
 	g_signal_connect (data->complete_spinbutton,
@@ -2484,7 +2431,7 @@ task_dialog_setup_widgets (DialogData *data,
 			  G_CALLBACK (task_dialog_complete_focus_out_cb),
 			  data);
 
-	data->priority_spinbutton = glade_xml_get_widget (glade, "priority_spinbutton");
+	data->priority_spinbutton = GTK_WIDGET (gtk_builder_get_object (builder, "priority_spinbutton"));
 	g_object_get (data->task, "priority", &int_value, NULL);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (data->priority_spinbutton), int_value);
 	g_signal_connect (data->priority_spinbutton,
@@ -2500,7 +2447,7 @@ task_dialog_setup_widgets (DialogData *data,
 			  G_CALLBACK (task_dialog_priority_focus_out_cb),
 			  data);
 
-	data->note_textview = glade_xml_get_widget (glade, "note_textview");
+	data->note_textview = GTK_WIDGET (gtk_builder_get_object (builder, "note_textview"));
 
 	data->note_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (data->note_textview));
 
@@ -2524,7 +2471,7 @@ task_dialog_setup_widgets (DialogData *data,
 			  G_CALLBACK (task_dialog_note_focus_in_cb),
 			  data);
 
-	w = glade_xml_get_widget (glade, "stamp_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "stamp_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (task_dialog_note_stamp_cb),
@@ -2673,14 +2620,10 @@ task_dialog_setup_predecessor_list (DialogData *data)
 				     GTK_SELECTION_SINGLE);
 
 	/* Name */
-	cell = planner_cell_renderer_list_new ();
+	cell = gtk_cell_renderer_text_new ();
 
 	g_object_set (cell, "editable", FALSE, NULL);
 
-	g_object_set_data (G_OBJECT (cell),
-			   "column",
-			   GINT_TO_POINTER (PREDECESSOR_COL_NAME));
-
 	col = gtk_tree_view_column_new_with_attributes (_("Name"),
 							cell,
 							"text", PREDECESSOR_COL_NAME,
@@ -2690,29 +2633,21 @@ task_dialog_setup_predecessor_list (DialogData *data)
 	gtk_tree_view_append_column (tree, col);
 
 	/* Type */
-	cell = planner_cell_renderer_list_new ();
+	cell = gtk_cell_renderer_combo_new ();
+	model = task_dialog_cell_type_create_model ();
 
-	g_object_set (cell, "editable", TRUE, NULL);
-
-	g_object_set_data (G_OBJECT (cell),
-			   "column",
-			   GINT_TO_POINTER (PREDECESSOR_COL_TYPE));
+	g_object_set (cell,
+		      "editable", TRUE,
+		      "has-entry", FALSE,
+		      "model", model,
+		      "text-column", COLUMN_RELATION_TEXT,
+		      NULL);
 
 	g_signal_connect (cell,
-			  "edited",
-			  G_CALLBACK (task_dialog_pred_cell_edited),
+			  "changed",
+			  G_CALLBACK (task_dialog_pred_relation_cell_changed),
 			  data);
 
-	g_signal_connect (cell,
-			  "show_popup",
-			  G_CALLBACK (task_dialog_cell_type_show_popup),
-			  data);
-
-	g_signal_connect_after (cell,
-				"hide_popup",
-				G_CALLBACK (task_dialog_cell_type_hide_popup),
-				data);
-
 	col = gtk_tree_view_column_new_with_attributes (_("Type"),
 							cell,
 							"text", PREDECESSOR_COL_TYPE,
@@ -2725,13 +2660,9 @@ task_dialog_setup_predecessor_list (DialogData *data)
 
 	g_object_set (cell, "editable", TRUE, NULL);
 
-	g_object_set_data (G_OBJECT (cell),
-			   "column",
-			   GINT_TO_POINTER (PREDECESSOR_COL_LAG));
-
 	g_signal_connect (cell,
 			  "edited",
-			  G_CALLBACK (task_dialog_pred_cell_edited),
+			  G_CALLBACK (task_dialog_pred_lag_cell_edited),
 			  data);
 
 	col = gtk_tree_view_column_new ();
@@ -2906,13 +2837,12 @@ planner_task_dialog_new (PlannerWindow *window,
 			 PlannerTaskDialogPage  page)
 {
 	DialogData   *data;
-	GladeXML     *glade;
+	GtkBuilder   *builder;
 	GtkWidget    *dialog;
 	GtkWidget    *w;
 	GtkSizeGroup *size_group;
 	MrpProject   *project;
 	MrpCalendar  *calendar;
-	gchar        *filename;
 
 	g_return_val_if_fail (MRP_IS_TASK (task), NULL);
 
@@ -2926,16 +2856,9 @@ planner_task_dialog_new (PlannerWindow *window,
 		return dialog;
 	}
 
-	filename = mrp_paths_get_glade_dir ("task-dialog.glade");
-	glade = glade_xml_new (filename, NULL, NULL);
-	g_free (filename);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/ui/task-dialog.ui");
 
-	if (!glade) {
-		g_warning ("Could not create task dialog.");
-		return NULL;
-	}
-
-	dialog = glade_xml_get_widget (glade, "task_dialog");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "task_dialog"));
 
 	data = g_new0 (DialogData, 1);
 
@@ -2962,23 +2885,23 @@ planner_task_dialog_new (PlannerWindow *window,
 				 dialog,
 				 0);
 
-	w = glade_xml_get_widget (glade, "task_notebook");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "task_notebook"));
 
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (w), page);
 
-	data->resource_list = glade_xml_get_widget (glade, "resource_list");
+	data->resource_list = GTK_WIDGET (gtk_builder_get_object (builder, "resource_list"));
 	task_dialog_setup_resource_list (data);
 
-	data->predecessor_list = glade_xml_get_widget (glade, "predecessor_list");
+	data->predecessor_list = GTK_WIDGET (gtk_builder_get_object (builder, "predecessor_list"));
 	task_dialog_setup_predecessor_list (data);
 
-	w = glade_xml_get_widget (glade, "add_predecessor_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "add_predecessor_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (task_dialog_add_predecessor_cb),
 			  data);
 
-	w = glade_xml_get_widget (glade, "remove_predecessor_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "remove_predecessor_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (task_dialog_remove_predecessor_cb),
@@ -2986,16 +2909,16 @@ planner_task_dialog_new (PlannerWindow *window,
 
 	size_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
 
-	w = glade_xml_get_widget (glade, "name_pad");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "name_pad"));
 	gtk_size_group_add_widget (size_group, w);
 
-	w = glade_xml_get_widget (glade, "milestone_pad");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "milestone_pad"));
 	gtk_size_group_add_widget (size_group, w);
 
-	w = glade_xml_get_widget (glade, "complete_pad");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "complete_pad"));
 	gtk_size_group_add_widget (size_group, w);
 
-	w = glade_xml_get_widget (glade, "priority_pad");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "priority_pad"));
 	gtk_size_group_add_widget (size_group, w);
 
 	g_object_unref (size_group);
@@ -3004,7 +2927,7 @@ planner_task_dialog_new (PlannerWindow *window,
 				"data", data,
 				g_free);
 
-	task_dialog_setup_widgets (data, glade);
+	task_dialog_setup_widgets (data, builder);
 
 	task_dialog_update_sensitivity (data);
 
@@ -3021,5 +2944,6 @@ planner_task_dialog_new (PlannerWindow *window,
 				 dialog,
 				 0);
 
+	g_object_unref (builder);
 	return dialog;
 }
