@@ -19,8 +19,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_TASK_DIALOG_H__
-#define __PLANNER_TASK_DIALOG_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libplanner/mrp-project.h>
@@ -37,14 +36,3 @@ typedef enum {
 GtkWidget * planner_task_dialog_new  (PlannerWindow         *window,
 				      MrpTask               *task,
 				      PlannerTaskDialogPage  page);
-
-#endif /* __PLANNER_TASK_DIALOG_H__ */
-
-
-
-
-
-
-
-
-
