@@ -17,8 +17,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_TASK_POPUP_H__
-#define __PLANNER_TASK_POPUP_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include "planner-task-tree.h"
@@ -29,6 +28,3 @@ void          planner_task_popup_set_sensitive      (GtkUIManager *ui_manager,
 						     gboolean sensitive);
 void          planner_task_popup_update_sensitivity (GtkUIManager    *ui_manager,
 						     GList           *tasks);
-
-
-#endif
