@@ -5,6 +5,7 @@
  * Copyright (C) 2002-2003 Richard Hult <richard@imendio.com>
  * Copyright (C) 2002      Mikael Hallendal <micke@imendio.com>
  * Copyright (C) 2002-2004 Alvaro del Castillo <acs@barrapunto.com>
+ * Copyright (C) 2021-2022 Mart Raudsepp <mart@leio.tech>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,7 +32,7 @@
 #include <glib/gi18n.h>
 #include "planner-format.h"
 #include "planner-marshal.h"
-#include "planner-cell-renderer-date.h"
+#include "planner-cell-renderer-calendar.h"
 #include "planner-task-dialog.h"
 #include "planner-task-cmd.h"
 #include "planner-task-input-dialog.h"
@@ -39,7 +40,8 @@
 #include "planner-task-tree.h"
 #include "planner-gantt-model.h"
 #include "planner-task-popup.h"
-
+#include "planner-util.h"
+#include <libplanner/mrp-relation.h>
 
 #define WARN_TASK_DIALOGS 10
 #define MAX_TASK_DIALOGS 25
@@ -52,7 +54,7 @@ enum {
 };
 
 struct _PlannerTaskTreePriv {
-	GtkItemFactory *popup_factory;
+	GtkUIManager   *popup_ui_manager;
 	gboolean        custom_properties;
 	MrpProject     *project;
 	GHashTable     *property_to_column;
@@ -69,6 +71,9 @@ struct _PlannerTaskTreePriv {
 	 */
 	GHashTable     *task_dialogs;
 	GtkTreePath    *anchor;
+
+	/* Old constraint before current cell renderer popover started */
+	MrpConstraint   old_constraint;
 };
 
 typedef struct {
@@ -625,15 +630,28 @@ task_cmd_constraint_free (PlannerCmd *cmd_base)
 }
 
 
-static PlannerCmd *
-task_cmd_constraint (PlannerTaskTree *tree,
-		     MrpTask         *task,
-		     MrpConstraint    constraint)
+static void
+task_cmd_constraint_if_changed (PlannerTaskTree *tree,
+                                MrpTask         *task,
+                                MrpConstraint    constraint,
+                                MrpConstraint    old_constraint)
 {
 	PlannerTaskTreePriv *priv = tree->priv;
 	PlannerCmd          *cmd_base;
 	TaskCmdConstraint   *cmd;
 
+	if (constraint.time == old_constraint.time &&
+	    constraint.type == old_constraint.type) {
+		/* Constraint remained the same, no undo stack */
+		return;
+	}
+
+	if (constraint.type == MRP_CONSTRAINT_ASAP &&
+	    old_constraint.type == MRP_CONSTRAINT_ASAP) {
+		/* Constraint effectively the same, as ASAP ignores time */
+		return;
+	}
+
 	cmd_base = planner_cmd_new (TaskCmdConstraint,
 				    _("Apply constraint to task"),
 				    task_cmd_constraint_do,
@@ -646,14 +664,12 @@ task_cmd_constraint (PlannerTaskTree *tree,
 	cmd->constraint = g_new0 (MrpConstraint, 1);
 	cmd->constraint->time = constraint.time;
 	cmd->constraint->type = constraint.type;
-
-	g_object_get (task, "constraint",
-		      &cmd->constraint_old, NULL);
+	cmd->constraint_old = g_new0 (MrpConstraint, 1);
+	cmd->constraint_old->time = old_constraint.time;
+	cmd->constraint_old->type = old_constraint.type;
 
 	planner_cmd_manager_insert_and_do (planner_window_get_cmd_manager (priv->main_window),
 					   cmd_base);
-
-	return cmd_base;
 }
 
 static gboolean
@@ -1043,7 +1059,7 @@ task_tree_init (PlannerTaskTree *tree)
 	tree->priv = priv;
 
 	priv->property_to_column = g_hash_table_new (NULL, NULL);
-	priv->popup_factory = planner_task_popup_new (tree);
+	priv->popup_ui_manager = planner_task_popup_new (tree);
 	priv->anchor = NULL;
 
 	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (tree), FALSE);
@@ -1068,6 +1084,8 @@ task_tree_finalize (GObject *object)
 	tree = PLANNER_TASK_TREE (object);
 	priv = tree->priv;
 
+	g_clear_object (&tree->priv->popup_ui_manager);
+
 	g_hash_table_destroy (priv->property_to_column);
 
 	planner_task_tree_set_anchor (tree, NULL);
@@ -1208,42 +1226,15 @@ task_tree_tree_view_popup_menu (GtkWidget       *widget,
 				PlannerTaskTree *tree)
 {
 	GList             *tasks;
-	GtkTreePath       *path;
-	GtkTreeViewColumn *column;
-	GdkRectangle       rect;
-	gint               x, y;
 
 	tasks = planner_task_tree_get_selected_tasks (tree);
-	planner_task_popup_update_sensitivity (tree->priv->popup_factory, tasks);
+	planner_task_popup_update_sensitivity (tree->priv->popup_ui_manager, tasks);
 	g_list_free (tasks);
 
-	gtk_tree_view_get_cursor (GTK_TREE_VIEW (tree), &path, &column);
-	gtk_tree_view_get_cell_area (GTK_TREE_VIEW (tree),
-				     path,
-				     column,
-				     &rect);
-
-	x = rect.x;
-	y = rect.y;
-
-	/* Note: this is not perfect, but good enough for now. */
-	gdk_window_get_root_origin (GTK_WIDGET (tree)->window, &x, &y);
-	rect.x += x;
-	rect.y += y;
-
-	gtk_widget_translate_coordinates (GTK_WIDGET (tree),
-					  gtk_widget_get_toplevel (GTK_WIDGET (tree)),
-					  rect.x, rect.y,
-					  &x, &y);
-
-	/* Offset so it's not overlapping the cell. */
-	rect.x = x + 20;
-	rect.y = y + 20;
-
-	gtk_item_factory_popup (tree->priv->popup_factory,
-				rect.x, rect.y,
-				0,
-				gtk_get_current_event_time ());
+	gtk_menu_popup (GTK_MENU (gtk_ui_manager_get_widget (tree->priv->popup_ui_manager, "/TaskPopup")),
+			NULL, NULL,
+			planner_util_menu_position_on_current_cell, tree,
+			0, gtk_get_current_event_time ());
 }
 
 static gboolean
@@ -1253,12 +1244,12 @@ task_tree_tree_view_button_press_event (GtkTreeView     *tv,
 {
 	GtkTreePath         *path;
 	PlannerTaskTreePriv *priv;
-	GtkItemFactory      *factory;
+	GtkUIManager        *popup_ui_manager;
 	GtkTreeIter          iter;
 	GList               *tasks;
 
 	priv = tree->priv;
-	factory = priv->popup_factory;
+	popup_ui_manager = priv->popup_ui_manager;
 
 	if (event->button == 3) {
 		gtk_widget_grab_focus (GTK_WIDGET (tree));
@@ -1272,7 +1263,7 @@ task_tree_tree_view_button_press_event (GtkTreeView     *tv,
 			}
 
 			tasks = planner_task_tree_get_selected_tasks (tree);
-			planner_task_popup_update_sensitivity (factory, tasks);
+			planner_task_popup_update_sensitivity (popup_ui_manager, tasks);
 			g_list_free (tasks);
 
 			planner_task_tree_set_anchor (tree, path);
@@ -1280,22 +1271,17 @@ task_tree_tree_view_button_press_event (GtkTreeView     *tv,
 		} else {
 			gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (tv));
 
-			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, PLANNER_TASK_POPUP_SUBTASK), FALSE);
-			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, PLANNER_TASK_POPUP_REMOVE), FALSE);
-			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, PLANNER_TASK_POPUP_UNLINK), FALSE);
-			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, PLANNER_TASK_POPUP_EDIT_RESOURCES), FALSE);
-			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, PLANNER_TASK_POPUP_EDIT_TASK), FALSE);
+			planner_task_popup_set_sensitive (popup_ui_manager, "/TaskPopup/InsertSubtask", FALSE);
+			planner_task_popup_set_sensitive (popup_ui_manager, "/TaskPopup/RemoveTask", FALSE);
+			planner_task_popup_set_sensitive (popup_ui_manager, "/TaskPopup/UnlinkTask", FALSE);
+			planner_task_popup_set_sensitive (popup_ui_manager, "/TaskPopup/AssignResources", FALSE);
+			planner_task_popup_set_sensitive (popup_ui_manager, "/TaskPopup/EditTask", FALSE);
 
 			planner_task_tree_set_anchor (tree, NULL);
 		}
 
-		gtk_item_factory_popup (factory, event->x_root, event->y_root,
-					event->button, event->time);
+		gtk_menu_popup (GTK_MENU (gtk_ui_manager_get_widget (popup_ui_manager, "/TaskPopup")),
+				NULL, NULL, NULL, NULL, event->button, event->time);
 		return TRUE;
 	}
 	else if (event->button == 1) {
@@ -1320,10 +1306,10 @@ task_tree_tree_view_key_release_event (GtkTreeView *tree_view,
 					PlannerTaskTree *tree)
 {
 	if (!(event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK))) {
-		if (event->keyval & (GDK_Up | GDK_Page_Up | GDK_KP_Up |
-			GDK_KP_Page_Up | GDK_Pointer_Up | GDK_ISO_Move_Line_Up |
-			GDK_Down | GDK_Page_Down | GDK_KP_Down | GDK_KP_Page_Down |
-			GDK_Pointer_Down | GDK_ISO_Move_Line_Down)) {
+		if (event->keyval & (GDK_KEY_Up | GDK_KEY_Page_Up | GDK_KEY_KP_Up |
+			GDK_KEY_KP_Page_Up | GDK_KEY_Pointer_Up | GDK_KEY_ISO_Move_Line_Up |
+			GDK_KEY_Down | GDK_KEY_Page_Down | GDK_KEY_KP_Down | GDK_KEY_KP_Page_Down |
+			GDK_KEY_Pointer_Down | GDK_KEY_ISO_Move_Line_Down)) {
 
 			GtkTreeSelection *selection = gtk_tree_view_get_selection (tree_view);
 			GList *list = gtk_tree_selection_get_selected_rows (selection, NULL);
@@ -1768,56 +1754,18 @@ task_tree_complete_edited (GtkCellRendererText *cell,
 }
 
 static void
-task_tree_start_edited (GtkCellRendererText *cell,
-			gchar               *path_string,
-			gchar               *new_text,
-			gpointer             data)
+task_tree_start_configure_popover_cb (PlannerCellRendererCalendar *cell,
+                                      const gchar                 *path_string,
+                                      GtkTreeView                 *tree_view)
 {
-	PlannerTaskTree         *tree = data;
-	PlannerCellRendererDate *date;
-	GtkTreeView             *view;
-	GtkTreeModel            *model;
-	GtkTreePath             *path;
-	GtkTreeIter              iter;
-	MrpTask                 *task;
-	MrpConstraint            constraint;
-
-	view = GTK_TREE_VIEW (data);
-	model = gtk_tree_view_get_model (view);
-	date = PLANNER_CELL_RENDERER_DATE (cell);
-
-	path = gtk_tree_path_new_from_string (path_string);
-	gtk_tree_model_get_iter (model, &iter, path);
-
-	gtk_tree_model_get (model, &iter,
-			    COL_TASK, &task,
-			    -1);
-
-	constraint.time = date->time;
-	constraint.type = date->type;
-
-	task_cmd_constraint (tree, task, constraint);
-
-	/* g_object_set (task, "constraint", &constraint, NULL); */
-
-	gtk_tree_path_free (path);
-}
-
-static void
-task_tree_start_show_popup (PlannerCellRendererDate *cell,
-			    const gchar        *path_string,
-			    gint                x1,
-			    gint                y1,
-			    gint                x2,
-			    gint                y2,
-			    GtkTreeView        *tree_view)
-{
-	GtkTreeModel  *model;
-	GtkTreeIter    iter;
-	GtkTreePath   *path;
-	MrpTask       *task;
-	mrptime        start;
-	MrpConstraint *constraint;
+	GtkTreeModel    *model;
+	GtkTreeIter      iter;
+	GtkTreePath     *path;
+	MrpTask         *task;
+	mrptime          start;
+	gint             year, month, day;
+	MrpConstraint   *constraint;
+	PlannerTaskTree *task_tree = PLANNER_TASK_TREE (tree_view);
 
 	model = gtk_tree_view_get_model (tree_view);
 
@@ -1831,32 +1779,116 @@ task_tree_start_show_popup (PlannerCellRendererDate *cell,
 		      "constraint", &constraint,
 		      NULL);
 
-	cell->type = constraint->type;
+	task_tree->priv->old_constraint.time = constraint->time;
+	task_tree->priv->old_constraint.type = constraint->type;
 
-	if (cell->type == MRP_CONSTRAINT_ASAP) {
+	if (constraint->type == MRP_CONSTRAINT_ASAP) {
 		start = mrp_task_get_start (task);
-		cell->time = start;
 	} else {
-		cell->time = constraint->time;
+		start = constraint->time;
 	}
 
+	mrp_time_decompose (start, &year, &month, &day, NULL, NULL, NULL);
+
+	g_object_set (cell,
+		      "constraint-type", constraint->type,
+		      "mrptime", start,
+		      NULL);
+
 	g_free (constraint);
 	gtk_tree_path_free (path);
 }
 
 static void
-task_tree_property_date_show_popup (PlannerCellRendererDate *cell,
-				    const gchar        *path_string,
-				    gint                x1,
-				    gint                y1,
-				    gint                x2,
-				    gint                y2,
-				    GtkTreeView        *tree_view)
+task_tree_start_mrptime_changed_cb (PlannerCellRendererCalendar *cell,
+                                    const gchar                 *path_string,
+                                    mrptime                      t,
+                                    GtkTreeView                 *tree_view)
 {
+	GtkTreeModel      *model;
+	GtkTreeIter        iter;
+	GtkTreePath       *path;
+	MrpTask           *task;
+	MrpConstraintType  constraint_type;
+	MrpConstraint      constraint;
 
-	if (cell->time == MRP_TIME_INVALID) {
-		cell->time = mrp_time_current_time ();
-	}
+	model = gtk_tree_view_get_model (tree_view);
+
+	path = gtk_tree_path_new_from_string (path_string);
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_model_get (model, &iter,
+			    COL_TASK, &task,
+			    -1);
+
+	g_object_get (cell, "constraint-type", &constraint_type, NULL);
+
+	constraint.time = t;
+	constraint.type = constraint_type;
+
+	g_object_set (task, "constraint", &constraint, NULL);
+
+	gtk_tree_path_free (path);
+}
+
+static void
+task_tree_start_constraint_type_changed_cb (PlannerCellRendererCalendar *cell,
+                                            const gchar                 *path_string,
+                                            MrpConstraintType            constraint_type,
+                                            GtkTreeView                 *tree_view)
+{
+	GtkTreeModel  *model;
+	GtkTreeIter    iter;
+	GtkTreePath   *path;
+	MrpTask       *task;
+	mrptime        t;
+	MrpConstraint  constraint;
+
+	model = gtk_tree_view_get_model (tree_view);
+
+	path = gtk_tree_path_new_from_string (path_string);
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_model_get (model, &iter,
+			    COL_TASK, &task,
+			    -1);
+
+	g_object_get (cell, "mrptime", &t, NULL);
+	constraint.time = t;
+	constraint.type = constraint_type;
+
+	g_object_set (task, "constraint", &constraint, NULL);
+
+	gtk_tree_path_free (path);
+}
+
+static void
+task_tree_start_calendar_closed_cb (PlannerCellRendererCalendar *cell,
+                                    const gchar                 *path_string,
+                                    GtkTreeView                 *tree_view)
+{
+	GtkTreeModel      *model;
+	GtkTreeIter        iter;
+	GtkTreePath       *path;
+	MrpTask           *task;
+	MrpConstraint      constraint;
+	PlannerTaskTree   *task_tree = PLANNER_TASK_TREE (tree_view);
+
+	model = gtk_tree_view_get_model (tree_view);
+
+	path = gtk_tree_path_new_from_string (path_string);
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_model_get (model, &iter,
+			    COL_TASK, &task,
+			    -1);
+
+	g_object_get (cell,
+		      "mrptime", &constraint.time,
+		      "constraint-type", &constraint.type,
+		      NULL);
+
+	task_cmd_constraint_if_changed (PLANNER_TASK_TREE (tree_view), task,
+					constraint, task_tree->priv->old_constraint);
+
+	gtk_tree_path_free (path);
 }
 
 static void
@@ -2070,12 +2102,6 @@ task_view_custom_property_set_value (MrpProperty         *property,
 
 	case MRP_PROPERTY_TYPE_DATE:
 		/* FIXME: Currently custom properties can't be dates. Why? */
-		/*
-		 * date = PLANNER_CELL_RENDERER_DATE (cell);
-		 * mrp_object_set (MRP_OBJECT (task),
-				mrp_property_get_name (property),
-				&(date->time),
-				NULL);*/
 		break;
 	case MRP_PROPERTY_TYPE_COST:
 		fvalue = g_strtod (new_text, NULL);
@@ -2130,7 +2156,6 @@ task_tree_property_added (MrpProject      *project,
 {
 	GtkTreeView         *tree;
 	PlannerTaskTreePriv *priv;
-	MrpPropertyType      type;
 	GtkTreeViewColumn   *col;
 	GtkCellRenderer     *cell;
 	ColPropertyData     *data;
@@ -2141,7 +2166,8 @@ task_tree_property_added (MrpProject      *project,
 
 	data = g_new0 (ColPropertyData, 1);
 
-	type = mrp_property_get_property_type (property);
+	/* TODO: Add back date property support once we have it as a supported custom property again */
+	/* type = mrp_property_get_property_type (property); */
 
 	/* The costs are edited in resources view
 	   if (type == MRP_PROPERTY_TYPE_COST) {
@@ -2152,15 +2178,7 @@ task_tree_property_added (MrpProject      *project,
 		return;
 	}
 
-	if (type == MRP_PROPERTY_TYPE_DATE) {
-		cell = planner_cell_renderer_date_new (FALSE);
-		g_signal_connect (cell,
-				  "show_popup",
-				  G_CALLBACK (task_tree_property_date_show_popup),
-				  tree);
-	} else {
-		cell = gtk_cell_renderer_text_new ();
-	}
+	cell = gtk_cell_renderer_text_new ();
 
 	g_object_set (cell, "editable", TRUE, NULL);
 
@@ -2378,14 +2396,24 @@ task_tree_add_column (PlannerTaskTree *tree,
 		break;
 
 	case COL_START:
-		cell = planner_cell_renderer_date_new (TRUE);
+	{
+		cell = GTK_CELL_RENDERER (planner_cell_renderer_calendar_new (TRUE));
+
 		g_signal_connect (cell,
-				  "edited",
-				  G_CALLBACK (task_tree_start_edited),
+				  "calendar-activated",
+				  G_CALLBACK (task_tree_start_configure_popover_cb),
 				  GTK_TREE_VIEW (tree));
 		g_signal_connect (cell,
-				  "show-popup",
-				  G_CALLBACK (task_tree_start_show_popup),
+				  "calendar-mrptime-changed",
+				  G_CALLBACK (task_tree_start_mrptime_changed_cb),
+				  GTK_TREE_VIEW (tree));
+		g_signal_connect (cell,
+				  "calendar-constraint-type-changed",
+				  G_CALLBACK (task_tree_start_constraint_type_changed_cb),
+				  GTK_TREE_VIEW (tree));
+		g_signal_connect (cell,
+				  "calendar-closed",
+				  G_CALLBACK (task_tree_start_calendar_closed_cb),
 				  GTK_TREE_VIEW (tree));
 
 		col = gtk_tree_view_column_new_with_attributes (title,
@@ -2401,6 +2429,7 @@ task_tree_add_column (PlannerTaskTree *tree,
 				   "data-func", task_tree_start_data_func);
 		g_object_set_data (G_OBJECT (col), "id", "start");
 		break;
+	}
 
 	case COL_DURATION:
 		cell = gtk_cell_renderer_text_new ();
@@ -2464,10 +2493,10 @@ task_tree_add_column (PlannerTaskTree *tree,
 		break;
 
 	case COL_FINISH:
-		cell = planner_cell_renderer_date_new (FALSE);
+		cell = GTK_CELL_RENDERER (planner_cell_renderer_calendar_new (FALSE));
 		g_signal_connect (cell,
-				  "show-popup",
-				  G_CALLBACK (task_tree_start_show_popup),
+				  "calendar-activated",
+				  G_CALLBACK (task_tree_start_configure_popover_cb),
 				  GTK_TREE_VIEW (tree));
 
 		col = gtk_tree_view_column_new_with_attributes (title,
@@ -2541,7 +2570,7 @@ task_tree_add_column (PlannerTaskTree *tree,
 							 NULL);
 		g_object_set_data (G_OBJECT (col),
 				   "data-func", task_tree_assigned_to_data_func);
-		g_object_set_data (G_OBJECT (col), "id", "assigned_to");
+		g_object_set_data (G_OBJECT (col), "id", "assigned-to");
 		break;
 
 	default:
@@ -3347,8 +3376,12 @@ planner_task_tree_move_task_up (PlannerTaskTree *tree)
 		}
 	}
 
-	/* Reselect all the previous selected tasks. */
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
+
+	/* unselect every tasks since tasks have moved */
+	gtk_tree_selection_unselect_all( selection );
+
+	/* Reselect all the previous selected tasks. */
 	for (l = list; l; l = l->next) {
 		task = l->data;
 
@@ -3482,8 +3515,12 @@ planner_task_tree_move_task_down (PlannerTaskTree *tree)
 		}
 	}
 
-	/* Reselect all the previous selected tasks. */
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
+
+	/* unselect every tasks since tasks have moved */
+	gtk_tree_selection_unselect_all( selection );
+
+	/* Reselect all the previous selected tasks. */
 	for (l = list; l; l = l->next) {
 		task = l->data;
 
@@ -3720,3 +3757,11 @@ planner_task_tree_get_window (PlannerTaskTree       *tree)
 
 	return tree->priv->main_window;
 }
+
+GtkUIManager *
+planner_task_tree_get_popup_ui_manager (PlannerTaskTree       *tree)
+{
+	g_return_val_if_fail (PLANNER_IS_TASK_TREE (tree), NULL);
+
+	return tree->priv->popup_ui_manager;
+}
