@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_TASK_TREE_H__
-#define __PLANNER_TASK_TREE_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libplanner/mrp-project.h>
@@ -102,5 +101,3 @@ PlannerCmd*  planner_task_tree_task_cmd_link          (PlannerTaskTree       *tr
 PlannerWindow * planner_task_tree_get_window          (PlannerTaskTree       *tree);
 
 GtkUIManager * planner_task_tree_get_popup_ui_manager (PlannerTaskTree       *tree);
-
-#endif /* __PLANNER_TASK_TREE_H__ */
