@@ -30,7 +30,6 @@
 #include "planner-task-view.h"
 #include "libplanner/mrp-paths.h"
 #include "planner-conf.h"
-#include "planner-cell-renderer-date.h"
 #include "planner-task-dialog.h"
 #include "planner-property-dialog.h"
 #include "planner-gantt-model.h"
@@ -41,7 +40,7 @@
 
 struct _PlannerTaskViewPriv {
 	GtkWidget              *tree;
-	GtkWidget              *frame;
+	GtkWidget              *sw;
 	PlannerTablePrintSheet *print_sheet;
 	GtkUIManager           *ui_manager;
 	GtkActionGroup         *actions;
@@ -167,8 +166,8 @@ static const GtkToggleActionEntry toggle_entries[] = {
 	  G_CALLBACK (task_view_nonstandard_days_cb), FALSE }
 };
 
-#define CRITICAL_PATH_KEY  "/views/task_view/highlight_critical_path"
-#define NOSTDDAYS_PATH_KEY "/views/task_view/display_nonstandard_days"
+#define CRITICAL_PATH_KEY  "highlight-critical-path"
+#define NOSTDDAYS_PATH_KEY "display-nonstandard-days"
 
 G_DEFINE_TYPE (PlannerTaskView, planner_task_view, PLANNER_TYPE_VIEW);
 
@@ -253,8 +252,8 @@ task_view_activate (PlannerView *view)
 	gtk_ui_manager_ensure_update (priv->ui_manager);
 
 	/* Set the initial UI state. */
-	show_critical =   planner_conf_get_bool (CRITICAL_PATH_KEY, NULL);
-	show_nostd_days = planner_conf_get_bool (NOSTDDAYS_PATH_KEY, NULL);
+	show_critical =   planner_conf_get_bool (CRITICAL_PATH_KEY, "task");
+	show_nostd_days = planner_conf_get_bool (NOSTDDAYS_PATH_KEY, "task");
 	planner_task_tree_set_highlight_critical (PLANNER_TASK_TREE (priv->tree),
 						  show_critical);
 	planner_task_tree_set_nonstandard_days (PLANNER_TASK_TREE (priv->tree),
@@ -330,7 +329,6 @@ task_view_get_widget (PlannerView *view)
 {
 	PlannerTaskViewPriv *priv;
 	MrpProject          *project;
-	GtkWidget           *sw;
 	PlannerGanttModel   *model;
 
 	priv = PLANNER_TASK_VIEW (view)->priv;
@@ -343,16 +341,12 @@ task_view_get_widget (PlannerView *view)
 				  G_CALLBACK (task_view_project_loaded_cb),
 				  view);
 
-		sw = gtk_scrolled_window_new (NULL, NULL);
-		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+		priv->sw = gtk_scrolled_window_new (NULL, NULL);
+		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->sw),
 						GTK_POLICY_AUTOMATIC,
 						GTK_POLICY_AUTOMATIC);
-
-		priv->frame = gtk_frame_new (NULL);
-		gtk_frame_set_shadow_type (GTK_FRAME (priv->frame), GTK_SHADOW_IN);
-
-		gtk_container_add (GTK_CONTAINER (priv->frame), sw);
-
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (priv->sw),
+						     GTK_SHADOW_IN);
 		model = planner_gantt_model_new (project);
 
 		priv->tree = planner_task_tree_new (view->main_window,
@@ -384,7 +378,7 @@ task_view_get_widget (PlannerView *view)
 
 		task_view_load_columns (view);
 
-		gtk_container_add (GTK_CONTAINER (sw), priv->tree);
+		gtk_container_add (GTK_CONTAINER (priv->sw), priv->tree);
 
 		g_signal_connect (priv->tree,
 				  "columns-changed",
@@ -412,11 +406,10 @@ task_view_get_widget (PlannerView *view)
 				  view);
 
 		gtk_widget_show (priv->tree);
-		gtk_widget_show (sw);
-		gtk_widget_show (priv->frame);
+		gtk_widget_show (priv->sw);
 	}
 
-	return priv->frame;
+	return priv->sw;
 }
 
 static void
@@ -627,7 +620,7 @@ task_view_highlight_critical_cb (GtkAction *action,
 		PLANNER_TASK_TREE (priv->tree),
 		state);
 
-	planner_conf_set_bool (CRITICAL_PATH_KEY, state, NULL);
+	planner_conf_set_bool (CRITICAL_PATH_KEY, state, "task");
 }
 
 static void
@@ -646,7 +639,7 @@ task_view_nonstandard_days_cb (GtkAction *action,
 		state);
 
 
-	planner_conf_set_bool (NOSTDDAYS_PATH_KEY, state, NULL);
+	planner_conf_set_bool (NOSTDDAYS_PATH_KEY, state, "task");
 }
 
 static void
@@ -794,72 +787,20 @@ task_view_save_columns (PlannerView *view)
 
 	priv = PLANNER_TASK_VIEW (view)->priv;
 
-	planner_view_column_save_helper (view, GTK_TREE_VIEW (priv->tree));
+	planner_view_column_save_helper (view, GTK_TREE_VIEW (priv->tree),
+					 "task");
 }
 
 static void
 task_view_load_columns (PlannerView *view)
 {
 	PlannerTaskViewPriv *priv;
-	GList               *columns, *l;
-	GtkTreeViewColumn   *column;
-	const gchar         *id;
-	gint                 i;
 
 	priv = PLANNER_TASK_VIEW (view)->priv;
 
 	/* Load the columns. */
-	planner_view_column_load_helper (view, GTK_TREE_VIEW (priv->tree));
-
-	/* Make things a bit more robust by setting defaults if we don't get any
-	 * visible columns. Should be done through a schema instead (but we'll
-	 * keep this since a lot of people get bad installations when installing
-	 * themselves).
-	 */
-	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (priv->tree));
-	i = 0;
-	for (l = columns; l; l = l->next) {
-		if (gtk_tree_view_column_get_visible (l->data)) {
-			i++;
-		}
-	}
-
-	if (i == 0) {
-		for (l = columns; l; l = l->next) {
-			column = l->data;
-
-			if (g_object_get_data (G_OBJECT (column), "custom")) {
-				continue;
-			}
-
-			id = g_object_get_data (G_OBJECT (column), "id");
-
-			g_print ("%s\n", id);
-
-			if (!id) {
-				continue;
-			}
-
-
-			if (strcmp (id, "wbs") == 0 ||
-			    strcmp (id, "name") == 0 ||
-			    strcmp (id, "start") == 0 ||
-			    strcmp (id, "finish") == 0 ||
-			    strcmp (id, "work") == 0 ||
-			    strcmp (id, "duration") == 0 ||
-			    strcmp (id, "duration") == 0 ||
-			    strcmp (id, "slack") == 0 ||
-			    strcmp (id, "cost") == 0 ||
-			    strcmp (id, "complete") == 0 ||
-			    strcmp (id, "assigned-to")) {
-				gtk_tree_view_column_set_visible (column, TRUE);
-			} else {
-				gtk_tree_view_column_set_visible (column, FALSE);
-			}
-		}
-	}
-
-	g_list_free (columns);
+	planner_view_column_load_helper (view, GTK_TREE_VIEW (priv->tree),
+					 "task");
 }
 
 PlannerView *
