@@ -48,11 +48,11 @@
 #define ZOOM_OUT_LIMIT 0
 
 #define DEFAULT_ZOOM_LEVEL 7
-#define SCALE(n) (f*pow(2,(n)-19))
-#define ZOOM(x) (log((x)/f)/log(2)+19)
+#define SCALE(n) (font_width_factor*pow(2,(n)-19))
+#define ZOOM(x) (log((x)/font_width_factor)/log(2)+19)
 
 /* Font width factor. */
-static gdouble f = 1.0;
+static gdouble font_width_factor = 1.0;
 
 typedef struct _TreeNode TreeNode;
 typedef void (*TreeFunc) (TreeNode *node, gpointer data);
@@ -78,6 +78,8 @@ struct _PlannerUsageChartPriv {
 
 	GtkAdjustment   *hadjustment;
 	GtkAdjustment   *vadjustment;
+	guint            hscroll_policy : 1;
+	guint            vscroll_policy : 1;
 
 	GtkTreeModel    *model;
 	TreeNode        *tree;
@@ -100,7 +102,12 @@ enum {
 	PROP_0,
 	PROP_HEADER_HEIGHT,
 	PROP_ROW_HEIGHT,
-	PROP_MODEL
+	PROP_MODEL,
+	/* Scrollable interface */
+	PROP_HADJUSTMENT,
+	PROP_VADJUSTMENT,
+	PROP_HSCROLL_POLICY,
+	PROP_VSCROLL_POLICY
 };
 
 enum {
@@ -122,17 +129,17 @@ static void      usage_chart_get_property          (GObject                 *obj
 						     GParamSpec              *spec);
 static void      usage_chart_set_zoom              (PlannerUsageChart      *chart,
 						     gdouble                  level);
-static void      usage_chart_destroy               (GtkObject               *object);
-static void      usage_chart_style_set             (GtkWidget               *widget,
-						     GtkStyle                *prev_style);
+static void      usage_chart_destroy               (GtkWidget               *widget);
+static void      usage_chart_style_updated         (GtkWidget               *widget);
 static void      usage_chart_realize               (GtkWidget               *widget);
 static void      usage_chart_map                   (GtkWidget               *widget);
 static void      usage_chart_unrealize             (GtkWidget               *widget);
 static void      usage_chart_size_allocate         (GtkWidget               *widget,
 						     GtkAllocation           *allocation);
-static void      usage_chart_set_adjustments       (PlannerUsageChart      *chart,
-						     GtkAdjustment           *hadj,
-						     GtkAdjustment           *vadj);
+static void      usage_chart_set_hadjustment       (PlannerUsageChart       *chart,
+						    GtkAdjustment           *hadj);
+static void      usage_chart_set_vadjustment       (PlannerUsageChart       *chart,
+						    GtkAdjustment           *vadj);
 static void      usage_chart_reflow_now            (PlannerUsageChart      *chart);
 static void      usage_chart_reflow                (PlannerUsageChart      *chart,
 						     gboolean                 height_changed);
@@ -199,7 +206,7 @@ static void      usage_chart_row_deleted           (GtkTreeModel            *mod
 
 
 static guint signals[LAST_SIGNAL];
-static GtkVBoxClass *parent_class = NULL;
+static GtkBoxClass *parent_class = NULL;
 
 GType
 planner_usage_chart_get_type (void)
@@ -218,9 +225,18 @@ planner_usage_chart_get_type (void)
 			0,      /* n_preallocs */
 			(GInstanceInitFunc) usage_chart_init
 		};
-		type = g_type_register_static (GTK_TYPE_VBOX,
+
+		static const GInterfaceInfo scrollable_info = {
+			(GInterfaceInitFunc) NULL,
+			NULL,
+			NULL
+		};
+
+		type = g_type_register_static (GTK_TYPE_BOX,
 					       "PlannerUsageChart", &info,
 					       0);
+
+		g_type_add_interface_static (type, GTK_TYPE_SCROLLABLE, &scrollable_info);
 	}
 	return type;
 }
@@ -229,39 +245,24 @@ static void
 usage_chart_class_init (PlannerUsageChartClass * class)
 {
 	GObjectClass      *o_class;
-	GtkObjectClass    *object_class;
 	GtkWidgetClass    *widget_class;
 
 	parent_class = g_type_class_peek_parent (class);
 
 	o_class = (GObjectClass *) class;
-	object_class = (GtkObjectClass *) class;
 	widget_class = (GtkWidgetClass *) class;
 
 	o_class->set_property = usage_chart_set_property;
 	o_class->get_property = usage_chart_get_property;
 	o_class->finalize = usage_chart_finalize;
 
-	object_class->destroy = usage_chart_destroy;
-
-	widget_class->style_set = usage_chart_style_set;
+	widget_class->destroy = usage_chart_destroy;
+	widget_class->style_updated = usage_chart_style_updated;
 	widget_class->realize = usage_chart_realize;
 	widget_class->map = usage_chart_map;
 	widget_class->unrealize = usage_chart_unrealize;
 	widget_class->size_allocate = usage_chart_size_allocate;
 
-	class->set_scroll_adjustments = usage_chart_set_adjustments;
-
-	widget_class->set_scroll_adjustments_signal =
-		g_signal_new ("set_scroll_adjustments",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (PlannerUsageChartClass,
-					       set_scroll_adjustments), NULL,
-			      NULL, planner_marshal_VOID__OBJECT_OBJECT,
-			      G_TYPE_NONE, 2, GTK_TYPE_ADJUSTMENT,
-			      GTK_TYPE_ADJUSTMENT);
-
 	signals[STATUS_UPDATED] =
 		g_signal_new ("status_updated",
 			      G_TYPE_FROM_CLASS (class),
@@ -269,8 +270,14 @@ usage_chart_class_init (PlannerUsageChartClass * class)
 			      0, NULL, NULL,
 			      planner_marshal_VOID__POINTER,
 			      G_TYPE_NONE, 1, G_TYPE_POINTER);
-	/* Properties. */
 
+	/* GtkScrollable interface properties */
+	g_object_class_override_property (o_class, PROP_HADJUSTMENT,    "hadjustment");
+	g_object_class_override_property (o_class, PROP_VADJUSTMENT,    "vadjustment");
+	g_object_class_override_property (o_class, PROP_HSCROLL_POLICY, "hscroll-policy");
+	g_object_class_override_property (o_class, PROP_VSCROLL_POLICY, "vscroll-policy");
+
+	/* Properties. */
 	g_object_class_install_property (o_class,
 					 PROP_MODEL,
 					 g_param_spec_object ("model",
@@ -339,8 +346,10 @@ usage_chart_init (PlannerUsageChart * chart)
 			    0);
 
 	priv->canvas = GNOME_CANVAS (gnome_canvas_new ());
+	/* TODO: Consider porting these over to gtk3
 	priv->canvas->close_enough = 5;
 	gnome_canvas_set_center_scroll_region (priv->canvas, FALSE);
+	 */
 
 	/* Easiest way to get access to the chart from the canvas items. */
 	g_object_set_data (G_OBJECT (priv->canvas), "chart", chart);
@@ -356,6 +365,14 @@ usage_chart_init (PlannerUsageChart * chart)
 				       PLANNER_TYPE_GANTT_BACKGROUND, "scale",
 				       SCALE (priv->zoom), "zoom", priv->zoom,
 				       NULL);
+
+	g_object_bind_property (chart, "hadjustment",
+				priv->header, "hadjustment",
+				G_BINDING_DEFAULT);
+	g_object_bind_property (chart, "hadjustment",
+				priv->canvas, "hadjustment",
+				G_BINDING_DEFAULT);
+
 }
 
 static TreeNode *
@@ -389,6 +406,20 @@ usage_chart_set_property (GObject * object,
 		chart->priv->row_height = g_value_get_int (value);
 		usage_chart_reflow (chart, TRUE);
 		break;
+	case PROP_HADJUSTMENT:
+		usage_chart_set_hadjustment (chart, g_value_get_object (value));
+		break;
+	case PROP_VADJUSTMENT:
+		usage_chart_set_vadjustment (chart, g_value_get_object (value));
+		break;
+	case PROP_HSCROLL_POLICY:
+		chart->priv->hscroll_policy = g_value_get_enum (value);
+		gtk_widget_queue_resize (GTK_WIDGET (chart));
+		break;
+	case PROP_VSCROLL_POLICY:
+		chart->priv->hscroll_policy = g_value_get_enum (value);
+		gtk_widget_queue_resize (GTK_WIDGET (chart));
+		break;
 	default:
 		break;
 	}
@@ -406,6 +437,18 @@ usage_chart_get_property (GObject * object,
 	case PROP_MODEL:
 		g_value_set_object (value, G_OBJECT (chart->priv->model));
 		break;
+	case PROP_HADJUSTMENT:
+		g_value_set_object (value, chart->priv->hadjustment);
+		break;
+	case PROP_VADJUSTMENT:
+		g_value_set_object (value, chart->priv->vadjustment);
+		break;
+	case PROP_HSCROLL_POLICY:
+		g_value_set_enum (value, chart->priv->hscroll_policy);
+		break;
+	case PROP_VSCROLL_POLICY:
+		g_value_set_enum (value, chart->priv->vscroll_policy);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, spec);
 		break;
@@ -439,13 +482,15 @@ static mrptime
 usage_chart_get_center (PlannerUsageChart * chart)
 {
 	PlannerUsageChartPriv *priv;
-	gint                    x1, width, x;
+	gint                   x1, width, x;
+	GtkAllocation          allocation;
 
 	priv = chart->priv;
 
 	gnome_canvas_get_scroll_offsets (priv->canvas, &x1, NULL);
 
-	width = GTK_WIDGET (priv->canvas)->allocation.width;
+	gtk_widget_get_allocation (GTK_WIDGET (priv->canvas), &allocation);
+	width = allocation.width;
 
 	x = x1 + width / 2 - PADDING;
 	x += floor (priv->project_start * SCALE (priv->zoom) + 0.5);
@@ -457,13 +502,15 @@ static void
 usage_chart_set_center (PlannerUsageChart *chart, mrptime t)
 {
 	PlannerUsageChartPriv *priv;
-	gint                    x1, width, x;
+	gint                   x1, width, x;
+	GtkAllocation          allocation;
 
 	priv = chart->priv;
 
 	x = floor (t * SCALE (priv->zoom) + 0.5);
 
-	width = GTK_WIDGET (priv->canvas)->allocation.width;
+	gtk_widget_get_allocation (GTK_WIDGET (priv->canvas), &allocation);
+	width = allocation.width;
 
 	x1 = x - width / 2 + PADDING;
 	x1 -= floor (priv->project_start * SCALE (priv->zoom) + 0.5);
@@ -535,6 +582,7 @@ planner_usage_chart_zoom_to_fit (PlannerUsageChart *chart)
 	gdouble                 t;
 	gdouble                 zoom;
 	gdouble                 alloc;
+	GtkAllocation           allocation;
 
 	g_return_if_fail (PLANNER_IS_USAGE_CHART (chart));
 
@@ -543,7 +591,8 @@ planner_usage_chart_zoom_to_fit (PlannerUsageChart *chart)
 		return;
 	}
 
-	alloc = GTK_WIDGET (chart)->allocation.width - PADDING * 2;
+	gtk_widget_get_allocation (GTK_WIDGET (chart), &allocation);
+	alloc = allocation.width - PADDING * 2;
 
 	zoom = planner_scale_clamp_zoom (ZOOM (alloc / t));
 	usage_chart_set_zoom (chart, zoom);
@@ -584,11 +633,11 @@ usage_chart_finalize (GObject *object)
 }
 
 static void
-usage_chart_destroy (GtkObject *object)
+usage_chart_destroy (GtkWidget *widget)
 {
 	PlannerUsageChart *chart;
 
-	chart = PLANNER_USAGE_CHART (object);
+	chart = PLANNER_USAGE_CHART (widget);
 
 	if (chart->priv->model != NULL) {
 		usage_chart_disconnect_signals (chart);
@@ -596,36 +645,34 @@ usage_chart_destroy (GtkObject *object)
 		chart->priv->model = NULL;
 	}
 
-	if (GTK_OBJECT_CLASS (parent_class)->destroy) {
-		(*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+	if (GTK_WIDGET_CLASS (parent_class)->destroy) {
+		(*GTK_WIDGET_CLASS (parent_class)->destroy) (widget);
 	}
 }
 
 static void
-usage_chart_style_set (GtkWidget *widget, GtkStyle *prev_style)
+usage_chart_style_updated (GtkWidget *widget)
 {
-	PlannerUsageChart     *chart;
-	PlannerUsageChartPriv *priv;
-	GtkWidget              *canvas;
-	PangoContext           *context;
-	PangoFontMetrics       *metrics;
+	PlannerUsageChart *chart;
+	PangoContext      *context;
+	PangoFontMetrics  *metrics;
 
-	if (GTK_WIDGET_CLASS (parent_class)->style_set) {
-		GTK_WIDGET_CLASS (parent_class)->style_set (widget,
-							    prev_style);
+	if (GTK_WIDGET_CLASS (parent_class)->style_updated) {
+		GTK_WIDGET_CLASS (parent_class)->style_updated (widget);
 	}
 
 	chart = PLANNER_USAGE_CHART (widget);
-	priv = chart->priv;
 
-	canvas = GTK_WIDGET (priv->canvas);
+	context = gtk_widget_get_pango_context (GTK_WIDGET (chart->priv->canvas));
+
+	metrics = pango_context_get_metrics (context, NULL, NULL);
+
+	font_width_factor = 0.2 * pango_font_metrics_get_approximate_char_width (metrics) / PANGO_SCALE;
 
-	context = gtk_widget_get_pango_context (canvas);
-	metrics = pango_context_get_metrics (context,
-					     canvas->style->font_desc, NULL);
-	f = 0.2 * pango_font_metrics_get_approximate_char_width (metrics) /
-		PANGO_SCALE;
 	pango_font_metrics_unref(metrics);
+
+	/* Re-layout with the new factor. */
+	usage_chart_set_zoom (PLANNER_USAGE_CHART (widget), chart->priv->zoom);
 }
 
 static void
@@ -633,9 +680,10 @@ usage_chart_realize (GtkWidget *widget)
 {
 	PlannerUsageChart     *chart;
 	PlannerUsageChartPriv *priv;
-	GtkWidget              *canvas;
-	GtkStyle               *style;
-	GdkColormap            *colormap;
+	GtkWidget             *canvas;
+	GtkStyleContext       *style_context;
+	GtkCssProvider        *css_provider;
+	GError                *error = NULL;
 
 	chart = PLANNER_USAGE_CHART (widget);
 	priv = chart->priv;
@@ -647,11 +695,20 @@ usage_chart_realize (GtkWidget *widget)
 	}
 
 	/* Set the background to white. */
-	style = gtk_style_copy (canvas->style);
-	colormap = gtk_widget_get_colormap (canvas);
-	gdk_color_white (colormap, &style->bg[GTK_STATE_NORMAL]);
-	gtk_widget_set_style (canvas, style);
-	g_object_unref (style);
+	css_provider = gtk_css_provider_new ();
+	gtk_css_provider_load_from_data (css_provider,
+					 "@define-color theme_bg_color white;",
+					 -1, &error);
+	style_context = gtk_widget_get_style_context (canvas);
+	if (error == NULL) {
+		gtk_style_context_add_provider (style_context,
+						GTK_STYLE_PROVIDER (css_provider),
+						GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	} else {
+		g_warning ("%s: %s", G_STRFUNC, error->message);
+		g_clear_error (&error);
+	}
+	g_object_unref (css_provider);
 
 	usage_chart_set_zoom (chart, priv->zoom);
 }
@@ -699,50 +756,63 @@ usage_chart_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 }
 
 static void
-usage_chart_set_adjustments (PlannerUsageChart *chart,
-			      GtkAdjustment      *hadj,
-			      GtkAdjustment      *vadj)
+usage_chart_set_hadjustment (PlannerUsageChart *chart,
+                             GtkAdjustment     *hadj)
 {
-	PlannerUsageChartPriv *priv;
+	if (hadj && chart->priv->hadjustment == hadj)
+		return;
 
-	gboolean need_adjust = FALSE;
+	if (hadj)
+		g_return_if_fail (GTK_IS_ADJUSTMENT (hadj));
+	else
+		hadj = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 0.0, 0.0, 0.0, 0.0));
 
-	g_return_if_fail (hadj == NULL || GTK_IS_ADJUSTMENT (hadj));
-	g_return_if_fail (vadj == NULL || GTK_IS_ADJUSTMENT (vadj));
-
-	priv = chart->priv;
+	if (chart->priv->hadjustment != NULL) {
+		g_signal_handlers_disconnect_matched (chart->priv->hadjustment,
+						      G_SIGNAL_MATCH_DATA,
+						      0, 0, NULL, NULL,
+						      chart);
+		g_object_unref (chart->priv->hadjustment);
+	}
 
 	if (hadj == NULL) {
 		hadj = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 0.0, 0.0, 0.0, 0.0));
 	}
-	if (vadj == NULL) {
+
+	/* TODO: value-changed handler? If not adding, disconnecting above is probably unnecessary too */
+	chart->priv->hadjustment = g_object_ref_sink (hadj);
+	/* TODO: Do we need to set the initial hadj values? */
+	/* TODO: Share the hadjustment with header and canvas? */
+
+	g_object_notify (G_OBJECT (chart), "hadjustment");
+}
+
+static void
+usage_chart_set_vadjustment (PlannerUsageChart *chart,
+                             GtkAdjustment     *vadj)
+{
+	if (vadj && chart->priv->vadjustment == vadj)
+		return;
+
+	if (vadj)
+		g_return_if_fail (GTK_IS_ADJUSTMENT (vadj));
+	else
 		vadj = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 0.0, 0.0, 0.0, 0.0));
-	}
-	if (priv->hadjustment && (priv->hadjustment != hadj)) {
-		g_object_unref (priv->hadjustment);
-	}
-	if (priv->vadjustment && (priv->vadjustment != hadj)) {
-		g_object_unref (priv->vadjustment);
+
+	if (chart->priv->vadjustment != NULL) {
+		g_signal_handlers_disconnect_matched (chart->priv->vadjustment,
+						      G_SIGNAL_MATCH_DATA,
+						      0, 0, NULL, NULL,
+						      chart);
+		g_object_unref (chart->priv->vadjustment);
 	}
 
-	if (priv->hadjustment != hadj) {
-		priv->hadjustment = hadj;
-		g_object_ref (priv->hadjustment);
-		gtk_object_sink (GTK_OBJECT (priv->hadjustment));
-		gtk_widget_set_scroll_adjustments (priv->header, hadj, NULL);
-		need_adjust = TRUE;
-	}
-	if (priv->vadjustment != vadj) {
-		priv->vadjustment = vadj;
-		g_object_ref (priv->vadjustment);
-		gtk_object_sink (GTK_OBJECT (priv->vadjustment));
-		need_adjust = TRUE;
-	}
+	/* TODO: value-changed handler? If not adding, disconnecting above is probably unnecessary too */
+	chart->priv->vadjustment = g_object_ref_sink (vadj);
+	/* TODO: Do we need to set the initial vadj values? */
+	/* TODO: Share the vadjustment with canvas? */
 
-	if (need_adjust) {
-		gtk_widget_set_scroll_adjustments (GTK_WIDGET (priv->canvas),
-						   hadj, vadj);
-	}
+	g_object_notify (G_OBJECT (chart), "vadjustment");
 }
 
 static gboolean
@@ -818,7 +888,7 @@ usage_chart_reflow_idle (PlannerUsageChart *chart)
 		height = priv->height;
 	}
 
-	allocation = GTK_WIDGET (priv->canvas)->allocation;
+	gtk_widget_get_allocation (GTK_WIDGET (priv->canvas), &allocation);
 
 	t1 = priv->project_start;
 	t2 = priv->last_time;
@@ -949,7 +1019,9 @@ planner_usage_chart_new_with_model (GtkTreeModel *model)
 {
 	PlannerUsageChart *chart;
 
-	chart = g_object_new (PLANNER_TYPE_USAGE_CHART, NULL);
+	chart = g_object_new (PLANNER_TYPE_USAGE_CHART,
+			      "orientation", GTK_ORIENTATION_VERTICAL,
+			      NULL);
 
 	if (model) {
 		planner_usage_chart_set_model (chart, model);
@@ -1510,7 +1582,7 @@ usage_chart_remove_children (PlannerUsageChart *chart, TreeNode *node)
 		usage_chart_remove_children (chart, node->children[i]);
 	}
 
-	gtk_object_destroy (GTK_OBJECT (node->item));
+	g_object_run_dispose (G_OBJECT (node->item));
 	node->item = NULL;
 
 	node->assignment = NULL;
