@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_USAGE_MODEL_H__
-#define __PLANNER_USAGE_MODEL_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libplanner/mrp-project.h>
@@ -80,6 +79,3 @@ gboolean            planner_usage_model_path_is_resource       (PlannerUsageMode
 								 GtkTreePath        *path);
 gboolean            planner_usage_model_path_is_assignment     (PlannerUsageModel *model,
 								 GtkTreePath        *Path);
-
-
-#endif /* __PLANNER_USAGE_MODEL_H__ */
