@@ -19,8 +19,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_USAGE_ROW_H__
-#define __PLANNER_USAGE_ROW_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libgnomecanvas/gnome-canvas.h>
@@ -54,6 +53,3 @@ void planner_usage_row_get_geometry (PlannerUsageRow *row,
 				     gdouble         *y2);
 void planner_usage_row_set_visible  (PlannerUsageRow *row,
 				     gboolean         is_visible);
-
-
-#endif /* __PLANNER_USAGE_ROW_H__ */
