@@ -20,8 +20,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_USAGE_TREE__
-#define __PLANNER_USAGE_TREE__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <libplanner/mrp-project.h>
@@ -59,6 +58,3 @@ void       planner_usage_tree_edit_resource      (PlannerUsageTree  *tree);
 GList *    planner_usage_tree_get_selected_items (PlannerUsageTree  *tree);
 void       planner_usage_tree_expand_all         (PlannerUsageTree  *tree);
 void       planner_usage_tree_collapse_all       (PlannerUsageTree  *tree);
-
-
-#endif /* __PLANNER_USAGE_TREE__ */
