@@ -18,8 +18,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_UTIL_H__
-#define __PLANNER_UTIL_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <glib.h>
@@ -33,6 +32,3 @@ void planner_util_menu_position_on_current_cell (GtkMenu  *menu,
                                                  gint     *y,
                                                  gboolean *push_in,
                                                  gpointer  user_data);
-
-#endif /* __PLANNER_UTIL_H__ */
-
