@@ -18,8 +18,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLANNER_VIEW_H__
-#define __PLANNER_VIEW_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include "planner-window.h"
@@ -90,6 +89,3 @@ void         planner_view_column_load_helper (PlannerView     *view,
 void         planner_view_column_save_helper (PlannerView     *view,
 					      GtkTreeView     *tree,
 					      const gchar     *set);
-
-#endif /* __PLANNER_VIEW_H__ */
-
