@@ -27,7 +27,6 @@
 #include <glib/gi18n.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <libplanner/mrp-error.h>
 #include <libplanner/mrp-project.h>
 #include <libplanner/mrp-paths.h>
@@ -192,17 +191,13 @@ static void window_connect_proxy_cb (GtkUIManager  *manager,
 				     GtkWidget     *proxy,
 				     PlannerWindow *window);
 
-#define CONF_WINDOW_DIR       "/ui"
-#define CONF_WINDOW_MAXIMIZED "/ui/main_window_maximized"
-#define CONF_WINDOW_WIDTH     "/ui/main_window_width"
-#define CONF_WINDOW_HEIGHT    "/ui/main_window_height"
-#define CONF_WINDOW_POS_X     "/ui/main_window_position_x"
-#define CONF_WINDOW_POS_Y     "/ui/main_window_position_y"
-#define CONF_ACTIVE_VIEW           "/ui/active_view"
-#define CONF_LAST_DIR         "/general/last_dir"
-
-#define DEFAULT_WINDOW_WIDTH  800
-#define DEFAULT_WINDOW_HEIGHT 550
+#define CONF_WINDOW_MAXIMIZED "main-window-maximized"
+#define CONF_WINDOW_WIDTH     "main-window-width"
+#define CONF_WINDOW_HEIGHT    "main-window-height"
+#define CONF_WINDOW_POS_X     "main-window-position-x"
+#define CONF_WINDOW_POS_Y     "main-window-position-y"
+#define CONF_ACTIVE_VIEW           "active-view"
+#define CONF_LAST_DIR         "last-dir"
 
 #define VIEW_PATH "/menu/View/Views placeholder"
 #define VIEW_GROUP "view group"
@@ -572,7 +567,7 @@ window_populate (PlannerWindow *window)
 
 	window_add_stock_icons ();
 
-	priv->ui_box = gtk_vbox_new (FALSE, 0);
+	priv->ui_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add (GTK_CONTAINER (window), priv->ui_box);
 
 	priv->actions = gtk_action_group_new ("Planner");
@@ -643,7 +638,7 @@ window_populate (PlannerWindow *window)
 	open_recent = gtk_ui_manager_get_widget (priv->ui_manager, "/MenuBar/File/FileOpenRecent");
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (open_recent), recent_view);
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
 	priv->sidebar = planner_sidebar_new ();
 	gtk_box_pack_start (GTK_BOX (hbox), priv->sidebar, FALSE, TRUE, 0);
@@ -727,7 +722,7 @@ window_populate (PlannerWindow *window)
 	/* Load plugins. */
 	priv->plugins = planner_plugin_loader_load (window);
 
-	str = planner_conf_get_string (CONF_ACTIVE_VIEW, NULL);
+	str = planner_conf_get_string (CONF_ACTIVE_VIEW, "ui");
 	if (str) {
 		gboolean found;
 
@@ -798,7 +793,8 @@ window_view_selected (PlannerSidebar *sidebar,
 
 	priv->current_view = view;
 
-	planner_conf_set_string (CONF_ACTIVE_VIEW, planner_view_get_name (view), NULL);
+	planner_conf_set_string (CONF_ACTIVE_VIEW,
+				 planner_view_get_name (view), "ui");
 }
 
 static void
@@ -838,9 +834,10 @@ get_last_dir (PlannerWindow *window)
 {
 	gchar             *last_dir;
 
-	last_dir = planner_conf_get_string (CONF_LAST_DIR, NULL);
+	last_dir = planner_conf_get_string (CONF_LAST_DIR, "gen");
 
-	if (last_dir == NULL) {
+	if (!last_dir[0]) {
+		g_free (last_dir);
 		last_dir = g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS));
 	}
 
@@ -902,7 +899,7 @@ window_open_cb (GtkAction *action,
 			if (filename) {
 				last_dir = g_path_get_dirname (filename);
 				g_free (filename);
-				planner_conf_set_string (CONF_LAST_DIR, last_dir, NULL);
+				planner_conf_set_string (CONF_LAST_DIR, last_dir, "gen");
 				g_free (last_dir);
 			}
 		}
@@ -1181,7 +1178,7 @@ window_about_cb (GtkAction *action,
 			       "authors", authors,
 			       "documenters", documenters,
 			       "translator-credits", _("translator-credits"),
-			       "website", "http://live.gnome.org/Planner",
+			       "website", "https://wiki.gnome.org/Apps/Planner",
 			       "website-label", _("The Planner Homepage"),
 			       "logo", pixbuf,
 			       NULL);
@@ -1212,13 +1209,14 @@ window_drag_data_received_cb (GtkWidget        *widget,
 	gchar             **uris;
 	gint                i;
 
-	if (data->length < 0 || data->format != 8) {
-		g_message ("Don't know how to handle format %d", data->format);
+	if (gtk_selection_data_get_length (data) < 0 || gtk_selection_data_get_format (data) != 8) {
+		g_message ("Don't know how to handle format %d",
+			   gtk_selection_data_get_format (data));
 		gtk_drag_finish (context, FALSE, FALSE, time);
 		return;
 	}
 
-	uris = g_uri_list_extract_uris (data->data);
+	uris = gtk_selection_data_get_uris (data);
 
 	i = 0;
 	while (uris[i]) {
@@ -1311,19 +1309,26 @@ static gboolean
 window_confirm_exit_run (PlannerWindow *window)
 {
 	PlannerWindowPriv *priv;
-	gchar            *time_str;
 	GtkWidget        *dialog;
 	GtkWidget        *quit_button, *cancel_button, *save_button;
 	gint              ret;
 	gint              minutes;
 	gint              hours;
 	gchar            *name;
-	gchar            *tmp;
 	const gchar      *uri;
 	gboolean          is_sql = FALSE;
 
 	priv = window->priv;
 
+	name = window_get_name (window);
+	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+					 GTK_DIALOG_MODAL |
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_WARNING,
+					 GTK_BUTTONS_NONE,
+					 _("Save changes to document '%s' before closing?"), name);
+	g_free (name);
+
 	minutes = (gint) (g_timer_elapsed (priv->last_saved, NULL) / 60);
 
 	minutes = MAX (1, minutes);
@@ -1331,53 +1336,27 @@ window_confirm_exit_run (PlannerWindow *window)
 	minutes -= 60 * hours;
 
 	if (hours == 0 && minutes == 1) {
-		time_str = g_strdup (_("If you don't save, changes made "
-				       "the last minute will be discarded."));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+			_("If you don't save, changes made the last minute will be discarded."));
 	}
 	else if (hours == 0) {
-		time_str =
-			g_strdup_printf (ngettext(
-					   "If you don't save, changes made "
-					   "the last %d minute will be "
-					   "discarded.",
-					   "If you don't save, changes made "
-					   "the last %d minutes will be "
-					   "discarded.", minutes), minutes);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+			ngettext("If you don't save, changes made the last %d minute will be discarded.",
+				 "If you don't save, changes made the last %d minutes will be discarded.",
+				 minutes),
+			minutes);
 	}
 	else if (hours == 1) {
-		time_str = g_strdup (_("If you don't save, changes made "
-				       "the last hour will be "
-				       "discarded."));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+			_("If you don't save, changes made the last hour will be discarded."));
 	} else {
-		time_str =
-			g_strdup_printf (ngettext("If you don't save, changes made "
-					   "the last %d hour will be "
-					   "discarded.",
-					   "If you don't save, changes made "
-					   "the last %d hours will be "
-					   "discarded.", hours), hours);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+			ngettext("If you don't save, changes made the last %d hour will be discarded.",
+				 "If you don't save, changes made the last %d hours will be discarded.",
+				 hours),
+			hours);
 	}
 
-	name = window_get_name (window);
-
-	tmp = g_strdup_printf (_("Save changes to document '%s' before closing?"), name);
-
-	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-					 GTK_DIALOG_MODAL |
-					 GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_WARNING,
-					 GTK_BUTTONS_NONE,
-					 "<b>%s</b>\n%s", tmp, time_str);
-	g_free (name);
-	g_free (time_str);
-	g_free (tmp);
-
-	g_object_set (GTK_MESSAGE_DIALOG (dialog)->label,
-		      "use-markup", TRUE,
-		      "wrap", FALSE,
-		      "selectable", FALSE,
-		      NULL);
-
 	uri = mrp_project_get_uri (priv->project);
 	if (uri && strncmp (uri, "sql://", 6) == 0) {
 		/* Hack. */
@@ -1572,7 +1551,7 @@ window_do_save_as (PlannerWindow *window)
 		}
 
 		last_dir = g_path_get_dirname (filename);
-		planner_conf_set_string (CONF_LAST_DIR, last_dir, NULL);
+		planner_conf_set_string (CONF_LAST_DIR, last_dir, "gen");
 		g_free (last_dir);
 
 		g_free (filename);
@@ -1599,7 +1578,7 @@ window_create_dialog_button (const gchar *icon_name, const gchar *text)
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
 
-	hbox = gtk_hbox_new (FALSE, 2);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
 
 	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
 
@@ -1946,14 +1925,14 @@ window_save_state (PlannerWindow *window)
 	GdkWindowState     state;
 	gboolean           maximized;
 
-	state = gdk_window_get_state (GTK_WIDGET (window)->window);
+	state = gdk_window_get_state (gtk_widget_get_window (GTK_WIDGET (window)));
 	if (state & GDK_WINDOW_STATE_MAXIMIZED) {
 		maximized = TRUE;
 	} else {
 		maximized = FALSE;
 	}
 
-	planner_conf_set_bool (CONF_WINDOW_MAXIMIZED, maximized, NULL);
+	planner_conf_set_bool (CONF_WINDOW_MAXIMIZED, maximized, "ui");
 
 	/* If maximized don't save the size and position */
 	if (!maximized) {
@@ -1961,56 +1940,38 @@ window_save_state (PlannerWindow *window)
 		int x, y;
 
 		gtk_window_get_size (GTK_WINDOW (window), &width, &height);
-		planner_conf_set_int (CONF_WINDOW_WIDTH, width, NULL);
-		planner_conf_set_int (CONF_WINDOW_HEIGHT, height, NULL);
+		planner_conf_set_int (CONF_WINDOW_WIDTH, width, "ui");
+		planner_conf_set_int (CONF_WINDOW_HEIGHT, height, "ui");
 
 		gtk_window_get_position (GTK_WINDOW (window), &x, &y);
-		planner_conf_set_int (CONF_WINDOW_POS_X, x, NULL);
-		planner_conf_set_int (CONF_WINDOW_POS_Y, y, NULL);
+		planner_conf_set_int (CONF_WINDOW_POS_X, x, "ui");
+		planner_conf_set_int (CONF_WINDOW_POS_Y, y, "ui");
 	}
+
+	g_settings_sync ();
 }
 
 static void
 window_restore_state (PlannerWindow *window)
 {
-	gboolean           exists;
 	gboolean           maximized;
 	int                width, height;
 	int                x, y;
 
-	exists = planner_conf_dir_exists (CONF_WINDOW_DIR, NULL);
+	maximized = planner_conf_get_bool (CONF_WINDOW_MAXIMIZED, "ui");
 
-	if (exists) {
-		maximized = planner_conf_get_bool (CONF_WINDOW_MAXIMIZED,
-						   NULL);
-
-		if (maximized) {
-			gtk_window_maximize (GTK_WINDOW (window));
-		} else {
-			width = planner_conf_get_int (CONF_WINDOW_WIDTH,
-						      NULL);
-			height = planner_conf_get_int (CONF_WINDOW_HEIGHT,
-						       NULL);
-
-			if (width == 0) {
-				width = DEFAULT_WINDOW_WIDTH;
-			}
-			if (height == 0) {
-				height = DEFAULT_WINDOW_HEIGHT;
-			}
-
-			gtk_window_set_default_size (GTK_WINDOW (window),
-						     width, height);
-
-			x = planner_conf_get_int (CONF_WINDOW_POS_X,
-						  NULL);
-			y = planner_conf_get_int (CONF_WINDOW_POS_Y,
-						  NULL);
-
-			gtk_window_move (GTK_WINDOW (window), x, y);
-		}
+	if (maximized) {
+		gtk_window_maximize (GTK_WINDOW (window));
 	} else {
-		gtk_window_set_default_size (GTK_WINDOW (window), 800, 600);
+		width = planner_conf_get_int (CONF_WINDOW_WIDTH, "ui");
+		height = planner_conf_get_int (CONF_WINDOW_HEIGHT, "ui");
+
+		gtk_window_set_default_size (GTK_WINDOW (window), width, height);
+
+		x = planner_conf_get_int (CONF_WINDOW_POS_X, "ui");
+		y = planner_conf_get_int (CONF_WINDOW_POS_Y, "ui");
+
+		gtk_window_move (GTK_WINDOW (window), x, y);
 	}
 }
 
